Class: Google::Apis::WalletobjectsV1::DiffUploadRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

A Diff upload request. For details on the Scotty Diff protocol, visit http:// go/scotty-diff-protocol.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiffUploadRequest

Returns a new instance of DiffUploadRequest.



1105
1106
1107
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1105

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#checksums_infoGoogle::Apis::WalletobjectsV1::CompositeMedia

A sequence of media data references representing composite data. Introduced to support Bigstore composite objects. For details, visit http://go/bigstore- composites. Corresponds to the JSON property checksumsInfo



1090
1091
1092
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1090

def checksums_info
  @checksums_info
end

#object_infoGoogle::Apis::WalletobjectsV1::CompositeMedia

A sequence of media data references representing composite data. Introduced to support Bigstore composite objects. For details, visit http://go/bigstore- composites. Corresponds to the JSON property objectInfo



1097
1098
1099
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1097

def object_info
  @object_info
end

#object_versionString

The object version of the object that is the base version the incoming diff script will be applied to. This field will always be filled in. Corresponds to the JSON property objectVersion

Returns:

  • (String)


1103
1104
1105
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1103

def object_version
  @object_version
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1110
1111
1112
1113
1114
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1110

def update!(**args)
  @checksums_info = args[:checksums_info] if args.key?(:checksums_info)
  @object_info = args[:object_info] if args.key?(:object_info)
  @object_version = args[:object_version] if args.key?(:object_version)
end