Class: Google::Apis::WalletobjectsV1::DiffUploadResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Backend response for a Diff upload request. For details on the Scotty Diff protocol, visit http://go/scotty-diff-protocol.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiffUploadResponse

Returns a new instance of DiffUploadResponse.



1151
1152
1153
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1151

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#object_versionString

The object version of the object at the server. Must be included in the end notification response. The version in the end notification response must correspond to the new version of the object that is now stored at the server, after the upload. Corresponds to the JSON property objectVersion

Returns:

  • (String)


1142
1143
1144
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1142

def object_version
  @object_version
end

#original_objectGoogle::Apis::WalletobjectsV1::CompositeMedia

A sequence of media data references representing composite data. Introduced to support Bigstore composite objects. For details, visit http://go/bigstore- composites. Corresponds to the JSON property originalObject



1149
1150
1151
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1149

def original_object
  @original_object
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1156
1157
1158
1159
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1156

def update!(**args)
  @object_version = args[:object_version] if args.key?(:object_version)
  @original_object = args[:original_object] if args.key?(:original_object)
end