Class: Google::Apis::WalletobjectsV1::DiscoverableProgram

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Information about how a class may be discovered and instantiated from within the Google Wallet app. This is done by searching for a loyalty or gift card program and scanning or manually entering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverableProgram



1195
1196
1197
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1195

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#merchant_signin_infoGoogle::Apis::WalletobjectsV1::DiscoverableProgramMerchantSigninInfo

Information about the merchant hosted signin flow for a program. Corresponds to the JSON property merchantSigninInfo



1183
1184
1185
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1183

def 
  
end

#merchant_signup_infoGoogle::Apis::WalletobjectsV1::DiscoverableProgramMerchantSignupInfo

Information about the merchant hosted signup flow for a program. Corresponds to the JSON property merchantSignupInfo



1188
1189
1190
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1188

def 
  
end

#stateString

Visibility state of the discoverable program. Corresponds to the JSON property state



1193
1194
1195
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1193

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1200
1201
1202
1203
1204
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1200

def update!(**args)
   = args[:merchant_signin_info] if args.key?(:merchant_signin_info)
   = args[:merchant_signup_info] if args.key?(:merchant_signup_info)
  @state = args[:state] if args.key?(:state)
end