Class: Google::Apis::WalletobjectsV1::DiscoverableProgramMerchantSignupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Information about the merchant hosted signup flow for a program.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverableProgramMerchantSignupInfo

Returns a new instance of DiscoverableProgramMerchantSignupInfo.



1242
1243
1244
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1242

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signup_shared_datasArray<String>

User data that is sent in a POST request to the signup website URL. This information is encoded and then shared so that the merchant's website can prefill fields used to enroll the user for the discoverable program. Corresponds to the JSON property signupSharedDatas

Returns:

  • (Array<String>)


1235
1236
1237
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1235

def 
  @signup_shared_datas
end

#signup_websiteGoogle::Apis::WalletobjectsV1::Uri

The URL to direct the user to for the merchant's signup site. Corresponds to the JSON property signupWebsite



1240
1241
1242
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1240

def 
  @signup_website
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1247
1248
1249
1250
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1247

def update!(**args)
  @signup_shared_datas = args[:signup_shared_datas] if args.key?(:signup_shared_datas)
  @signup_website = args[:signup_website] if args.key?(:signup_website)
end