Class: Google::Apis::WalletobjectsV1::FieldReference

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Reference definition to use with field overrides.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ FieldReference

Returns a new instance of FieldReference.



2349
2350
2351
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2349

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#date_formatString

Only valid if the fieldPath references a date field. Chooses how the date field will be formatted and displayed in the UI. Corresponds to the JSON property dateFormat

Returns:

  • (String)


2340
2341
2342
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2340

def date_format
  @date_format
end

#field_pathString

Path to the field being referenced, prefixed with "object" or "class" and separated with dots. For example, it may be the string "object.purchaseDetails. purchasePrice". Corresponds to the JSON property fieldPath

Returns:

  • (String)


2347
2348
2349
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2347

def field_path
  @field_path
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



2354
2355
2356
2357
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2354

def update!(**args)
  @date_format = args[:date_format] if args.key?(:date_format)
  @field_path = args[:field_path] if args.key?(:field_path)
end