Class: Google::Apis::WalletobjectsV1::GenericClass

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Generic Class

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GenericClass

Returns a new instance of GenericClass.



3372
3373
3374
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3372

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

Optional app or website link that will be displayed as a button on the front of the pass. If AppLinkData is provided for the corresponding object that will be used instead. Corresponds to the JSON property appLinkData



3275
3276
3277
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3275

def app_link_data
  @app_link_data
end

#callback_optionsGoogle::Apis::WalletobjectsV1::CallbackOptions

Callback options to be used to call the issuer back for every save/delete of an object for this class by the end-user. All objects of this class are eligible for the callback. Corresponds to the JSON property callbackOptions



3282
3283
3284
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3282

def callback_options
  @callback_options
end

#class_template_infoGoogle::Apis::WalletobjectsV1::ClassTemplateInfo

Template information about how the class should be displayed. If unset, Google will fallback to a default set of fields to display. Corresponds to the JSON property classTemplateInfo



3288
3289
3290
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3288

def class_template_info
  @class_template_info
end

#enable_smart_tapBoolean Also known as: enable_smart_tap?

Available only to Smart Tap enabled partners. Contact support for additional guidance. Corresponds to the JSON property enableSmartTap

Returns:

  • (Boolean)


3294
3295
3296
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3294

def enable_smart_tap
  @enable_smart_tap
end

#idString

Required. The unique identifier for the class. This ID must be unique across all from an issuer. This value needs to follow the format issuerID.identifier where issuerID is issued by Google and identifier is chosen by you. The unique identifier can only include alphanumeric characters, ., _, or -. Corresponds to the JSON property id

Returns:

  • (String)


3303
3304
3305
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3303

def id
  @id
end

#image_modules_dataArray<Google::Apis::WalletobjectsV1::ImageModuleData>

Image module data. If imageModulesData is also defined on the object, both will be displayed. Only one of the image from class and one from object level will be rendered when both set. Corresponds to the JSON property imageModulesData



3310
3311
3312
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3310

def image_modules_data
  @image_modules_data
end

Links module data. If linksModuleData is also defined on the object, both will be displayed. The maximum number of these fields displayed is 10 from class and 10 from object. Corresponds to the JSON property linksModuleData



3317
3318
3319
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3317

def links_module_data
  @links_module_data
end

#merchant_locationsArray<Google::Apis::WalletobjectsV1::MerchantLocation>

Merchant locations. There is a maximum of ten on the class. Any additional MerchantLocations added beyond the 10 will be rejected. These locations will trigger a notification when a user enters within a Google-set radius of the point. This field replaces the deprecated LatLongPoints. Corresponds to the JSON property merchantLocations



3325
3326
3327
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3325

def merchant_locations
  @merchant_locations
end

#messagesArray<Google::Apis::WalletobjectsV1::Message>

An array of messages displayed in the app. All users of this object will receive its associated messages. The maximum number of these fields is 10. Corresponds to the JSON property messages



3331
3332
3333
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3331

def messages
  @messages
end

#multiple_devices_and_holders_allowed_statusString

Identifies whether multiple users and devices will save the same object referencing this class. Corresponds to the JSON property multipleDevicesAndHoldersAllowedStatus

Returns:

  • (String)


3337
3338
3339
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3337

def multiple_devices_and_holders_allowed_status
  @multiple_devices_and_holders_allowed_status
end

#redemption_issuersArray<Fixnum>

Identifies which redemption issuers can redeem the pass over Smart Tap. Redemption issuers are identified by their issuer ID. Redemption issuers must have at least one Smart Tap key configured. The enableSmartTap and object level smartTapRedemptionLevel fields must also be set up correctly in order for a pass to support Smart Tap. Corresponds to the JSON property redemptionIssuers

Returns:

  • (Array<Fixnum>)


3346
3347
3348
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3346

def redemption_issuers
  @redemption_issuers
end

#security_animationGoogle::Apis::WalletobjectsV1::SecurityAnimation

Optional information about the security animation. If this is set a security animation will be rendered on pass details. Corresponds to the JSON property securityAnimation



3352
3353
3354
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3352

def security_animation
  @security_animation
end

#text_modules_dataArray<Google::Apis::WalletobjectsV1::TextModuleData>

Text module data. If textModulesData is also defined on the object, both will be displayed. The maximum number of these fields displayed is 10 from class and 10 from object. Corresponds to the JSON property textModulesData



3359
3360
3361
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3359

def text_modules_data
  @text_modules_data
end

#value_added_module_dataArray<Google::Apis::WalletobjectsV1::ValueAddedModuleData>

Optional value added module data. Maximum of fifteen on the class. For a pass only fifteen will be displayed, prioritizing those from the object. Corresponds to the JSON property valueAddedModuleData



3365
3366
3367
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3365

def value_added_module_data
  @value_added_module_data
end

#view_unlock_requirementString

View Unlock Requirement options for the generic pass. Corresponds to the JSON property viewUnlockRequirement

Returns:

  • (String)


3370
3371
3372
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3370

def view_unlock_requirement
  @view_unlock_requirement
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



3377
3378
3379
3380
3381
3382
3383
3384
3385
3386
3387
3388
3389
3390
3391
3392
3393
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 3377

def update!(**args)
  @app_link_data = args[:app_link_data] if args.key?(:app_link_data)
  @callback_options = args[:callback_options] if args.key?(:callback_options)
  @class_template_info = args[:class_template_info] if args.key?(:class_template_info)
  @enable_smart_tap = args[:enable_smart_tap] if args.key?(:enable_smart_tap)
  @id = args[:id] if args.key?(:id)
  @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data)
  @links_module_data = args[:links_module_data] if args.key?(:links_module_data)
  @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations)
  @messages = args[:messages] if args.key?(:messages)
  @multiple_devices_and_holders_allowed_status = args[:multiple_devices_and_holders_allowed_status] if args.key?(:multiple_devices_and_holders_allowed_status)
  @redemption_issuers = args[:redemption_issuers] if args.key?(:redemption_issuers)
  @security_animation = args[:security_animation] if args.key?(:security_animation)
  @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data)
  @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data)
  @view_unlock_requirement = args[:view_unlock_requirement] if args.key?(:view_unlock_requirement)
end