Class: Google::Apis::WalletobjectsV1::GroupingInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ GroupingInfo

Returns a new instance of GroupingInfo.



4425
4426
4427
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4425

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#grouping_idString

Optional grouping ID for grouping the passes with the same ID visually together. Grouping with different types of passes is allowed. Corresponds to the JSON property groupingId

Returns:

  • (String)


4415
4416
4417
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4415

def grouping_id
  @grouping_id
end

#sort_indexFixnum

Optional index for sorting the passes when they are grouped with other passes. Passes with lower sort index are shown before passes with higher sort index. If unspecified, the value is assumed to be INT_MAX. For two passes with the same sort index, the sorting behavior is undefined. Corresponds to the JSON property sortIndex

Returns:

  • (Fixnum)


4423
4424
4425
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4423

def sort_index
  @sort_index
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4430
4431
4432
4433
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4430

def update!(**args)
  @grouping_id = args[:grouping_id] if args.key?(:grouping_id)
  @sort_index = args[:sort_index] if args.key?(:sort_index)
end