Class: Google::Apis::WalletobjectsV1::ImageUri

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ImageUri

Returns a new instance of ImageUri.



4524
4525
4526
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4524

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#descriptionString

Additional information about the image, which is unused and retained only for backward compatibility. Corresponds to the JSON property description

Returns:

  • (String)


4511
4512
4513
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4511

def description
  @description
end

#localized_descriptionGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the description, which are unused and retained only for backward compatibility. Corresponds to the JSON property localizedDescription



4517
4518
4519
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4517

def localized_description
  @localized_description
end

#uriString

The location of the image. URIs must have a scheme. Corresponds to the JSON property uri

Returns:

  • (String)


4522
4523
4524
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4522

def uri
  @uri
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4529
4530
4531
4532
4533
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4529

def update!(**args)
  @description = args[:description] if args.key?(:description)
  @localized_description = args[:localized_description] if args.key?(:localized_description)
  @uri = args[:uri] if args.key?(:uri)
end