Class: Google::Apis::WalletobjectsV1::JsonResource

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

A JSON representation of a pass.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ JsonResource

Returns a new instance of JsonResource.



4720
4721
4722
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4720

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#jsonString

Required. A JSON string representing the unencoded JWT payload for a pass of the format described at https://developers.google.com/wallet/reference/rest/v1/ Jwt. This can be set to either the entire JSON representation described at this link or just the contents of the payload field holding the relevant classes and objects. Corresponds to the JSON property json

Returns:

  • (String)


4718
4719
4720
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4718

def json
  @json
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4725
4726
4727
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4725

def update!(**args)
  @json = args[:json] if args.key?(:json)
end