Class: Google::Apis::WalletobjectsV1::LabelValue

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

A pair of text strings to be displayed in the details view. Note we no longer display LabelValue/LabelValueRow as a table, instead a list of items.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ LabelValue

Returns a new instance of LabelValue.



4771
4772
4773
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4771

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#labelString

The label for a specific row and column. Recommended maximum is 15 characters for a two-column layout and 30 characters for a one-column layout. Corresponds to the JSON property label

Returns:

  • (String)


4751
4752
4753
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4751

def label
  @label
end

#localized_labelGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the label. Recommended maximum is 15 characters for a two-column layout and 30 characters for a one-column layout. Corresponds to the JSON property localizedLabel



4757
4758
4759
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4757

def localized_label
  @localized_label
end

#localized_valueGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the value. Recommended maximum is 15 characters for a two-column layout and 30 characters for a one-column layout. Corresponds to the JSON property localizedValue



4763
4764
4765
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4763

def localized_value
  @localized_value
end

#valueString

The value for a specific row and column. Recommended maximum is 15 characters for a two-column layout and 30 characters for a one-column layout. Corresponds to the JSON property value

Returns:

  • (String)


4769
4770
4771
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4769

def value
  @value
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4776
4777
4778
4779
4780
4781
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4776

def update!(**args)
  @label = args[:label] if args.key?(:label)
  @localized_label = args[:localized_label] if args.key?(:localized_label)
  @localized_value = args[:localized_value] if args.key?(:localized_value)
  @value = args[:value] if args.key?(:value)
end