Class: Google::Apis::WalletobjectsV1::ListTemplateOverride

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListTemplateOverride

Returns a new instance of ListTemplateOverride.



4953
4954
4955
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4953

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#first_row_optionGoogle::Apis::WalletobjectsV1::FirstRowOption

Specifies from a predefined set of options or from a reference to the field what will be displayed in the first row. To set this override, set the FirstRowOption.fieldOption to the FieldSelector of your choice. Corresponds to the JSON property firstRowOption



4941
4942
4943
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4941

def first_row_option
  @first_row_option
end

#second_row_optionGoogle::Apis::WalletobjectsV1::FieldSelector

Custom field selector to use with field overrides. Corresponds to the JSON property secondRowOption



4946
4947
4948
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4946

def second_row_option
  @second_row_option
end

#third_row_optionGoogle::Apis::WalletobjectsV1::FieldSelector

Custom field selector to use with field overrides. Corresponds to the JSON property thirdRowOption



4951
4952
4953
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4951

def third_row_option
  @third_row_option
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



4958
4959
4960
4961
4962
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4958

def update!(**args)
  @first_row_option = args[:first_row_option] if args.key?(:first_row_option)
  @second_row_option = args[:second_row_option] if args.key?(:second_row_option)
  @third_row_option = args[:third_row_option] if args.key?(:third_row_option)
end