Class: Google::Apis::WalletobjectsV1::MerchantLocation

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Locations of interest for this class or object. Currently, this location is used for geofenced notifications. When a user is within a set radius of this lat/long, and dwells there, Google will trigger a notification. When a user exits this radius, the notification will be hidden.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ MerchantLocation



6068
6069
6070
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6068

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#latitudeFloat

The latitude specified as any value in the range of -90.0 through +90.0, both inclusive. Values outside these bounds will be rejected. Corresponds to the JSON property latitude



6060
6061
6062
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6060

def latitude
  @latitude
end

#longitudeFloat

The longitude specified in the range -180.0 through +180.0, both inclusive. Values outside these bounds will be rejected. Corresponds to the JSON property longitude



6066
6067
6068
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6066

def longitude
  @longitude
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



6073
6074
6075
6076
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6073

def update!(**args)
  @latitude = args[:latitude] if args.key?(:latitude)
  @longitude = args[:longitude] if args.key?(:longitude)
end