Class: Google::Apis::WalletobjectsV1::Pagination
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::Pagination
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#next_page_token ⇒ String
Page token to send to fetch the next page.
-
#results_per_page ⇒ Fixnum
Number of results returned in this page.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Pagination
constructor
A new instance of Pagination.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Pagination
Returns a new instance of Pagination.
7011 7012 7013 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7011 def initialize(**args) update!(**args) end |
Instance Attribute Details
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#pagination".
Corresponds to the JSON property kind
6999 7000 7001 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6999 def kind @kind end |
#next_page_token ⇒ String
Page token to send to fetch the next page.
Corresponds to the JSON property nextPageToken
7004 7005 7006 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7004 def next_page_token @next_page_token end |
#results_per_page ⇒ Fixnum
Number of results returned in this page.
Corresponds to the JSON property resultsPerPage
7009 7010 7011 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7009 def results_per_page @results_per_page end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7016 7017 7018 7019 7020 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7016 def update!(**args) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) @results_per_page = args[:results_per_page] if args.key?(:results_per_page) end |