Class: Google::Apis::WalletobjectsV1::Permissions
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::Permissions
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#issuer_id ⇒ Fixnum
ID of the issuer the list of permissions refer to.
-
#permissions ⇒ Array<Google::Apis::WalletobjectsV1::Permission>
The complete list of permissions for the issuer account.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Permissions
constructor
A new instance of Permissions.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Permissions
Returns a new instance of Permissions.
7088 7089 7090 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7088 def initialize(**args) update!(**args) end |
Instance Attribute Details
#issuer_id ⇒ Fixnum
ID of the issuer the list of permissions refer to.
Corresponds to the JSON property issuerId
7081 7082 7083 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7081 def issuer_id @issuer_id end |
#permissions ⇒ Array<Google::Apis::WalletobjectsV1::Permission>
The complete list of permissions for the issuer account.
Corresponds to the JSON property permissions
7086 7087 7088 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7086 def @permissions end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
7093 7094 7095 7096 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7093 def update!(**args) @issuer_id = args[:issuer_id] if args.key?(:issuer_id) @permissions = args[:permissions] if args.key?(:permissions) end |