Class: Google::Apis::WalletobjectsV1::PurchaseDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PurchaseDetails

Returns a new instance of PurchaseDetails.



7210
7211
7212
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7210

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

ID of the account used to purchase the ticket. Corresponds to the JSON property accountId

Returns:

  • (String)


7174
7175
7176
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7174

def 
  @account_id
end

#confirmation_codeString

The confirmation code for the purchase. This may be the same for multiple different tickets and is used to group tickets together. Corresponds to the JSON property confirmationCode

Returns:

  • (String)


7180
7181
7182
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7180

def confirmation_code
  @confirmation_code
end

#purchase_date_timeString

The purchase date/time of the ticket. This is an ISO 8601 extended format date/ time, with or without an offset. Time may be specified up to nanosecond precision. Offsets may be specified with seconds precision (even though offset seconds is not part of ISO 8601). For example: 1985-04-12T23:20:50.52Z would be 20 minutes and 50.52 seconds after the 23rd hour of April 12th, 1985 in UTC. 1985-04-12T19:20:50.52-04:00 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985, 4 hours before UTC (same instant in time as the above example). If the event were in New York, this would be the equivalent of Eastern Daylight Time (EDT). Remember that offset varies in regions that observe Daylight Saving Time (or Summer Time), depending on the time of the year. 1985-04-12T19:20:50.52 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985 with no offset information. Without offset information, some rich features may not be available. Corresponds to the JSON property purchaseDateTime

Returns:

  • (String)


7197
7198
7199
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7197

def purchase_date_time
  @purchase_date_time
end

#purchase_receipt_numberString

Receipt number/identifier for tracking the ticket purchase via the body that sold the ticket. Corresponds to the JSON property purchaseReceiptNumber

Returns:

  • (String)


7203
7204
7205
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7203

def purchase_receipt_number
  @purchase_receipt_number
end

#ticket_costGoogle::Apis::WalletobjectsV1::TicketCost

The cost of the ticket. Corresponds to the JSON property ticketCost



7208
7209
7210
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7208

def ticket_cost
  @ticket_cost
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7215
7216
7217
7218
7219
7220
7221
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7215

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @confirmation_code = args[:confirmation_code] if args.key?(:confirmation_code)
  @purchase_date_time = args[:purchase_date_time] if args.key?(:purchase_date_time)
  @purchase_receipt_number = args[:purchase_receipt_number] if args.key?(:purchase_receipt_number)
  @ticket_cost = args[:ticket_cost] if args.key?(:ticket_cost)
end