Class: Google::Apis::WalletobjectsV1::ReservationInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ReservationInfo

Returns a new instance of ReservationInfo.



7190
7191
7192
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7190

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#confirmation_codeString

Confirmation code needed to check into this flight. This is the number that the passenger would enter into a kiosk at the airport to look up the flight and print a boarding pass. Corresponds to the JSON property confirmationCode

Returns:

  • (String)


7172
7173
7174
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7172

def confirmation_code
  @confirmation_code
end

#eticket_numberString

E-ticket number. Corresponds to the JSON property eticketNumber

Returns:

  • (String)


7177
7178
7179
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7177

def eticket_number
  @eticket_number
end

#frequent_flyer_infoGoogle::Apis::WalletobjectsV1::FrequentFlyerInfo

Frequent flyer membership information. Corresponds to the JSON property frequentFlyerInfo



7182
7183
7184
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7182

def frequent_flyer_info
  @frequent_flyer_info
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " walletobjects#reservationInfo". Corresponds to the JSON property kind

Returns:

  • (String)


7188
7189
7190
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7188

def kind
  @kind
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7195
7196
7197
7198
7199
7200
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7195

def update!(**args)
  @confirmation_code = args[:confirmation_code] if args.key?(:confirmation_code)
  @eticket_number = args[:eticket_number] if args.key?(:eticket_number)
  @frequent_flyer_info = args[:frequent_flyer_info] if args.key?(:frequent_flyer_info)
  @kind = args[:kind] if args.key?(:kind)
end