Class: Google::Apis::WalletobjectsV1::RotatingBarcodeValues

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

A payload containing many barcode values and start date/time.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotatingBarcodeValues

Returns a new instance of RotatingBarcodeValues.



7453
7454
7455
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7453

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#period_millisFixnum

Required. The amount of time each barcode is valid for. Corresponds to the JSON property periodMillis

Returns:

  • (Fixnum)


7429
7430
7431
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7429

def period_millis
  @period_millis
end

#start_date_timeString

Required. The date/time the first barcode is valid from. Barcodes will be rotated through using period_millis defined on the object's RotatingBarcodeValueInfo. This is an ISO 8601 extended format date/time, with an offset. Time may be specified up to nanosecond precision. Offsets may be specified with seconds precision (even though offset seconds is not part of ISO 8601). For example: 1985-04-12T23:20:50.52Z would be 20 minutes and 50. 52 seconds after the 23rd hour of April 12th, 1985 in UTC. 1985-04-12T19:20: 50.52-04:00 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985, 4 hours before UTC (same instant in time as the above example). If the event were in New York, this would be the equivalent of Eastern Daylight Time (EDT). Remember that offset varies in regions that observe Daylight Saving Time (or Summer Time), depending on the time of the year. Corresponds to the JSON property startDateTime

Returns:

  • (String)


7446
7447
7448
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7446

def start_date_time
  @start_date_time
end

#valuesArray<String>

Required. The values to encode in the barcode. At least one value is required. Corresponds to the JSON property values

Returns:

  • (Array<String>)


7451
7452
7453
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7451

def values
  @values
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7458
7459
7460
7461
7462
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7458

def update!(**args)
  @period_millis = args[:period_millis] if args.key?(:period_millis)
  @start_date_time = args[:start_date_time] if args.key?(:start_date_time)
  @values = args[:values] if args.key?(:values)
end