Class: Google::Apis::WalletobjectsV1::TicketCost

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketCost

Returns a new instance of TicketCost.



7841
7842
7843
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7841

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#discount_messageGoogle::Apis::WalletobjectsV1::LocalizedString

A message describing any kind of discount that was applied. Corresponds to the JSON property discountMessage



7829
7830
7831
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7829

def discount_message
  @discount_message
end

#face_valueGoogle::Apis::WalletobjectsV1::Money

The face value of the ticket. Corresponds to the JSON property faceValue



7834
7835
7836
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7834

def face_value
  @face_value
end

#purchase_priceGoogle::Apis::WalletobjectsV1::Money

The actual purchase price of the ticket, after tax and/or discounts. Corresponds to the JSON property purchasePrice



7839
7840
7841
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7839

def purchase_price
  @purchase_price
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7846
7847
7848
7849
7850
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7846

def update!(**args)
  @discount_message = args[:discount_message] if args.key?(:discount_message)
  @face_value = args[:face_value] if args.key?(:face_value)
  @purchase_price = args[:purchase_price] if args.key?(:purchase_price)
end