Class: Google::Apis::WalletobjectsV1::UploadPrivateImageResponse
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::UploadPrivateImageResponse
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Overview
Response for uploading the private image.
Instance Attribute Summary collapse
-
#private_image_id ⇒ String
Unique ID of the uploaded image to be referenced later in Image.
Instance Method Summary collapse
-
#initialize(**args) ⇒ UploadPrivateImageResponse
constructor
A new instance of UploadPrivateImageResponse.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ UploadPrivateImageResponse
Returns a new instance of UploadPrivateImageResponse.
9087 9088 9089 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9087 def initialize(**args) update!(**args) end |
Instance Attribute Details
#private_image_id ⇒ String
Unique ID of the uploaded image to be referenced later in Image.
private_image_id.
Corresponds to the JSON property privateImageId
9085 9086 9087 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9085 def private_image_id @private_image_id end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9092 9093 9094 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9092 def update!(**args) @private_image_id = args[:private_image_id] if args.key?(:private_image_id) end |