Class: Google::Apis::WalletobjectsV1::ValueAddedModuleData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Data for Value Added module. Required fields are header and uri.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ValueAddedModuleData

Returns a new instance of ValueAddedModuleData.



9121
9122
9123
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9121

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bodyGoogle::Apis::WalletobjectsV1::LocalizedString

Body to be displayed on the module. Character limit is 50 and longer strings will be truncated. Corresponds to the JSON property body



9089
9090
9091
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9089

def body
  @body
end

#headerGoogle::Apis::WalletobjectsV1::LocalizedString

Header to be displayed on the module. Character limit is 60 and longer strings will be truncated. Corresponds to the JSON property header



9095
9096
9097
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9095

def header
  @header
end

#imageGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property image



9100
9101
9102
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9100

def image
  @image
end

#sort_indexFixnum

The index for sorting the modules. Modules with a lower sort index are shown before modules with a higher sort index. If unspecified, the sort index is assumed to be INT_MAX. For two modules with the same index, the sorting behavior is undefined. Corresponds to the JSON property sortIndex

Returns:

  • (Fixnum)


9108
9109
9110
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9108

def sort_index
  @sort_index
end

#uriString

URI that the module leads to on click. This can be a web link or a deep link as mentioned in https://developer.android.com/training/app-links/deep-linking. Corresponds to the JSON property uri

Returns:

  • (String)


9114
9115
9116
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9114

def uri
  @uri
end

#view_constraintsGoogle::Apis::WalletobjectsV1::ModuleViewConstraints

Constraints that all must be met for the module to be shown. Corresponds to the JSON property viewConstraints



9119
9120
9121
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9119

def view_constraints
  @view_constraints
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



9126
9127
9128
9129
9130
9131
9132
9133
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9126

def update!(**args)
  @body = args[:body] if args.key?(:body)
  @header = args[:header] if args.key?(:header)
  @image = args[:image] if args.key?(:image)
  @sort_index = args[:sort_index] if args.key?(:sort_index)
  @uri = args[:uri] if args.key?(:uri)
  @view_constraints = args[:view_constraints] if args.key?(:view_constraints)
end