Class: Google::Apis::WalletobjectsV1::CardRowThreeItems
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::CardRowThreeItems
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#end_item ⇒ Google::Apis::WalletobjectsV1::TemplateItem
The item to be displayed at the end of the row.
-
#middle_item ⇒ Google::Apis::WalletobjectsV1::TemplateItem
The item to be displayed in the middle of the row.
-
#start_item ⇒ Google::Apis::WalletobjectsV1::TemplateItem
The item to be displayed at the start of the row.
Instance Method Summary collapse
-
#initialize(**args) ⇒ CardRowThreeItems
constructor
A new instance of CardRowThreeItems.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ CardRowThreeItems
Returns a new instance of CardRowThreeItems.
665 666 667 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 665 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end_item ⇒ Google::Apis::WalletobjectsV1::TemplateItem
The item to be displayed at the end of the row. This item will be aligned to
the right.
Corresponds to the JSON property endItem
651 652 653 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 651 def end_item @end_item end |
#middle_item ⇒ Google::Apis::WalletobjectsV1::TemplateItem
The item to be displayed in the middle of the row. This item will be centered
between the start and end items.
Corresponds to the JSON property middleItem
657 658 659 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 657 def middle_item @middle_item end |
#start_item ⇒ Google::Apis::WalletobjectsV1::TemplateItem
The item to be displayed at the start of the row. This item will be aligned to
the left.
Corresponds to the JSON property startItem
663 664 665 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 663 def start_item @start_item end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
670 671 672 673 674 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 670 def update!(**args) @end_item = args[:end_item] if args.key?(:end_item) @middle_item = args[:middle_item] if args.key?(:middle_item) @start_item = args[:start_item] if args.key?(:start_item) end |