Class: Google::Apis::WalletobjectsV1::DiffUploadRequest
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::DiffUploadRequest
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Overview
A Diff upload request. For details on the Scotty Diff protocol, visit http:// go/scotty-diff-protocol.
Instance Attribute Summary collapse
-
#checksums_info ⇒ Google::Apis::WalletobjectsV1::CompositeMedia
A sequence of media data references representing composite data.
-
#object_info ⇒ Google::Apis::WalletobjectsV1::CompositeMedia
A sequence of media data references representing composite data.
-
#object_version ⇒ String
The object version of the object that is the base version the incoming diff script will be applied to.
Instance Method Summary collapse
-
#initialize(**args) ⇒ DiffUploadRequest
constructor
A new instance of DiffUploadRequest.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ DiffUploadRequest
Returns a new instance of DiffUploadRequest.
1119 1120 1121 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1119 def initialize(**args) update!(**args) end |
Instance Attribute Details
#checksums_info ⇒ Google::Apis::WalletobjectsV1::CompositeMedia
A sequence of media data references representing composite data. Introduced to
support Bigstore composite objects. For details, visit http://go/bigstore-
composites.
Corresponds to the JSON property checksumsInfo
1104 1105 1106 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1104 def checksums_info @checksums_info end |
#object_info ⇒ Google::Apis::WalletobjectsV1::CompositeMedia
A sequence of media data references representing composite data. Introduced to
support Bigstore composite objects. For details, visit http://go/bigstore-
composites.
Corresponds to the JSON property objectInfo
1111 1112 1113 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1111 def object_info @object_info end |
#object_version ⇒ String
The object version of the object that is the base version the incoming diff
script will be applied to. This field will always be filled in.
Corresponds to the JSON property objectVersion
1117 1118 1119 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1117 def object_version @object_version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1124 1125 1126 1127 1128 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1124 def update!(**args) @checksums_info = args[:checksums_info] if args.key?(:checksums_info) @object_info = args[:object_info] if args.key?(:object_info) @object_version = args[:object_version] if args.key?(:object_version) end |