Class: Google::Apis::WalletobjectsV1::DiscoverableProgram

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Information about how a class may be discovered and instantiated from within the Google Wallet app. This is done by searching for a loyalty or gift card program and scanning or manually entering.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverableProgram

Returns a new instance of DiscoverableProgram.



1209
1210
1211
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1209

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#merchant_signin_infoGoogle::Apis::WalletobjectsV1::DiscoverableProgramMerchantSigninInfo

Information about the merchant hosted signin flow for a program. Corresponds to the JSON property merchantSigninInfo



1197
1198
1199
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1197

def 
  @merchant_signin_info
end

#merchant_signup_infoGoogle::Apis::WalletobjectsV1::DiscoverableProgramMerchantSignupInfo

Information about the merchant hosted signup flow for a program. Corresponds to the JSON property merchantSignupInfo



1202
1203
1204
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1202

def 
  @merchant_signup_info
end

#stateString

Visibility state of the discoverable program. Corresponds to the JSON property state

Returns:

  • (String)


1207
1208
1209
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1207

def state
  @state
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1214
1215
1216
1217
1218
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1214

def update!(**args)
  @merchant_signin_info = args[:merchant_signin_info] if args.key?(:merchant_signin_info)
  @merchant_signup_info = args[:merchant_signup_info] if args.key?(:merchant_signup_info)
  @state = args[:state] if args.key?(:state)
end