Class: Google::Apis::WalletobjectsV1::DiscoverableProgramMerchantSignupInfo

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Information about the merchant hosted signup flow for a program.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ DiscoverableProgramMerchantSignupInfo

Returns a new instance of DiscoverableProgramMerchantSignupInfo.



1256
1257
1258
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1256

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#signup_shared_datasArray<String>

User data that is sent in a POST request to the signup website URL. This information is encoded and then shared so that the merchant's website can prefill fields used to enroll the user for the discoverable program. Corresponds to the JSON property signupSharedDatas

Returns:

  • (Array<String>)


1249
1250
1251
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1249

def 
  @signup_shared_datas
end

#signup_websiteGoogle::Apis::WalletobjectsV1::Uri

The URL to direct the user to for the merchant's signup site. Corresponds to the JSON property signupWebsite



1254
1255
1256
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1254

def 
  @signup_website
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1261
1262
1263
1264
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1261

def update!(**args)
  @signup_shared_datas = args[:signup_shared_datas] if args.key?(:signup_shared_datas)
  @signup_website = args[:signup_website] if args.key?(:signup_website)
end