Class: Google::Apis::WalletobjectsV1::EventSeat
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::EventSeat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#gate ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The gate the ticket holder should enter to get to their seat, such as "A" or " West".
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#row ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The row of the seat, such as "1", E", "BB", or "A5".
-
#seat ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The seat number, such as "1", "2", "3", or any other seat identifier.
-
#section ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The section of the seat, such as "121".
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventSeat
constructor
A new instance of EventSeat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventSeat
Returns a new instance of EventSeat.
1478 1479 1480 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1478 def initialize(**args) update!(**args) end |
Instance Attribute Details
#gate ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The gate the ticket holder should enter to get to their seat, such as "A" or "
West". This field is localizable so you may translate words or use different
alphabets for the characters in an identifier.
Corresponds to the JSON property gate
1450 1451 1452 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1450 def gate @gate end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#eventSeat".
Corresponds to the JSON property kind
1456 1457 1458 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1456 def kind @kind end |
#row ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The row of the seat, such as "1", E", "BB", or "A5". This field is localizable
so you may translate words or use different alphabets for the characters in an
identifier.
Corresponds to the JSON property row
1463 1464 1465 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1463 def row @row end |
#seat ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The seat number, such as "1", "2", "3", or any other seat identifier. This
field is localizable so you may translate words or use different alphabets for
the characters in an identifier.
Corresponds to the JSON property seat
1470 1471 1472 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1470 def seat @seat end |
#section ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The section of the seat, such as "121". This field is localizable so you may
translate words or use different alphabets for the characters in an identifier.
Corresponds to the JSON property section
1476 1477 1478 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1476 def section @section end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
1483 1484 1485 1486 1487 1488 1489 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1483 def update!(**args) @gate = args[:gate] if args.key?(:gate) @kind = args[:kind] if args.key?(:kind) @row = args[:row] if args.key?(:row) @seat = args[:seat] if args.key?(:seat) @section = args[:section] if args.key?(:section) end |