Class: Google::Apis::WalletobjectsV1::EventTicketClass

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ EventTicketClass

Returns a new instance of EventTicketClass.



1840
1841
1842
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1840

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#allow_multiple_users_per_objectBoolean Also known as: allow_multiple_users_per_object?

Deprecated. Use multipleDevicesAndHoldersAllowedStatus instead. Corresponds to the JSON property allowMultipleUsersPerObject

Returns:

  • (Boolean)


1499
1500
1501
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1499

def allow_multiple_users_per_object
  @allow_multiple_users_per_object
end

Optional app or website link that will be displayed as a button on the front of the pass. If AppLinkData is provided for the corresponding object that will be used instead. Corresponds to the JSON property appLinkData



1507
1508
1509
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1507

def app_link_data
  @app_link_data
end

#callback_optionsGoogle::Apis::WalletobjectsV1::CallbackOptions

Callback options to be used to call the issuer back for every save/delete of an object for this class by the end-user. All objects of this class are eligible for the callback. Corresponds to the JSON property callbackOptions



1514
1515
1516
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1514

def callback_options
  @callback_options
end

#class_template_infoGoogle::Apis::WalletobjectsV1::ClassTemplateInfo

Template information about how the class should be displayed. If unset, Google will fallback to a default set of fields to display. Corresponds to the JSON property classTemplateInfo



1520
1521
1522
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1520

def class_template_info
  @class_template_info
end

#confirmation_code_labelString

The label to use for the confirmation code value (eventTicketObject. reservationInfo.confirmationCode) on the card detail view. Each available option maps to a set of localized strings, so that translations are shown to the user based on their locale. Both confirmationCodeLabel and customConfirmationCodeLabel may not be set. If neither is set, the label will default to "Confirmation Code", localized. If the confirmation code field is unset, this label will not be used. Corresponds to the JSON property confirmationCodeLabel

Returns:

  • (String)


1531
1532
1533
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1531

def confirmation_code_label
  @confirmation_code_label
end

#country_codeString

Country code used to display the card's country (when the user is not in that country), as well as to display localized content when content is not available in the user's locale. Corresponds to the JSON property countryCode

Returns:

  • (String)


1538
1539
1540
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1538

def country_code
  @country_code
end

#custom_confirmation_code_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the confirmation code value (eventTicketObject. reservationInfo.confirmationCode) on the card detail view. This should only be used if the default "Confirmation Code" label or one of the confirmationCodeLabel options is not sufficient. Both confirmationCodeLabel and customConfirmationCodeLabel may not be set. If neither is set, the label will default to "Confirmation Code", localized. If the confirmation code field is unset, this label will not be used. Corresponds to the JSON property customConfirmationCodeLabel



1549
1550
1551
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1549

def custom_confirmation_code_label
  @custom_confirmation_code_label
end

#custom_gate_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the gate value (eventTicketObject.seatInfo.gate) on the card detail view. This should only be used if the default "Gate" label or one of the gateLabel options is not sufficient. Both gateLabel and customGateLabel may not be set. If neither is set, the label will default to " Gate", localized. If the gate field is unset, this label will not be used. Corresponds to the JSON property customGateLabel



1558
1559
1560
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1558

def custom_gate_label
  @custom_gate_label
end

#custom_row_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the row value (eventTicketObject.seatInfo.row) on the card detail view. This should only be used if the default "Row" label or one of the rowLabel options is not sufficient. Both rowLabel and customRowLabel may not be set. If neither is set, the label will default to " Row", localized. If the row field is unset, this label will not be used. Corresponds to the JSON property customRowLabel



1567
1568
1569
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1567

def custom_row_label
  @custom_row_label
end

#custom_seat_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the seat value (eventTicketObject.seatInfo.seat) on the card detail view. This should only be used if the default "Seat" label or one of the seatLabel options is not sufficient. Both seatLabel and customSeatLabel may not be set. If neither is set, the label will default to " Seat", localized. If the seat field is unset, this label will not be used. Corresponds to the JSON property customSeatLabel



1576
1577
1578
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1576

def custom_seat_label
  @custom_seat_label
end

#custom_section_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the section value (eventTicketObject.seatInfo. section) on the card detail view. This should only be used if the default " Section" label or one of the sectionLabel options is not sufficient. Both sectionLabel and customSectionLabel may not be set. If neither is set, the label will default to "Section", localized. If the section field is unset, this label will not be used. Corresponds to the JSON property customSectionLabel



1586
1587
1588
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1586

def 
  @custom_section_label
end

#date_timeGoogle::Apis::WalletobjectsV1::EventDateTime

The date & time information of the event. Corresponds to the JSON property dateTime



1591
1592
1593
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1591

def date_time
  @date_time
end

#enable_smart_tapBoolean Also known as: enable_smart_tap?

Identifies whether this class supports Smart Tap. The redemptionIssuers and object level smartTapRedemptionLevel fields must also be set up correctly in order for a pass to support Smart Tap. Corresponds to the JSON property enableSmartTap

Returns:

  • (Boolean)


1598
1599
1600
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1598

def enable_smart_tap
  @enable_smart_tap
end

#event_idString

The ID of the event. This ID should be unique for every event in an account. It is used to group tickets together if the user has saved multiple tickets for the same event. It can be at most 64 characters. If provided, the grouping will be stable. Be wary of unintentional collision to avoid grouping tickets that should not be grouped. If you use only one class per event, you can simply set this to the classId (with or without the issuer ID portion). If not provided, the platform will attempt to use other data to group tickets ( potentially unstable). Corresponds to the JSON property eventId

Returns:

  • (String)


1611
1612
1613
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1611

def event_id
  @event_id
end

#event_nameGoogle::Apis::WalletobjectsV1::LocalizedString

Required. The name of the event, such as "LA Dodgers at SF Giants". Corresponds to the JSON property eventName



1616
1617
1618
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1616

def event_name
  @event_name
end

#fine_printGoogle::Apis::WalletobjectsV1::LocalizedString

The fine print, terms, or conditions of the ticket. Corresponds to the JSON property finePrint



1621
1622
1623
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1621

def fine_print
  @fine_print
end

#gate_labelString

The label to use for the gate value (eventTicketObject.seatInfo.gate) on the card detail view. Each available option maps to a set of localized strings, so that translations are shown to the user based on their locale. Both gateLabel and customGateLabel may not be set. If neither is set, the label will default to "Gate", localized. If the gate field is unset, this label will not be used. Corresponds to the JSON property gateLabel

Returns:

  • (String)


1631
1632
1633
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1631

def gate_label
  @gate_label
end

#hero_imageGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property heroImage



1636
1637
1638
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1636

def hero_image
  @hero_image
end

#hex_background_colorString

The background color for the card. If not set the dominant color of the hero image is used, and if no hero image is set, the dominant color of the logo is used. The format is #rrggbb where rrggbb is a hex RGB triplet, such as # ffcc00. You can also use the shorthand version of the RGB triplet which is # rgb, such as #fc0. Corresponds to the JSON property hexBackgroundColor

Returns:

  • (String)


1645
1646
1647
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1645

def hex_background_color
  @hex_background_color
end

#homepage_uriGoogle::Apis::WalletobjectsV1::Uri

The URI of your application's home page. Populating the URI in this field results in the exact same behavior as populating an URI in linksModuleData ( when an object is rendered, a link to the homepage is shown in what would usually be thought of as the linksModuleData section of the object). Corresponds to the JSON property homepageUri



1653
1654
1655
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1653

def homepage_uri
  @homepage_uri
end

#idString

Required. The unique identifier for a class. This ID must be unique across all classes from an issuer. This value should follow the format issuer ID. identifier where the former is issued by Google and latter is chosen by you. Your unique identifier should only include alphanumeric characters, '.', '_', or '-'. Corresponds to the JSON property id

Returns:

  • (String)


1662
1663
1664
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1662

def id
  @id
end

#image_modules_dataArray<Google::Apis::WalletobjectsV1::ImageModuleData>

Image module data. The maximum number of these fields displayed is 1 from object level and 1 for class object level. Corresponds to the JSON property imageModulesData



1668
1669
1670
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1668

def image_modules_data
  @image_modules_data
end

#info_module_dataGoogle::Apis::WalletobjectsV1::InfoModuleData

Deprecated. Use textModulesData instead. Corresponds to the JSON property infoModuleData



1673
1674
1675
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1673

def info_module_data
  @info_module_data
end

#issuer_nameString

Required. The issuer name. Recommended maximum length is 20 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property issuerName

Returns:

  • (String)


1679
1680
1681
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1679

def issuer_name
  @issuer_name
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " walletobjects#eventTicketClass". Corresponds to the JSON property kind

Returns:

  • (String)


1685
1686
1687
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1685

def kind
  @kind
end

Links module data. If links module data is also defined on the object, both will be displayed. Corresponds to the JSON property linksModuleData



1691
1692
1693
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1691

def links_module_data
  @links_module_data
end

#localized_issuer_nameGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the issuer_name. Recommended maximum length is 20 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property localizedIssuerName



1697
1698
1699
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1697

def localized_issuer_name
  @localized_issuer_name
end

#locationsArray<Google::Apis::WalletobjectsV1::LatLongPoint>

Note: This field is currently not supported to trigger geo notifications. Corresponds to the JSON property locations



1702
1703
1704
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1702

def locations
  @locations
end

#logoGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property logo



1707
1708
1709
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1707

def 
  @logo
end

#merchant_locationsArray<Google::Apis::WalletobjectsV1::MerchantLocation>

Merchant locations. There is a maximum of ten on the class. Any additional MerchantLocations added beyond the 10 will be rejected. These locations will trigger a notification when a user enters within a Google-set radius of the point. This field replaces the deprecated LatLongPoints. Corresponds to the JSON property merchantLocations



1715
1716
1717
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1715

def merchant_locations
  @merchant_locations
end

#messagesArray<Google::Apis::WalletobjectsV1::Message>

An array of messages displayed in the app. All users of this object will receive its associated messages. The maximum number of these fields is 10. Corresponds to the JSON property messages



1721
1722
1723
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1721

def messages
  @messages
end

#multiple_devices_and_holders_allowed_statusString

Identifies whether multiple users and devices will save the same object referencing this class. Corresponds to the JSON property multipleDevicesAndHoldersAllowedStatus

Returns:

  • (String)


1727
1728
1729
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1727

def multiple_devices_and_holders_allowed_status
  @multiple_devices_and_holders_allowed_status
end

#notify_preferenceString

Whether or not field updates to this class should trigger notifications. When set to NOTIFY, we will attempt to trigger a field update notification to users. These notifications will only be sent to users if the field is part of an allowlist. If not specified, no notification will be triggered. This setting is ephemeral and needs to be set with each PATCH or UPDATE request, otherwise a notification will not be triggered. Corresponds to the JSON property notifyPreference

Returns:

  • (String)


1737
1738
1739
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1737

def notify_preference
  @notify_preference
end

#redemption_issuersArray<Fixnum>

Identifies which redemption issuers can redeem the pass over Smart Tap. Redemption issuers are identified by their issuer ID. Redemption issuers must have at least one Smart Tap key configured. The enableSmartTap and object level smartTapRedemptionLevel fields must also be set up correctly in order for a pass to support Smart Tap. Corresponds to the JSON property redemptionIssuers

Returns:

  • (Array<Fixnum>)


1746
1747
1748
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1746

def redemption_issuers
  @redemption_issuers
end

#reviewGoogle::Apis::WalletobjectsV1::Review

The review comments set by the platform when a class is marked approved or rejected. Corresponds to the JSON property review



1752
1753
1754
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1752

def review
  @review
end

#review_statusString

Required. The status of the class. This field can be set to draft or underReview using the insert, patch, or update API calls. Once the review state is changed from draft it may not be changed back to draft. You should keep this field to draft when the class is under development. A draft class cannot be used to create any object. You should set this field to underReview when you believe the class is ready for use. The platform will automatically set this field to approved and it can be immediately used to create or migrate objects. When updating an already approved class you should keep setting this field to underReview. Corresponds to the JSON property reviewStatus

Returns:

  • (String)


1765
1766
1767
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1765

def review_status
  @review_status
end

#row_labelString

The label to use for the row value (eventTicketObject.seatInfo.row) on the card detail view. Each available option maps to a set of localized strings, so that translations are shown to the user based on their locale. Both rowLabel and customRowLabel may not be set. If neither is set, the label will default to "Row", localized. If the row field is unset, this label will not be used. Corresponds to the JSON property rowLabel

Returns:

  • (String)


1774
1775
1776
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1774

def row_label
  @row_label
end

#seat_labelString

The label to use for the seat value (eventTicketObject.seatInfo.seat) on the card detail view. Each available option maps to a set of localized strings, so that translations are shown to the user based on their locale. Both seatLabel and customSeatLabel may not be set. If neither is set, the label will default to "Seat", localized. If the seat field is unset, this label will not be used. Corresponds to the JSON property seatLabel

Returns:

  • (String)


1784
1785
1786
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1784

def seat_label
  @seat_label
end

#section_labelString

The label to use for the section value (eventTicketObject.seatInfo.section) on the card detail view. Each available option maps to a set of localized strings, so that translations are shown to the user based on their locale. Both sectionLabel and customSectionLabel may not be set. If neither is set, the label will default to "Section", localized. If the section field is unset, this label will not be used. Corresponds to the JSON property sectionLabel

Returns:

  • (String)


1794
1795
1796
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1794

def 
  @section_label
end

#security_animationGoogle::Apis::WalletobjectsV1::SecurityAnimation

Optional information about the security animation. If this is set a security animation will be rendered on pass details. Corresponds to the JSON property securityAnimation



1800
1801
1802
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1800

def security_animation
  @security_animation
end

#text_modules_dataArray<Google::Apis::WalletobjectsV1::TextModuleData>

Text module data. If text module data is also defined on the class, both will be displayed. The maximum number of these fields displayed is 10 from the object and 10 from the class. Corresponds to the JSON property textModulesData



1807
1808
1809
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1807

def text_modules_data
  @text_modules_data
end

#value_added_module_dataArray<Google::Apis::WalletobjectsV1::ValueAddedModuleData>

Optional value added module data. Maximum of fifteen on the class. For a pass only fifteen will be displayed, prioritizing those from the object. Corresponds to the JSON property valueAddedModuleData



1813
1814
1815
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1813

def value_added_module_data
  @value_added_module_data
end

#venueGoogle::Apis::WalletobjectsV1::EventVenue

Event venue details. Corresponds to the JSON property venue



1818
1819
1820
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1818

def venue
  @venue
end

#versionFixnum

Deprecated Corresponds to the JSON property version

Returns:

  • (Fixnum)


1823
1824
1825
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1823

def version
  @version
end

#view_unlock_requirementString

View Unlock Requirement options for the event ticket. Corresponds to the JSON property viewUnlockRequirement

Returns:

  • (String)


1828
1829
1830
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1828

def view_unlock_requirement
  @view_unlock_requirement
end

#wide_logoGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property wideLogo



1833
1834
1835
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1833

def 
  @wide_logo
end

#word_markGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property wordMark



1838
1839
1840
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1838

def word_mark
  @word_mark
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



1845
1846
1847
1848
1849
1850
1851
1852
1853
1854
1855
1856
1857
1858
1859
1860
1861
1862
1863
1864
1865
1866
1867
1868
1869
1870
1871
1872
1873
1874
1875
1876
1877
1878
1879
1880
1881
1882
1883
1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1845

def update!(**args)
  @allow_multiple_users_per_object = args[:allow_multiple_users_per_object] if args.key?(:allow_multiple_users_per_object)
  @app_link_data = args[:app_link_data] if args.key?(:app_link_data)
  @callback_options = args[:callback_options] if args.key?(:callback_options)
  @class_template_info = args[:class_template_info] if args.key?(:class_template_info)
  @confirmation_code_label = args[:confirmation_code_label] if args.key?(:confirmation_code_label)
  @country_code = args[:country_code] if args.key?(:country_code)
  @custom_confirmation_code_label = args[:custom_confirmation_code_label] if args.key?(:custom_confirmation_code_label)
  @custom_gate_label = args[:custom_gate_label] if args.key?(:custom_gate_label)
  @custom_row_label = args[:custom_row_label] if args.key?(:custom_row_label)
  @custom_seat_label = args[:custom_seat_label] if args.key?(:custom_seat_label)
  @custom_section_label = args[:custom_section_label] if args.key?(:custom_section_label)
  @date_time = args[:date_time] if args.key?(:date_time)
  @enable_smart_tap = args[:enable_smart_tap] if args.key?(:enable_smart_tap)
  @event_id = args[:event_id] if args.key?(:event_id)
  @event_name = args[:event_name] if args.key?(:event_name)
  @fine_print = args[:fine_print] if args.key?(:fine_print)
  @gate_label = args[:gate_label] if args.key?(:gate_label)
  @hero_image = args[:hero_image] if args.key?(:hero_image)
  @hex_background_color = args[:hex_background_color] if args.key?(:hex_background_color)
  @homepage_uri = args[:homepage_uri] if args.key?(:homepage_uri)
  @id = args[:id] if args.key?(:id)
  @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data)
  @info_module_data = args[:info_module_data] if args.key?(:info_module_data)
  @issuer_name = args[:issuer_name] if args.key?(:issuer_name)
  @kind = args[:kind] if args.key?(:kind)
  @links_module_data = args[:links_module_data] if args.key?(:links_module_data)
  @localized_issuer_name = args[:localized_issuer_name] if args.key?(:localized_issuer_name)
  @locations = args[:locations] if args.key?(:locations)
  @logo = args[:logo] if args.key?(:logo)
  @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations)
  @messages = args[:messages] if args.key?(:messages)
  @multiple_devices_and_holders_allowed_status = args[:multiple_devices_and_holders_allowed_status] if args.key?(:multiple_devices_and_holders_allowed_status)
  @notify_preference = args[:notify_preference] if args.key?(:notify_preference)
  @redemption_issuers = args[:redemption_issuers] if args.key?(:redemption_issuers)
  @review = args[:review] if args.key?(:review)
  @review_status = args[:review_status] if args.key?(:review_status)
  @row_label = args[:row_label] if args.key?(:row_label)
  @seat_label = args[:seat_label] if args.key?(:seat_label)
  @section_label = args[:section_label] if args.key?(:section_label)
  @security_animation = args[:security_animation] if args.key?(:security_animation)
  @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data)
  @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data)
  @venue = args[:venue] if args.key?(:venue)
  @version = args[:version] if args.key?(:version)
  @view_unlock_requirement = args[:view_unlock_requirement] if args.key?(:view_unlock_requirement)
  @wide_logo = args[:wide_logo] if args.key?(:wide_logo)
  @word_mark = args[:word_mark] if args.key?(:word_mark)
end