Class: Google::Apis::WalletobjectsV1::EventTicketObject
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::EventTicketObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front of the pass.
-
#barcode ⇒ Google::Apis::WalletobjectsV1::Barcode
The barcode type and value.
-
#class_id ⇒ String
Required.
-
#class_reference ⇒ Google::Apis::WalletobjectsV1::EventTicketClass
A copy of the inherited fields of the parent class.
-
#disable_expiration_notification ⇒ Boolean
(also: #disable_expiration_notification?)
Indicates if notifications should explicitly be suppressed.
-
#face_value ⇒ Google::Apis::WalletobjectsV1::Money
The face value of the ticket, matching what would be printed on a physical version of the ticket.
-
#grouping_info ⇒ Google::Apis::WalletobjectsV1::GroupingInfo
Information that controls how passes are grouped together.
-
#has_linked_device ⇒ Boolean
(also: #has_linked_device?)
Whether this object is currently linked to a single device.
-
#has_users ⇒ Boolean
(also: #has_users?)
Indicates if the object has users.
-
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#hex_background_color ⇒ String
The background color for the card.
-
#id ⇒ String
Required.
-
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data.
-
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#linked_object_ids ⇒ Array<String>
linked_object_ids are a list of other objects such as event ticket, loyalty, offer, generic, giftcard, transit and boarding pass that should be automatically attached to this event ticket object.
-
#linked_offer_ids ⇒ Array<String>
A list of offer objects linked to this event ticket.
-
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data.
-
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
-
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations.
-
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app.
-
#notify_preference ⇒ String
Whether or not field updates to this object should trigger notifications.
-
#pass_constraints ⇒ Google::Apis::WalletobjectsV1::PassConstraints
Container for any constraints that may be placed on passes.
-
#reservation_info ⇒ Google::Apis::WalletobjectsV1::EventReservationInfo
Reservation details for this ticket.
-
#rotating_barcode ⇒ Google::Apis::WalletobjectsV1::RotatingBarcode
The rotating barcode type and value.
-
#save_restrictions ⇒ Google::Apis::WalletobjectsV1::SaveRestrictions
Defines restrictions on the object that will be verified during save.
-
#seat_info ⇒ Google::Apis::WalletobjectsV1::EventSeat
Seating details for this ticket.
-
#smart_tap_redemption_value ⇒ String
The value that will be transmitted to a Smart Tap certified terminal over NFC for this object.
-
#state ⇒ String
Required.
-
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data.
-
#ticket_holder_name ⇒ String
Name of the ticket holder, if the ticket is assigned to a person.
-
#ticket_number ⇒ String
The number of the ticket.
-
#ticket_type ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The type of the ticket, such as "Adult" or "Child", or "VIP" or "Standard".
-
#valid_time_interval ⇒ Google::Apis::WalletobjectsV1::TimeInterval
The time period this object will be
activeand object can be used. -
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data.
-
#version ⇒ Fixnum
Deprecated Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ EventTicketObject
constructor
A new instance of EventTicketObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ EventTicketObject
Returns a new instance of EventTicketObject.
2174 2175 2176 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2174 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front
of the pass. If AppLinkData is provided for the corresponding class only
object AppLinkData will be displayed.
Corresponds to the JSON property appLinkData
1935 1936 1937 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1935 def app_link_data @app_link_data end |
#barcode ⇒ Google::Apis::WalletobjectsV1::Barcode
The barcode type and value.
Corresponds to the JSON property barcode
1940 1941 1942 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1940 def end |
#class_id ⇒ String
Required. The class associated with this object. The class must be of the same
type as this object, must already exist, and must be approved. Class IDs
should follow the format issuer ID.identifier where the former is issued by
Google and latter is chosen by you.
Corresponds to the JSON property classId
1948 1949 1950 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1948 def class_id @class_id end |
#class_reference ⇒ Google::Apis::WalletobjectsV1::EventTicketClass
A copy of the inherited fields of the parent class. These fields are retrieved
during a GET.
Corresponds to the JSON property classReference
1954 1955 1956 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1954 def class_reference @class_reference end |
#disable_expiration_notification ⇒ Boolean Also known as: disable_expiration_notification?
Indicates if notifications should explicitly be suppressed. If this field is
set to true, regardless of the messages field, expiration notifications to
the user will be suppressed. By default, this field is set to false. Currently,
this can only be set for offers.
Corresponds to the JSON property disableExpirationNotification
1962 1963 1964 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1962 def disable_expiration_notification @disable_expiration_notification end |
#face_value ⇒ Google::Apis::WalletobjectsV1::Money
The face value of the ticket, matching what would be printed on a physical
version of the ticket.
Corresponds to the JSON property faceValue
1969 1970 1971 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1969 def face_value @face_value end |
#grouping_info ⇒ Google::Apis::WalletobjectsV1::GroupingInfo
Information that controls how passes are grouped together.
Corresponds to the JSON property groupingInfo
1974 1975 1976 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1974 def grouping_info @grouping_info end |
#has_linked_device ⇒ Boolean Also known as: has_linked_device?
Whether this object is currently linked to a single device. This field is set
by the platform when a user saves the object, linking it to their device.
Intended for use by select partners. Contact support for additional
information.
Corresponds to the JSON property hasLinkedDevice
1982 1983 1984 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1982 def has_linked_device @has_linked_device end |
#has_users ⇒ Boolean Also known as: has_users?
Indicates if the object has users. This field is set by the platform.
Corresponds to the JSON property hasUsers
1988 1989 1990 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1988 def has_users @has_users end |
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property heroImage
1994 1995 1996 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 1994 def hero_image @hero_image end |
#hex_background_color ⇒ String
The background color for the card. If not set the dominant color of the hero
image is used, and if no hero image is set, the dominant color of the logo is
used. The format is #rrggbb where rrggbb is a hex RGB triplet, such as #
ffcc00. You can also use the shorthand version of the RGB triplet which is #
rgb, such as #fc0.
Corresponds to the JSON property hexBackgroundColor
2003 2004 2005 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2003 def hex_background_color @hex_background_color end |
#id ⇒ String
Required. The unique identifier for an object. This ID must be unique across
all objects from an issuer. This value should follow the format issuer ID.
identifier where the former is issued by Google and latter is chosen by you.
The unique identifier should only include alphanumeric characters, '.', '_',
or '-'.
Corresponds to the JSON property id
2012 2013 2014 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2012 def id @id end |
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data. The maximum number of these fields displayed is 1 from
object level and 1 for class object level.
Corresponds to the JSON property imageModulesData
2018 2019 2020 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2018 def image_modules_data @image_modules_data end |
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated. Use textModulesData instead.
Corresponds to the JSON property infoModuleData
2023 2024 2025 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2023 def info_module_data @info_module_data end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#eventTicketObject".
Corresponds to the JSON property kind
2029 2030 2031 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2029 def kind @kind end |
#linked_object_ids ⇒ Array<String>
linked_object_ids are a list of other objects such as event ticket, loyalty,
offer, generic, giftcard, transit and boarding pass that should be
automatically attached to this event ticket object. If a user had saved this
event ticket, then these linked_object_ids would be automatically pushed to
the user's wallet (unless they turned off the setting to receive such linked
passes). Make sure that objects present in linked_object_ids are already
inserted - if not, calls would fail. Once linked, the linked objects cannot be
unlinked. You cannot link objects belonging to another issuer. There is a
limit to the number of objects that can be linked to a single object. After
the limit is reached, new linked objects in the call will be ignored silently.
Object IDs should follow the format issuer ID. identifier where the former is
issued by Google and the latter is chosen by you.
Corresponds to the JSON property linkedObjectIds
2045 2046 2047 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2045 def linked_object_ids @linked_object_ids end |
#linked_offer_ids ⇒ Array<String>
A list of offer objects linked to this event ticket. The offer objects must
already exist. Offer object IDs should follow the format issuer ID. identifier
where the former is issued by Google and latter is chosen by you.
Corresponds to the JSON property linkedOfferIds
2052 2053 2054 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2052 def linked_offer_ids @linked_offer_ids end |
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data. If links module data is also defined on the class, both
will be displayed.
Corresponds to the JSON property linksModuleData
2058 2059 2060 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2058 def links_module_data @links_module_data end |
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
Corresponds to the JSON property locations
2063 2064 2065 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2063 def locations @locations end |
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations. There is a maximum of ten on the object. Any additional
MerchantLocations added beyond the 10 will be rejected. These locations will
trigger a notification when a user enters within a Google-set radius of the
point. This field replaces the deprecated LatLongPoints.
Corresponds to the JSON property merchantLocations
2071 2072 2073 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2071 def merchant_locations @merchant_locations end |
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app. All users of this object will
receive its associated messages. The maximum number of these fields is 10.
Corresponds to the JSON property messages
2077 2078 2079 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2077 def end |
#notify_preference ⇒ String
Whether or not field updates to this object should trigger notifications. When
set to NOTIFY, we will attempt to trigger a field update notification to users.
These notifications will only be sent to users if the field is part of an
allowlist. If set to DO_NOT_NOTIFY or NOTIFICATION_SETTINGS_UNSPECIFIED, no
notification will be triggered. This setting is ephemeral and needs to be set
with each PATCH or UPDATE request, otherwise a notification will not be
triggered.
Corresponds to the JSON property notifyPreference
2088 2089 2090 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2088 def notify_preference @notify_preference end |
#pass_constraints ⇒ Google::Apis::WalletobjectsV1::PassConstraints
Container for any constraints that may be placed on passes.
Corresponds to the JSON property passConstraints
2093 2094 2095 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2093 def pass_constraints @pass_constraints end |
#reservation_info ⇒ Google::Apis::WalletobjectsV1::EventReservationInfo
Reservation details for this ticket. This is expected to be shared amongst all
tickets that were purchased in the same order.
Corresponds to the JSON property reservationInfo
2099 2100 2101 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2099 def reservation_info @reservation_info end |
#rotating_barcode ⇒ Google::Apis::WalletobjectsV1::RotatingBarcode
The rotating barcode type and value.
Corresponds to the JSON property rotatingBarcode
2104 2105 2106 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2104 def end |
#save_restrictions ⇒ Google::Apis::WalletobjectsV1::SaveRestrictions
Defines restrictions on the object that will be verified during save. Note:
this is an advanced feature, please contact Google for implementation support.
Corresponds to the JSON property saveRestrictions
2110 2111 2112 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2110 def save_restrictions @save_restrictions end |
#seat_info ⇒ Google::Apis::WalletobjectsV1::EventSeat
Seating details for this ticket.
Corresponds to the JSON property seatInfo
2115 2116 2117 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2115 def seat_info @seat_info end |
#smart_tap_redemption_value ⇒ String
The value that will be transmitted to a Smart Tap certified terminal over NFC
for this object. The class level fields enableSmartTap and
redemptionIssuers must also be set up correctly in order for the pass to
support Smart Tap. Only ASCII characters are supported.
Corresponds to the JSON property smartTapRedemptionValue
2123 2124 2125 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2123 def smart_tap_redemption_value @smart_tap_redemption_value end |
#state ⇒ String
Required. The state of the object. This field is used to determine how an
object is displayed in the app. For example, an inactive object is moved to
the "Expired passes" section.
Corresponds to the JSON property state
2130 2131 2132 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2130 def state @state end |
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data. If text module data is also defined on the class, both will
be displayed. The maximum number of these fields displayed is 10 from the
object and 10 from the class.
Corresponds to the JSON property textModulesData
2137 2138 2139 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2137 def text_modules_data @text_modules_data end |
#ticket_holder_name ⇒ String
Name of the ticket holder, if the ticket is assigned to a person. E.g. "John
Doe" or "Jane Doe".
Corresponds to the JSON property ticketHolderName
2143 2144 2145 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2143 def ticket_holder_name @ticket_holder_name end |
#ticket_number ⇒ String
The number of the ticket. This can be a unique identifier across all tickets
in an issuer's system, all tickets for the event (e.g. XYZ1234512345), or all
tickets in the order (1, 2, 3, etc.).
Corresponds to the JSON property ticketNumber
2150 2151 2152 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2150 def ticket_number @ticket_number end |
#ticket_type ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The type of the ticket, such as "Adult" or "Child", or "VIP" or "Standard".
Corresponds to the JSON property ticketType
2155 2156 2157 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2155 def ticket_type @ticket_type end |
#valid_time_interval ⇒ Google::Apis::WalletobjectsV1::TimeInterval
The time period this object will be active and object can be used. An object'
s state will be changed to expired when this time period has passed.
Corresponds to the JSON property validTimeInterval
2161 2162 2163 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2161 def valid_time_interval @valid_time_interval end |
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data. Maximum of fifteen on the object. For a pass
only fifteen will be displayed.
Corresponds to the JSON property valueAddedModuleData
2167 2168 2169 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2167 def value_added_module_data @value_added_module_data end |
#version ⇒ Fixnum
Deprecated
Corresponds to the JSON property version
2172 2173 2174 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2172 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2179 2180 2181 2182 2183 2184 2185 2186 2187 2188 2189 2190 2191 2192 2193 2194 2195 2196 2197 2198 2199 2200 2201 2202 2203 2204 2205 2206 2207 2208 2209 2210 2211 2212 2213 2214 2215 2216 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2179 def update!(**args) @app_link_data = args[:app_link_data] if args.key?(:app_link_data) = args[:barcode] if args.key?(:barcode) @class_id = args[:class_id] if args.key?(:class_id) @class_reference = args[:class_reference] if args.key?(:class_reference) @disable_expiration_notification = args[:disable_expiration_notification] if args.key?(:disable_expiration_notification) @face_value = args[:face_value] if args.key?(:face_value) @grouping_info = args[:grouping_info] if args.key?(:grouping_info) @has_linked_device = args[:has_linked_device] if args.key?(:has_linked_device) @has_users = args[:has_users] if args.key?(:has_users) @hero_image = args[:hero_image] if args.key?(:hero_image) @hex_background_color = args[:hex_background_color] if args.key?(:hex_background_color) @id = args[:id] if args.key?(:id) @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data) @info_module_data = args[:info_module_data] if args.key?(:info_module_data) @kind = args[:kind] if args.key?(:kind) @linked_object_ids = args[:linked_object_ids] if args.key?(:linked_object_ids) @linked_offer_ids = args[:linked_offer_ids] if args.key?(:linked_offer_ids) @links_module_data = args[:links_module_data] if args.key?(:links_module_data) @locations = args[:locations] if args.key?(:locations) @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations) = args[:messages] if args.key?(:messages) @notify_preference = args[:notify_preference] if args.key?(:notify_preference) @pass_constraints = args[:pass_constraints] if args.key?(:pass_constraints) @reservation_info = args[:reservation_info] if args.key?(:reservation_info) = args[:rotating_barcode] if args.key?(:rotating_barcode) @save_restrictions = args[:save_restrictions] if args.key?(:save_restrictions) @seat_info = args[:seat_info] if args.key?(:seat_info) @smart_tap_redemption_value = args[:smart_tap_redemption_value] if args.key?(:smart_tap_redemption_value) @state = args[:state] if args.key?(:state) @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data) @ticket_holder_name = args[:ticket_holder_name] if args.key?(:ticket_holder_name) @ticket_number = args[:ticket_number] if args.key?(:ticket_number) @ticket_type = args[:ticket_type] if args.key?(:ticket_type) @valid_time_interval = args[:valid_time_interval] if args.key?(:valid_time_interval) @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data) @version = args[:version] if args.key?(:version) end |