Class: Google::Apis::WalletobjectsV1::FlightClass
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::FlightClass
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#allow_multiple_users_per_object ⇒ Boolean
(also: #allow_multiple_users_per_object?)
Deprecated.
-
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front of the pass.
-
#boarding_and_seating_policy ⇒ Google::Apis::WalletobjectsV1::BoardingAndSeatingPolicy
Policies for boarding and seating.
-
#callback_options ⇒ Google::Apis::WalletobjectsV1::CallbackOptions
Callback options to be used to call the issuer back for every save/delete of an object for this class by the end-user.
-
#class_template_info ⇒ Google::Apis::WalletobjectsV1::ClassTemplateInfo
Template information about how the class should be displayed.
-
#country_code ⇒ String
Country code used to display the card's country (when the user is not in that country), as well as to display localized content when content is not available in the user's locale.
-
#destination ⇒ Google::Apis::WalletobjectsV1::AirportInfo
Required.
-
#enable_smart_tap ⇒ Boolean
(also: #enable_smart_tap?)
Identifies whether this class supports Smart Tap.
-
#flight_header ⇒ Google::Apis::WalletobjectsV1::FlightHeader
Required.
-
#flight_status ⇒ String
Status of this flight.
-
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#hex_background_color ⇒ String
The background color for the card.
-
#homepage_uri ⇒ Google::Apis::WalletobjectsV1::Uri
The URI of your application's home page.
-
#id ⇒ String
Required.
-
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data.
-
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated.
-
#issuer_name ⇒ String
Required.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#language_override ⇒ String
If this field is present, boarding passes served to a user's device will always be in this language.
-
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data.
-
#local_boarding_date_time ⇒ String
The boarding time as it would be printed on the boarding pass.
-
#local_estimated_or_actual_arrival_date_time ⇒ String
The estimated time the aircraft plans to reach the destination gate (not the runway) or the actual time it reached the gate.
-
#local_estimated_or_actual_departure_date_time ⇒ String
The estimated time the aircraft plans to pull from the gate or the actual time the aircraft already pulled from the gate.
-
#local_gate_closing_date_time ⇒ String
The gate closing time as it would be printed on the boarding pass.
-
#local_scheduled_arrival_date_time ⇒ String
The scheduled time the aircraft plans to reach the destination gate (not the runway).
-
#local_scheduled_departure_date_time ⇒ String
Required.
-
#localized_issuer_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the issuer_name.
-
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
-
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations.
-
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app.
-
#multiple_devices_and_holders_allowed_status ⇒ String
Identifies whether multiple users and devices will save the same object referencing this class.
-
#notify_preference ⇒ String
Whether or not field updates to this class should trigger notifications.
-
#origin ⇒ Google::Apis::WalletobjectsV1::AirportInfo
Required.
-
#redemption_issuers ⇒ Array<Fixnum>
Identifies which redemption issuers can redeem the pass over Smart Tap.
-
#review ⇒ Google::Apis::WalletobjectsV1::Review
The review comments set by the platform when a class is marked
approvedorrejected. -
#review_status ⇒ String
Required.
-
#security_animation ⇒ Google::Apis::WalletobjectsV1::SecurityAnimation
Optional information about the security animation.
-
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data.
-
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data.
-
#version ⇒ Fixnum
Deprecated Corresponds to the JSON property
version. -
#view_unlock_requirement ⇒ String
View Unlock Requirement options for the boarding pass.
-
#word_mark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Instance Method Summary collapse
-
#initialize(**args) ⇒ FlightClass
constructor
A new instance of FlightClass.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ FlightClass
Returns a new instance of FlightClass.
2783 2784 2785 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2783 def initialize(**args) update!(**args) end |
Instance Attribute Details
#allow_multiple_users_per_object ⇒ Boolean Also known as: allow_multiple_users_per_object?
Deprecated. Use multipleDevicesAndHoldersAllowedStatus instead.
Corresponds to the JSON property allowMultipleUsersPerObject
2474 2475 2476 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2474 def allow_multiple_users_per_object @allow_multiple_users_per_object end |
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front
of the pass. If AppLinkData is provided for the corresponding object that will
be used instead.
Corresponds to the JSON property appLinkData
2482 2483 2484 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2482 def app_link_data @app_link_data end |
#boarding_and_seating_policy ⇒ Google::Apis::WalletobjectsV1::BoardingAndSeatingPolicy
Policies for boarding and seating. These will inform which labels will be
shown to users.
Corresponds to the JSON property boardingAndSeatingPolicy
2488 2489 2490 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2488 def boarding_and_seating_policy @boarding_and_seating_policy end |
#callback_options ⇒ Google::Apis::WalletobjectsV1::CallbackOptions
Callback options to be used to call the issuer back for every save/delete of
an object for this class by the end-user. All objects of this class are
eligible for the callback.
Corresponds to the JSON property callbackOptions
2495 2496 2497 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2495 def @callback_options end |
#class_template_info ⇒ Google::Apis::WalletobjectsV1::ClassTemplateInfo
Template information about how the class should be displayed. If unset, Google
will fallback to a default set of fields to display.
Corresponds to the JSON property classTemplateInfo
2501 2502 2503 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2501 def class_template_info @class_template_info end |
#country_code ⇒ String
Country code used to display the card's country (when the user is not in that
country), as well as to display localized content when content is not
available in the user's locale.
Corresponds to the JSON property countryCode
2508 2509 2510 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2508 def country_code @country_code end |
#destination ⇒ Google::Apis::WalletobjectsV1::AirportInfo
Required. Destination airport.
Corresponds to the JSON property destination
2513 2514 2515 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2513 def destination @destination end |
#enable_smart_tap ⇒ Boolean Also known as: enable_smart_tap?
Identifies whether this class supports Smart Tap. The redemptionIssuers and
object level smartTapRedemptionLevel fields must also be set up correctly in
order for a pass to support Smart Tap.
Corresponds to the JSON property enableSmartTap
2520 2521 2522 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2520 def enable_smart_tap @enable_smart_tap end |
#flight_header ⇒ Google::Apis::WalletobjectsV1::FlightHeader
Required. Information about the flight carrier and number.
Corresponds to the JSON property flightHeader
2526 2527 2528 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2526 def flight_header @flight_header end |
#flight_status ⇒ String
Status of this flight. If unset, Google will compute status based on data from
other sources, such as FlightStats, etc. Note: Google-computed status will not
be returned in API responses.
Corresponds to the JSON property flightStatus
2533 2534 2535 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2533 def flight_status @flight_status end |
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property heroImage
2538 2539 2540 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2538 def hero_image @hero_image end |
#hex_background_color ⇒ String
The background color for the card. If not set the dominant color of the hero
image is used, and if no hero image is set, the dominant color of the logo is
used. The format is #rrggbb where rrggbb is a hex RGB triplet, such as #
ffcc00. You can also use the shorthand version of the RGB triplet which is #
rgb, such as #fc0.
Corresponds to the JSON property hexBackgroundColor
2547 2548 2549 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2547 def hex_background_color @hex_background_color end |
#homepage_uri ⇒ Google::Apis::WalletobjectsV1::Uri
The URI of your application's home page. Populating the URI in this field
results in the exact same behavior as populating an URI in linksModuleData (
when an object is rendered, a link to the homepage is shown in what would
usually be thought of as the linksModuleData section of the object).
Corresponds to the JSON property homepageUri
2555 2556 2557 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2555 def homepage_uri @homepage_uri end |
#id ⇒ String
Required. The unique identifier for a class. This ID must be unique across all
classes from an issuer. This value should follow the format issuer ID.
identifier where the former is issued by Google and latter is chosen by you.
Your unique identifier should only include alphanumeric characters, '.', '_',
or '-'.
Corresponds to the JSON property id
2564 2565 2566 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2564 def id @id end |
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data. The maximum number of these fields displayed is 1 from
object level and 1 for class object level.
Corresponds to the JSON property imageModulesData
2570 2571 2572 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2570 def image_modules_data @image_modules_data end |
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated. Use textModulesData instead.
Corresponds to the JSON property infoModuleData
2575 2576 2577 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2575 def info_module_data @info_module_data end |
#issuer_name ⇒ String
Required. The issuer name. Recommended maximum length is 20 characters to
ensure full string is displayed on smaller screens.
Corresponds to the JSON property issuerName
2581 2582 2583 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2581 def issuer_name @issuer_name end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#flightClass".
Corresponds to the JSON property kind
2587 2588 2589 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2587 def kind @kind end |
#language_override ⇒ String
If this field is present, boarding passes served to a user's device will
always be in this language. Represents the BCP 47 language tag. Example values
are "en-US", "en-GB", "de", or "de-AT".
Corresponds to the JSON property languageOverride
2594 2595 2596 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2594 def language_override @language_override end |
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data. If links module data is also defined on the object, both
will be displayed.
Corresponds to the JSON property linksModuleData
2600 2601 2602 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2600 def links_module_data @links_module_data end |
#local_boarding_date_time ⇒ String
The boarding time as it would be printed on the boarding pass. This is an ISO
8601 extended format date/time without an offset. Time may be specified up to
millisecond precision. eg: 2027-03-05T06:30:00 This should be the local date/
time at the airport (not a UTC time). Google will reject the request if UTC
offset is provided. Time zones will be calculated by Google based on departure
airport.
Corresponds to the JSON property localBoardingDateTime
2610 2611 2612 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2610 def local_boarding_date_time @local_boarding_date_time end |
#local_estimated_or_actual_arrival_date_time ⇒ String
The estimated time the aircraft plans to reach the destination gate (not the
runway) or the actual time it reached the gate. This field should be set if at
least one of the below is true: - It differs from the scheduled time. Google
will use it to calculate the delay. - The aircraft already arrived at the gate.
Google will use it to inform the user that the flight has arrived at the gate.
This is an ISO 8601 extended format date/time without an offset. Time may be
specified up to millisecond precision. eg: 2027-03-05T06:30:00 This should
be the local date/time at the airport (not a UTC time). Google will reject the
request if UTC offset is provided. Time zones will be calculated by Google
based on arrival airport.
Corresponds to the JSON property localEstimatedOrActualArrivalDateTime
2624 2625 2626 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2624 def local_estimated_or_actual_arrival_date_time @local_estimated_or_actual_arrival_date_time end |
#local_estimated_or_actual_departure_date_time ⇒ String
The estimated time the aircraft plans to pull from the gate or the actual time
the aircraft already pulled from the gate. Note: This is not the runway time.
This field should be set if at least one of the below is true: - It differs
from the scheduled time. Google will use it to calculate the delay. - The
aircraft already pulled from the gate. Google will use it to inform the user
when the flight actually departed. This is an ISO 8601 extended format date/
time without an offset. Time may be specified up to millisecond precision. eg:
2027-03-05T06:30:00 This should be the local date/time at the airport (not a
UTC time). Google will reject the request if UTC offset is provided. Time
zones will be calculated by Google based on departure airport.
Corresponds to the JSON property localEstimatedOrActualDepartureDateTime
2638 2639 2640 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2638 def local_estimated_or_actual_departure_date_time @local_estimated_or_actual_departure_date_time end |
#local_gate_closing_date_time ⇒ String
The gate closing time as it would be printed on the boarding pass. Do not set
this field if you do not want to print it in the boarding pass. This is an ISO
8601 extended format date/time without an offset. Time may be specified up to
millisecond precision. eg: 2027-03-05T06:30:00 This should be the local date/
time at the airport (not a UTC time). Google will reject the request if UTC
offset is provided. Time zones will be calculated by Google based on departure
airport.
Corresponds to the JSON property localGateClosingDateTime
2649 2650 2651 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2649 def local_gate_closing_date_time @local_gate_closing_date_time end |
#local_scheduled_arrival_date_time ⇒ String
The scheduled time the aircraft plans to reach the destination gate (not the
runway). Note: This field should not change too close to the flight time. For
updates to departure times (delays, etc), please set
localEstimatedOrActualArrivalDateTime. This is an ISO 8601 extended format
date/time without an offset. Time may be specified up to millisecond precision.
eg: 2027-03-05T06:30:00 This should be the local date/time at the airport (
not a UTC time). Google will reject the request if UTC offset is provided.
Time zones will be calculated by Google based on arrival airport.
Corresponds to the JSON property localScheduledArrivalDateTime
2661 2662 2663 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2661 def local_scheduled_arrival_date_time @local_scheduled_arrival_date_time end |
#local_scheduled_departure_date_time ⇒ String
Required. The scheduled date and time when the aircraft is expected to depart
the gate (not the runway) Note: This field should not change too close to the
departure time. For updates to departure times (delays, etc), please set
localEstimatedOrActualDepartureDateTime. This is an ISO 8601 extended format
date/time without an offset. Time may be specified up to millisecond precision.
eg: 2027-03-05T06:30:00 This should be the local date/time at the airport (
not a UTC time). Google will reject the request if UTC offset is provided.
Time zones will be calculated by Google based on departure airport.
Corresponds to the JSON property localScheduledDepartureDateTime
2673 2674 2675 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2673 def local_scheduled_departure_date_time @local_scheduled_departure_date_time end |
#localized_issuer_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the issuer_name. Recommended maximum length is 20
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedIssuerName
2679 2680 2681 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2679 def localized_issuer_name @localized_issuer_name end |
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
Corresponds to the JSON property locations
2684 2685 2686 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2684 def locations @locations end |
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations. There is a maximum of ten on the class. Any additional
MerchantLocations added beyond the 10 will be rejected by the validator. These
locations will trigger a notification when a user enters within a Google-set
radius of the point. This field replaces the deprecated LatLongPoints.
Corresponds to the JSON property merchantLocations
2692 2693 2694 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2692 def merchant_locations @merchant_locations end |
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app. All users of this object will
receive its associated messages. The maximum number of these fields is 10.
Corresponds to the JSON property messages
2698 2699 2700 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2698 def @messages end |
#multiple_devices_and_holders_allowed_status ⇒ String
Identifies whether multiple users and devices will save the same object
referencing this class.
Corresponds to the JSON property multipleDevicesAndHoldersAllowedStatus
2704 2705 2706 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2704 def multiple_devices_and_holders_allowed_status @multiple_devices_and_holders_allowed_status end |
#notify_preference ⇒ String
Whether or not field updates to this class should trigger notifications. When
set to NOTIFY, we will attempt to trigger a field update notification to users.
These notifications will only be sent to users if the field is part of an
allowlist. If not specified, no notification will be triggered. This setting
is ephemeral and needs to be set with each PATCH or UPDATE request, otherwise
a notification will not be triggered.
Corresponds to the JSON property notifyPreference
2714 2715 2716 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2714 def notify_preference @notify_preference end |
#origin ⇒ Google::Apis::WalletobjectsV1::AirportInfo
Required. Origin airport.
Corresponds to the JSON property origin
2719 2720 2721 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2719 def origin @origin end |
#redemption_issuers ⇒ Array<Fixnum>
Identifies which redemption issuers can redeem the pass over Smart Tap.
Redemption issuers are identified by their issuer ID. Redemption issuers must
have at least one Smart Tap key configured. The enableSmartTap and object
level smartTapRedemptionLevel fields must also be set up correctly in order
for a pass to support Smart Tap.
Corresponds to the JSON property redemptionIssuers
2728 2729 2730 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2728 def redemption_issuers @redemption_issuers end |
#review ⇒ Google::Apis::WalletobjectsV1::Review
The review comments set by the platform when a class is marked approved or
rejected.
Corresponds to the JSON property review
2734 2735 2736 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2734 def review @review end |
#review_status ⇒ String
Required. The status of the class. This field can be set to draft or
underReview using the insert, patch, or update API calls. Once the review
state is changed from draft it may not be changed back to draft. You
should keep this field to draft when the class is under development. A
draft class cannot be used to create any object. You should set this field to
underReview when you believe the class is ready for use. The platform will
automatically set this field to approved and it can be immediately used to
create or migrate objects. When updating an already approved class you
should keep setting this field to underReview.
Corresponds to the JSON property reviewStatus
2747 2748 2749 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2747 def review_status @review_status end |
#security_animation ⇒ Google::Apis::WalletobjectsV1::SecurityAnimation
Optional information about the security animation. If this is set a security
animation will be rendered on pass details.
Corresponds to the JSON property securityAnimation
2753 2754 2755 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2753 def security_animation @security_animation end |
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data. If text module data is also defined on the class, both will
be displayed. The maximum number of these fields displayed is 10 from the
object and 10 from the class.
Corresponds to the JSON property textModulesData
2760 2761 2762 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2760 def text_modules_data @text_modules_data end |
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data. Maximum of fifteen on the class. For a pass
only fifteen will be displayed, prioritizing those from the object.
Corresponds to the JSON property valueAddedModuleData
2766 2767 2768 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2766 def value_added_module_data @value_added_module_data end |
#version ⇒ Fixnum
Deprecated
Corresponds to the JSON property version
2771 2772 2773 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2771 def version @version end |
#view_unlock_requirement ⇒ String
View Unlock Requirement options for the boarding pass.
Corresponds to the JSON property viewUnlockRequirement
2776 2777 2778 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2776 def view_unlock_requirement @view_unlock_requirement end |
#word_mark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property wordMark
2781 2782 2783 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2781 def word_mark @word_mark end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
2788 2789 2790 2791 2792 2793 2794 2795 2796 2797 2798 2799 2800 2801 2802 2803 2804 2805 2806 2807 2808 2809 2810 2811 2812 2813 2814 2815 2816 2817 2818 2819 2820 2821 2822 2823 2824 2825 2826 2827 2828 2829 2830 2831 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 2788 def update!(**args) @allow_multiple_users_per_object = args[:allow_multiple_users_per_object] if args.key?(:allow_multiple_users_per_object) @app_link_data = args[:app_link_data] if args.key?(:app_link_data) @boarding_and_seating_policy = args[:boarding_and_seating_policy] if args.key?(:boarding_and_seating_policy) @callback_options = args[:callback_options] if args.key?(:callback_options) @class_template_info = args[:class_template_info] if args.key?(:class_template_info) @country_code = args[:country_code] if args.key?(:country_code) @destination = args[:destination] if args.key?(:destination) @enable_smart_tap = args[:enable_smart_tap] if args.key?(:enable_smart_tap) @flight_header = args[:flight_header] if args.key?(:flight_header) @flight_status = args[:flight_status] if args.key?(:flight_status) @hero_image = args[:hero_image] if args.key?(:hero_image) @hex_background_color = args[:hex_background_color] if args.key?(:hex_background_color) @homepage_uri = args[:homepage_uri] if args.key?(:homepage_uri) @id = args[:id] if args.key?(:id) @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data) @info_module_data = args[:info_module_data] if args.key?(:info_module_data) @issuer_name = args[:issuer_name] if args.key?(:issuer_name) @kind = args[:kind] if args.key?(:kind) @language_override = args[:language_override] if args.key?(:language_override) @links_module_data = args[:links_module_data] if args.key?(:links_module_data) @local_boarding_date_time = args[:local_boarding_date_time] if args.key?(:local_boarding_date_time) @local_estimated_or_actual_arrival_date_time = args[:local_estimated_or_actual_arrival_date_time] if args.key?(:local_estimated_or_actual_arrival_date_time) @local_estimated_or_actual_departure_date_time = args[:local_estimated_or_actual_departure_date_time] if args.key?(:local_estimated_or_actual_departure_date_time) @local_gate_closing_date_time = args[:local_gate_closing_date_time] if args.key?(:local_gate_closing_date_time) @local_scheduled_arrival_date_time = args[:local_scheduled_arrival_date_time] if args.key?(:local_scheduled_arrival_date_time) @local_scheduled_departure_date_time = args[:local_scheduled_departure_date_time] if args.key?(:local_scheduled_departure_date_time) @localized_issuer_name = args[:localized_issuer_name] if args.key?(:localized_issuer_name) @locations = args[:locations] if args.key?(:locations) @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations) @messages = args[:messages] if args.key?(:messages) @multiple_devices_and_holders_allowed_status = args[:multiple_devices_and_holders_allowed_status] if args.key?(:multiple_devices_and_holders_allowed_status) @notify_preference = args[:notify_preference] if args.key?(:notify_preference) @origin = args[:origin] if args.key?(:origin) @redemption_issuers = args[:redemption_issuers] if args.key?(:redemption_issuers) @review = args[:review] if args.key?(:review) @review_status = args[:review_status] if args.key?(:review_status) @security_animation = args[:security_animation] if args.key?(:security_animation) @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data) @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data) @version = args[:version] if args.key?(:version) @view_unlock_requirement = args[:view_unlock_requirement] if args.key?(:view_unlock_requirement) @word_mark = args[:word_mark] if args.key?(:word_mark) end |