Class: Google::Apis::WalletobjectsV1::GiftCardObject
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::GiftCardObject
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front of the pass.
-
#balance ⇒ Google::Apis::WalletobjectsV1::Money
The card's monetary balance.
-
#balance_update_time ⇒ Google::Apis::WalletobjectsV1::DateTime
The date and time when the balance was last updated.
-
#barcode ⇒ Google::Apis::WalletobjectsV1::Barcode
The barcode type and value.
-
#card_number ⇒ String
Required.
-
#class_id ⇒ String
Required.
-
#class_reference ⇒ Google::Apis::WalletobjectsV1::GiftCardClass
A copy of the inherited fields of the parent class.
-
#disable_expiration_notification ⇒ Boolean
(also: #disable_expiration_notification?)
Indicates if notifications should explicitly be suppressed.
-
#event_number ⇒ String
The card's event number, an optional field used by some gift cards.
-
#grouping_info ⇒ Google::Apis::WalletobjectsV1::GroupingInfo
Information that controls how passes are grouped together.
-
#has_linked_device ⇒ Boolean
(also: #has_linked_device?)
Whether this object is currently linked to a single device.
-
#has_users ⇒ Boolean
(also: #has_users?)
Indicates if the object has users.
-
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#id ⇒ String
Required.
-
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data.
-
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#linked_object_ids ⇒ Array<String>
linked_object_ids are a list of other objects such as event ticket, loyalty, offer, generic, giftcard, transit and boarding pass that should be automatically attached to this giftcard object.
-
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data.
-
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
-
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations.
-
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app.
-
#notify_preference ⇒ String
Whether or not field updates to this object should trigger notifications.
-
#pass_constraints ⇒ Google::Apis::WalletobjectsV1::PassConstraints
Container for any constraints that may be placed on passes.
-
#pin ⇒ String
The card's PIN.
-
#rotating_barcode ⇒ Google::Apis::WalletobjectsV1::RotatingBarcode
The rotating barcode type and value.
-
#save_restrictions ⇒ Google::Apis::WalletobjectsV1::SaveRestrictions
Defines restrictions on the object that will be verified during save.
-
#smart_tap_redemption_value ⇒ String
The value that will be transmitted to a Smart Tap certified terminal over NFC for this object.
-
#state ⇒ String
Required.
-
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data.
-
#valid_time_interval ⇒ Google::Apis::WalletobjectsV1::TimeInterval
The time period this object will be
activeand object can be used. -
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data.
-
#version ⇒ Fixnum
Deprecated Corresponds to the JSON property
version.
Instance Method Summary collapse
-
#initialize(**args) ⇒ GiftCardObject
constructor
A new instance of GiftCardObject.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ GiftCardObject
Returns a new instance of GiftCardObject.
4321 4322 4323 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4321 def initialize(**args) update!(**args) end |
Instance Attribute Details
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front
of the pass. If AppLinkData is provided for the corresponding class only
object AppLinkData will be displayed.
Corresponds to the JSON property appLinkData
4106 4107 4108 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4106 def app_link_data @app_link_data end |
#balance ⇒ Google::Apis::WalletobjectsV1::Money
The card's monetary balance.
Corresponds to the JSON property balance
4111 4112 4113 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4111 def balance @balance end |
#balance_update_time ⇒ Google::Apis::WalletobjectsV1::DateTime
The date and time when the balance was last updated. Offset is required. If
balance is updated and this property is not provided, system will default to
the current time.
Corresponds to the JSON property balanceUpdateTime
4118 4119 4120 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4118 def balance_update_time @balance_update_time end |
#barcode ⇒ Google::Apis::WalletobjectsV1::Barcode
The barcode type and value.
Corresponds to the JSON property barcode
4123 4124 4125 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4123 def @barcode end |
#card_number ⇒ String
Required. The card's number.
Corresponds to the JSON property cardNumber
4128 4129 4130 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4128 def card_number @card_number end |
#class_id ⇒ String
Required. The class associated with this object. The class must be of the same
type as this object, must already exist, and must be approved. Class IDs
should follow the format issuer ID.identifier where the former is issued by
Google and latter is chosen by you.
Corresponds to the JSON property classId
4136 4137 4138 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4136 def class_id @class_id end |
#class_reference ⇒ Google::Apis::WalletobjectsV1::GiftCardClass
A copy of the inherited fields of the parent class. These fields are retrieved
during a GET.
Corresponds to the JSON property classReference
4142 4143 4144 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4142 def class_reference @class_reference end |
#disable_expiration_notification ⇒ Boolean Also known as: disable_expiration_notification?
Indicates if notifications should explicitly be suppressed. If this field is
set to true, regardless of the messages field, expiration notifications to
the user will be suppressed. By default, this field is set to false. Currently,
this can only be set for offers.
Corresponds to the JSON property disableExpirationNotification
4150 4151 4152 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4150 def disable_expiration_notification @disable_expiration_notification end |
#event_number ⇒ String
The card's event number, an optional field used by some gift cards.
Corresponds to the JSON property eventNumber
4156 4157 4158 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4156 def event_number @event_number end |
#grouping_info ⇒ Google::Apis::WalletobjectsV1::GroupingInfo
Information that controls how passes are grouped together.
Corresponds to the JSON property groupingInfo
4161 4162 4163 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4161 def grouping_info @grouping_info end |
#has_linked_device ⇒ Boolean Also known as: has_linked_device?
Whether this object is currently linked to a single device. This field is set
by the platform when a user saves the object, linking it to their device.
Intended for use by select partners. Contact support for additional
information.
Corresponds to the JSON property hasLinkedDevice
4169 4170 4171 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4169 def has_linked_device @has_linked_device end |
#has_users ⇒ Boolean Also known as: has_users?
Indicates if the object has users. This field is set by the platform.
Corresponds to the JSON property hasUsers
4175 4176 4177 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4175 def has_users @has_users end |
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property heroImage
4181 4182 4183 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4181 def hero_image @hero_image end |
#id ⇒ String
Required. The unique identifier for an object. This ID must be unique across
all objects from an issuer. This value should follow the format issuer ID.
identifier where the former is issued by Google and latter is chosen by you.
The unique identifier should only include alphanumeric characters, '.', '_',
or '-'.
Corresponds to the JSON property id
4190 4191 4192 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4190 def id @id end |
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data. The maximum number of these fields displayed is 1 from
object level and 1 for class object level.
Corresponds to the JSON property imageModulesData
4196 4197 4198 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4196 def image_modules_data @image_modules_data end |
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated. Use textModulesData instead.
Corresponds to the JSON property infoModuleData
4201 4202 4203 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4201 def info_module_data @info_module_data end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#giftCardObject".
Corresponds to the JSON property kind
4207 4208 4209 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4207 def kind @kind end |
#linked_object_ids ⇒ Array<String>
linked_object_ids are a list of other objects such as event ticket, loyalty,
offer, generic, giftcard, transit and boarding pass that should be
automatically attached to this giftcard object. If a user had saved this gift
card, then these linked_object_ids would be automatically pushed to the user's
wallet (unless they turned off the setting to receive such linked passes).
Make sure that objects present in linked_object_ids are already inserted - if
not, calls would fail. Once linked, the linked objects cannot be unlinked. You
cannot link objects belonging to another issuer. There is a limit to the
number of objects that can be linked to a single object. After the limit is
reached, new linked objects in the call will be ignored silently. Object IDs
should follow the format issuer ID. identifier where the former is issued by
Google and the latter is chosen by you.
Corresponds to the JSON property linkedObjectIds
4223 4224 4225 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4223 def linked_object_ids @linked_object_ids end |
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data. If links module data is also defined on the class, both
will be displayed.
Corresponds to the JSON property linksModuleData
4229 4230 4231 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4229 def links_module_data @links_module_data end |
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
Corresponds to the JSON property locations
4234 4235 4236 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4234 def locations @locations end |
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations. There is a maximum of ten on the object. Any additional
MerchantLocations added beyond the 10 will be rejected. These locations will
trigger a notification when a user enters within a Google-set radius of the
point. This field replaces the deprecated LatLongPoints.
Corresponds to the JSON property merchantLocations
4242 4243 4244 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4242 def merchant_locations @merchant_locations end |
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app. All users of this object will
receive its associated messages. The maximum number of these fields is 10.
Corresponds to the JSON property messages
4248 4249 4250 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4248 def @messages end |
#notify_preference ⇒ String
Whether or not field updates to this object should trigger notifications. When
set to NOTIFY, we will attempt to trigger a field update notification to users.
These notifications will only be sent to users if the field is part of an
allowlist. If set to DO_NOT_NOTIFY or NOTIFICATION_SETTINGS_UNSPECIFIED, no
notification will be triggered. This setting is ephemeral and needs to be set
with each PATCH or UPDATE request, otherwise a notification will not be
triggered.
Corresponds to the JSON property notifyPreference
4259 4260 4261 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4259 def notify_preference @notify_preference end |
#pass_constraints ⇒ Google::Apis::WalletobjectsV1::PassConstraints
Container for any constraints that may be placed on passes.
Corresponds to the JSON property passConstraints
4264 4265 4266 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4264 def pass_constraints @pass_constraints end |
#pin ⇒ String
The card's PIN.
Corresponds to the JSON property pin
4269 4270 4271 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4269 def pin @pin end |
#rotating_barcode ⇒ Google::Apis::WalletobjectsV1::RotatingBarcode
The rotating barcode type and value.
Corresponds to the JSON property rotatingBarcode
4274 4275 4276 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4274 def @rotating_barcode end |
#save_restrictions ⇒ Google::Apis::WalletobjectsV1::SaveRestrictions
Defines restrictions on the object that will be verified during save. Note:
this is an advanced feature, please contact Google for implementation support.
Corresponds to the JSON property saveRestrictions
4280 4281 4282 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4280 def save_restrictions @save_restrictions end |
#smart_tap_redemption_value ⇒ String
The value that will be transmitted to a Smart Tap certified terminal over NFC
for this object. The class level fields enableSmartTap and
redemptionIssuers must also be set up correctly in order for the pass to
support Smart Tap. Only ASCII characters are supported.
Corresponds to the JSON property smartTapRedemptionValue
4288 4289 4290 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4288 def smart_tap_redemption_value @smart_tap_redemption_value end |
#state ⇒ String
Required. The state of the object. This field is used to determine how an
object is displayed in the app. For example, an inactive object is moved to
the "Expired passes" section.
Corresponds to the JSON property state
4295 4296 4297 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4295 def state @state end |
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data. If text module data is also defined on the class, both will
be displayed. The maximum number of these fields displayed is 10 from the
object and 10 from the class.
Corresponds to the JSON property textModulesData
4302 4303 4304 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4302 def text_modules_data @text_modules_data end |
#valid_time_interval ⇒ Google::Apis::WalletobjectsV1::TimeInterval
The time period this object will be active and object can be used. An object'
s state will be changed to expired when this time period has passed.
Corresponds to the JSON property validTimeInterval
4308 4309 4310 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4308 def valid_time_interval @valid_time_interval end |
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data. Maximum of fifteen on the object. For a pass
only fifteen will be displayed.
Corresponds to the JSON property valueAddedModuleData
4314 4315 4316 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4314 def value_added_module_data @value_added_module_data end |
#version ⇒ Fixnum
Deprecated
Corresponds to the JSON property version
4319 4320 4321 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4319 def version @version end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4326 4327 4328 4329 4330 4331 4332 4333 4334 4335 4336 4337 4338 4339 4340 4341 4342 4343 4344 4345 4346 4347 4348 4349 4350 4351 4352 4353 4354 4355 4356 4357 4358 4359 4360 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4326 def update!(**args) @app_link_data = args[:app_link_data] if args.key?(:app_link_data) @balance = args[:balance] if args.key?(:balance) @balance_update_time = args[:balance_update_time] if args.key?(:balance_update_time) @barcode = args[:barcode] if args.key?(:barcode) @card_number = args[:card_number] if args.key?(:card_number) @class_id = args[:class_id] if args.key?(:class_id) @class_reference = args[:class_reference] if args.key?(:class_reference) @disable_expiration_notification = args[:disable_expiration_notification] if args.key?(:disable_expiration_notification) @event_number = args[:event_number] if args.key?(:event_number) @grouping_info = args[:grouping_info] if args.key?(:grouping_info) @has_linked_device = args[:has_linked_device] if args.key?(:has_linked_device) @has_users = args[:has_users] if args.key?(:has_users) @hero_image = args[:hero_image] if args.key?(:hero_image) @id = args[:id] if args.key?(:id) @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data) @info_module_data = args[:info_module_data] if args.key?(:info_module_data) @kind = args[:kind] if args.key?(:kind) @linked_object_ids = args[:linked_object_ids] if args.key?(:linked_object_ids) @links_module_data = args[:links_module_data] if args.key?(:links_module_data) @locations = args[:locations] if args.key?(:locations) @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations) @messages = args[:messages] if args.key?(:messages) @notify_preference = args[:notify_preference] if args.key?(:notify_preference) @pass_constraints = args[:pass_constraints] if args.key?(:pass_constraints) @pin = args[:pin] if args.key?(:pin) @rotating_barcode = args[:rotating_barcode] if args.key?(:rotating_barcode) @save_restrictions = args[:save_restrictions] if args.key?(:save_restrictions) @smart_tap_redemption_value = args[:smart_tap_redemption_value] if args.key?(:smart_tap_redemption_value) @state = args[:state] if args.key?(:state) @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data) @valid_time_interval = args[:valid_time_interval] if args.key?(:valid_time_interval) @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data) @version = args[:version] if args.key?(:version) end |