Class: Google::Apis::WalletobjectsV1::ListTemplateOverride
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::ListTemplateOverride
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#first_row_option ⇒ Google::Apis::WalletobjectsV1::FirstRowOption
Specifies from a predefined set of options or from a reference to the field what will be displayed in the first row.
-
#second_row_option ⇒ Google::Apis::WalletobjectsV1::FieldSelector
Custom field selector to use with field overrides.
-
#third_row_option ⇒ Google::Apis::WalletobjectsV1::FieldSelector
Custom field selector to use with field overrides.
Instance Method Summary collapse
-
#initialize(**args) ⇒ ListTemplateOverride
constructor
A new instance of ListTemplateOverride.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ ListTemplateOverride
Returns a new instance of ListTemplateOverride.
4892 4893 4894 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4892 def initialize(**args) update!(**args) end |
Instance Attribute Details
#first_row_option ⇒ Google::Apis::WalletobjectsV1::FirstRowOption
Specifies from a predefined set of options or from a reference to the field
what will be displayed in the first row. To set this override, set the
FirstRowOption.fieldOption to the FieldSelector of your choice.
Corresponds to the JSON property firstRowOption
4880 4881 4882 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4880 def first_row_option @first_row_option end |
#second_row_option ⇒ Google::Apis::WalletobjectsV1::FieldSelector
Custom field selector to use with field overrides.
Corresponds to the JSON property secondRowOption
4885 4886 4887 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4885 def second_row_option @second_row_option end |
#third_row_option ⇒ Google::Apis::WalletobjectsV1::FieldSelector
Custom field selector to use with field overrides.
Corresponds to the JSON property thirdRowOption
4890 4891 4892 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4890 def third_row_option @third_row_option end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
4897 4898 4899 4900 4901 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 4897 def update!(**args) @first_row_option = args[:first_row_option] if args.key?(:first_row_option) @second_row_option = args[:second_row_option] if args.key?(:second_row_option) @third_row_option = args[:third_row_option] if args.key?(:third_row_option) end |