Class: Google::Apis::WalletobjectsV1::LoyaltyClass
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::LoyaltyClass
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#account_id_label ⇒ String
The account ID label, such as "Member ID." Recommended maximum length is 15 characters to ensure full string is displayed on smaller screens.
-
#account_name_label ⇒ String
The account name label, such as "Member Name." Recommended maximum length is 15 characters to ensure full string is displayed on smaller screens.
-
#allow_multiple_users_per_object ⇒ Boolean
(also: #allow_multiple_users_per_object?)
Deprecated.
-
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front of the pass.
-
#callback_options ⇒ Google::Apis::WalletobjectsV1::CallbackOptions
Callback options to be used to call the issuer back for every save/delete of an object for this class by the end-user.
-
#class_template_info ⇒ Google::Apis::WalletobjectsV1::ClassTemplateInfo
Template information about how the class should be displayed.
-
#country_code ⇒ String
Country code used to display the card's country (when the user is not in that country), as well as to display localized content when content is not available in the user's locale.
-
#discoverable_program ⇒ Google::Apis::WalletobjectsV1::DiscoverableProgram
Information about how a class may be discovered and instantiated from within the Google Wallet app.
-
#enable_smart_tap ⇒ Boolean
(also: #enable_smart_tap?)
Identifies whether this class supports Smart Tap.
-
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#hex_background_color ⇒ String
The background color for the card.
-
#homepage_uri ⇒ Google::Apis::WalletobjectsV1::Uri
The URI of your application's home page.
-
#id ⇒ String
Required.
-
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data.
-
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated.
-
#issuer_name ⇒ String
Required.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data.
-
#localized_account_id_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the account_id_label.
-
#localized_account_name_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the account_name_label.
-
#localized_issuer_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the issuer_name.
-
#localized_program_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the program_name.
-
#localized_rewards_tier ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the rewards_tier.
-
#localized_rewards_tier_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the rewards_tier_label.
-
#localized_secondary_rewards_tier ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the secondary_rewards_tier.
-
#localized_secondary_rewards_tier_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the secondary_rewards_tier_label.
-
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
-
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations.
-
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app.
-
#multiple_devices_and_holders_allowed_status ⇒ String
Identifies whether multiple users and devices will save the same object referencing this class.
-
#notify_preference ⇒ String
Whether or not field updates to this class should trigger notifications.
-
#program_logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#program_name ⇒ String
Required.
-
#redemption_issuers ⇒ Array<Fixnum>
Identifies which redemption issuers can redeem the pass over Smart Tap.
-
#review ⇒ Google::Apis::WalletobjectsV1::Review
The review comments set by the platform when a class is marked
approvedorrejected. -
#review_status ⇒ String
Required.
-
#rewards_tier ⇒ String
The rewards tier, such as "Gold" or "Platinum." Recommended maximum length is 7 characters to ensure full string is displayed on smaller screens.
-
#rewards_tier_label ⇒ String
The rewards tier label, such as "Rewards Tier." Recommended maximum length is 9 characters to ensure full string is displayed on smaller screens.
-
#secondary_rewards_tier ⇒ String
The secondary rewards tier, such as "Gold" or "Platinum." Corresponds to the JSON property
secondaryRewardsTier. -
#secondary_rewards_tier_label ⇒ String
The secondary rewards tier label, such as "Rewards Tier." Corresponds to the JSON property
secondaryRewardsTierLabel. -
#security_animation ⇒ Google::Apis::WalletobjectsV1::SecurityAnimation
Optional information about the security animation.
-
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data.
-
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data.
-
#version ⇒ Fixnum
Deprecated Corresponds to the JSON property
version. -
#view_unlock_requirement ⇒ String
View Unlock Requirement options for the loyalty card.
-
#wide_program_logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#word_mark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Instance Method Summary collapse
-
#initialize(**args) ⇒ LoyaltyClass
constructor
A new instance of LoyaltyClass.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ LoyaltyClass
Returns a new instance of LoyaltyClass.
5303 5304 5305 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5303 def initialize(**args) update!(**args) end |
Instance Attribute Details
#account_id_label ⇒ String
The account ID label, such as "Member ID." Recommended maximum length is 15
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property accountIdLabel
5005 5006 5007 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5005 def account_id_label @account_id_label end |
#account_name_label ⇒ String
The account name label, such as "Member Name." Recommended maximum length is
15 characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property accountNameLabel
5011 5012 5013 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5011 def account_name_label @account_name_label end |
#allow_multiple_users_per_object ⇒ Boolean Also known as: allow_multiple_users_per_object?
Deprecated. Use multipleDevicesAndHoldersAllowedStatus instead.
Corresponds to the JSON property allowMultipleUsersPerObject
5016 5017 5018 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5016 def allow_multiple_users_per_object @allow_multiple_users_per_object end |
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front
of the pass. If AppLinkData is provided for the corresponding object that will
be used instead.
Corresponds to the JSON property appLinkData
5024 5025 5026 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5024 def app_link_data @app_link_data end |
#callback_options ⇒ Google::Apis::WalletobjectsV1::CallbackOptions
Callback options to be used to call the issuer back for every save/delete of
an object for this class by the end-user. All objects of this class are
eligible for the callback.
Corresponds to the JSON property callbackOptions
5031 5032 5033 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5031 def @callback_options end |
#class_template_info ⇒ Google::Apis::WalletobjectsV1::ClassTemplateInfo
Template information about how the class should be displayed. If unset, Google
will fallback to a default set of fields to display.
Corresponds to the JSON property classTemplateInfo
5037 5038 5039 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5037 def class_template_info @class_template_info end |
#country_code ⇒ String
Country code used to display the card's country (when the user is not in that
country), as well as to display localized content when content is not
available in the user's locale.
Corresponds to the JSON property countryCode
5044 5045 5046 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5044 def country_code @country_code end |
#discoverable_program ⇒ Google::Apis::WalletobjectsV1::DiscoverableProgram
Information about how a class may be discovered and instantiated from within
the Google Wallet app. This is done by searching for a loyalty or gift card
program and scanning or manually entering.
Corresponds to the JSON property discoverableProgram
5051 5052 5053 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5051 def discoverable_program @discoverable_program end |
#enable_smart_tap ⇒ Boolean Also known as: enable_smart_tap?
Identifies whether this class supports Smart Tap. The redemptionIssuers and
one of object level smartTapRedemptionLevel, barcode.value, oraccountId
fields must also be set up correctly in order for a pass to support Smart Tap.
Corresponds to the JSON propertyenableSmartTap`
5058 5059 5060 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5058 def enable_smart_tap @enable_smart_tap end |
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property heroImage
5064 5065 5066 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5064 def hero_image @hero_image end |
#hex_background_color ⇒ String
The background color for the card. If not set the dominant color of the hero
image is used, and if no hero image is set, the dominant color of the logo is
used. The format is #rrggbb where rrggbb is a hex RGB triplet, such as #
ffcc00. You can also use the shorthand version of the RGB triplet which is #
rgb, such as #fc0.
Corresponds to the JSON property hexBackgroundColor
5073 5074 5075 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5073 def hex_background_color @hex_background_color end |
#homepage_uri ⇒ Google::Apis::WalletobjectsV1::Uri
The URI of your application's home page. Populating the URI in this field
results in the exact same behavior as populating an URI in linksModuleData (
when an object is rendered, a link to the homepage is shown in what would
usually be thought of as the linksModuleData section of the object).
Corresponds to the JSON property homepageUri
5081 5082 5083 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5081 def homepage_uri @homepage_uri end |
#id ⇒ String
Required. The unique identifier for a class. This ID must be unique across all
classes from an issuer. This value should follow the format issuer ID.
identifier where the former is issued by Google and latter is chosen by you.
Your unique identifier should only include alphanumeric characters, '.', '_',
or '-'.
Corresponds to the JSON property id
5090 5091 5092 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5090 def id @id end |
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data. The maximum number of these fields displayed is 1 from
object level and 1 for class object level.
Corresponds to the JSON property imageModulesData
5096 5097 5098 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5096 def image_modules_data @image_modules_data end |
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated. Use textModulesData instead.
Corresponds to the JSON property infoModuleData
5101 5102 5103 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5101 def info_module_data @info_module_data end |
#issuer_name ⇒ String
Required. The issuer name. Recommended maximum length is 20 characters to
ensure full string is displayed on smaller screens.
Corresponds to the JSON property issuerName
5107 5108 5109 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5107 def issuer_name @issuer_name end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#loyaltyClass".
Corresponds to the JSON property kind
5113 5114 5115 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5113 def kind @kind end |
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data. If links module data is also defined on the object, both
will be displayed.
Corresponds to the JSON property linksModuleData
5119 5120 5121 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5119 def links_module_data @links_module_data end |
#localized_account_id_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the account_id_label. Recommended maximum length is 15
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedAccountIdLabel
5125 5126 5127 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5125 def localized_account_id_label @localized_account_id_label end |
#localized_account_name_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the account_name_label. Recommended maximum length is
15 characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedAccountNameLabel
5131 5132 5133 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5131 def localized_account_name_label @localized_account_name_label end |
#localized_issuer_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the issuer_name. Recommended maximum length is 20
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedIssuerName
5137 5138 5139 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5137 def localized_issuer_name @localized_issuer_name end |
#localized_program_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the program_name. The app may display an ellipsis after
the first 20 characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedProgramName
5143 5144 5145 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5143 def localized_program_name @localized_program_name end |
#localized_rewards_tier ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the rewards_tier. Recommended maximum length is 7
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedRewardsTier
5149 5150 5151 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5149 def localized_rewards_tier @localized_rewards_tier end |
#localized_rewards_tier_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the rewards_tier_label. Recommended maximum length is 9
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedRewardsTierLabel
5155 5156 5157 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5155 def localized_rewards_tier_label @localized_rewards_tier_label end |
#localized_secondary_rewards_tier ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the secondary_rewards_tier.
Corresponds to the JSON property localizedSecondaryRewardsTier
5160 5161 5162 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5160 def localized_secondary_rewards_tier @localized_secondary_rewards_tier end |
#localized_secondary_rewards_tier_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the secondary_rewards_tier_label.
Corresponds to the JSON property localizedSecondaryRewardsTierLabel
5165 5166 5167 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5165 def localized_secondary_rewards_tier_label @localized_secondary_rewards_tier_label end |
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
Corresponds to the JSON property locations
5170 5171 5172 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5170 def locations @locations end |
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations. There is a maximum of ten on the class. Any additional
MerchantLocations added beyond the 10 will be rejected. These locations will
trigger a notification when a user enters within a Google-set radius of the
point. This field replaces the deprecated LatLongPoints.
Corresponds to the JSON property merchantLocations
5178 5179 5180 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5178 def merchant_locations @merchant_locations end |
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app. All users of this object will
receive its associated messages. The maximum number of these fields is 10.
Corresponds to the JSON property messages
5184 5185 5186 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5184 def @messages end |
#multiple_devices_and_holders_allowed_status ⇒ String
Identifies whether multiple users and devices will save the same object
referencing this class.
Corresponds to the JSON property multipleDevicesAndHoldersAllowedStatus
5190 5191 5192 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5190 def multiple_devices_and_holders_allowed_status @multiple_devices_and_holders_allowed_status end |
#notify_preference ⇒ String
Whether or not field updates to this class should trigger notifications. When
set to NOTIFY, we will attempt to trigger a field update notification to users.
These notifications will only be sent to users if the field is part of an
allowlist. If not specified, no notification will be triggered. This setting
is ephemeral and needs to be set with each PATCH or UPDATE request, otherwise
a notification will not be triggered.
Corresponds to the JSON property notifyPreference
5200 5201 5202 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5200 def notify_preference @notify_preference end |
#program_logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property programLogo
5205 5206 5207 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5205 def program_logo @program_logo end |
#program_name ⇒ String
Required. The program name, such as "Adam's Apparel". The app may display an
ellipsis after the first 20 characters to ensure full string is displayed on
smaller screens.
Corresponds to the JSON property programName
5212 5213 5214 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5212 def program_name @program_name end |
#redemption_issuers ⇒ Array<Fixnum>
Identifies which redemption issuers can redeem the pass over Smart Tap.
Redemption issuers are identified by their issuer ID. Redemption issuers must
have at least one Smart Tap key configured. The enableSmartTap and one of
object level smartTapRedemptionValue, barcode.value, oraccountIdfields
must also be set up correctly in order for a pass to support Smart Tap.
Corresponds to the JSON propertyredemptionIssuers`
5221 5222 5223 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5221 def redemption_issuers @redemption_issuers end |
#review ⇒ Google::Apis::WalletobjectsV1::Review
The review comments set by the platform when a class is marked approved or
rejected.
Corresponds to the JSON property review
5227 5228 5229 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5227 def review @review end |
#review_status ⇒ String
Required. The status of the class. This field can be set to draft or
underReview using the insert, patch, or update API calls. Once the review
state is changed from draft it may not be changed back to draft. You
should keep this field to draft when the class is under development. A
draft class cannot be used to create any object. You should set this field to
underReview when you believe the class is ready for use. The platform will
automatically set this field to approved and it can be immediately used to
create or migrate objects. When updating an already approved class you
should keep setting this field to underReview.
Corresponds to the JSON property reviewStatus
5240 5241 5242 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5240 def review_status @review_status end |
#rewards_tier ⇒ String
The rewards tier, such as "Gold" or "Platinum." Recommended maximum length is
7 characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property rewardsTier
5246 5247 5248 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5246 def rewards_tier @rewards_tier end |
#rewards_tier_label ⇒ String
The rewards tier label, such as "Rewards Tier." Recommended maximum length is
9 characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property rewardsTierLabel
5252 5253 5254 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5252 def rewards_tier_label @rewards_tier_label end |
#secondary_rewards_tier ⇒ String
The secondary rewards tier, such as "Gold" or "Platinum."
Corresponds to the JSON property secondaryRewardsTier
5257 5258 5259 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5257 def secondary_rewards_tier @secondary_rewards_tier end |
#secondary_rewards_tier_label ⇒ String
The secondary rewards tier label, such as "Rewards Tier."
Corresponds to the JSON property secondaryRewardsTierLabel
5262 5263 5264 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5262 def secondary_rewards_tier_label @secondary_rewards_tier_label end |
#security_animation ⇒ Google::Apis::WalletobjectsV1::SecurityAnimation
Optional information about the security animation. If this is set a security
animation will be rendered on pass details.
Corresponds to the JSON property securityAnimation
5268 5269 5270 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5268 def security_animation @security_animation end |
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data. If text module data is also defined on the class, both will
be displayed. The maximum number of these fields displayed is 10 from the
object and 10 from the class.
Corresponds to the JSON property textModulesData
5275 5276 5277 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5275 def text_modules_data @text_modules_data end |
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data. Maximum of fifteen on the class. For a pass
only fifteen will be displayed, prioritizing those from the object.
Corresponds to the JSON property valueAddedModuleData
5281 5282 5283 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5281 def value_added_module_data @value_added_module_data end |
#version ⇒ Fixnum
Deprecated
Corresponds to the JSON property version
5286 5287 5288 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5286 def version @version end |
#view_unlock_requirement ⇒ String
View Unlock Requirement options for the loyalty card.
Corresponds to the JSON property viewUnlockRequirement
5291 5292 5293 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5291 def view_unlock_requirement @view_unlock_requirement end |
#wide_program_logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property wideProgramLogo
5296 5297 5298 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5296 def wide_program_logo @wide_program_logo end |
#word_mark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property wordMark
5301 5302 5303 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5301 def word_mark @word_mark end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
5308 5309 5310 5311 5312 5313 5314 5315 5316 5317 5318 5319 5320 5321 5322 5323 5324 5325 5326 5327 5328 5329 5330 5331 5332 5333 5334 5335 5336 5337 5338 5339 5340 5341 5342 5343 5344 5345 5346 5347 5348 5349 5350 5351 5352 5353 5354 5355 5356 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5308 def update!(**args) @account_id_label = args[:account_id_label] if args.key?(:account_id_label) @account_name_label = args[:account_name_label] if args.key?(:account_name_label) @allow_multiple_users_per_object = args[:allow_multiple_users_per_object] if args.key?(:allow_multiple_users_per_object) @app_link_data = args[:app_link_data] if args.key?(:app_link_data) @callback_options = args[:callback_options] if args.key?(:callback_options) @class_template_info = args[:class_template_info] if args.key?(:class_template_info) @country_code = args[:country_code] if args.key?(:country_code) @discoverable_program = args[:discoverable_program] if args.key?(:discoverable_program) @enable_smart_tap = args[:enable_smart_tap] if args.key?(:enable_smart_tap) @hero_image = args[:hero_image] if args.key?(:hero_image) @hex_background_color = args[:hex_background_color] if args.key?(:hex_background_color) @homepage_uri = args[:homepage_uri] if args.key?(:homepage_uri) @id = args[:id] if args.key?(:id) @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data) @info_module_data = args[:info_module_data] if args.key?(:info_module_data) @issuer_name = args[:issuer_name] if args.key?(:issuer_name) @kind = args[:kind] if args.key?(:kind) @links_module_data = args[:links_module_data] if args.key?(:links_module_data) @localized_account_id_label = args[:localized_account_id_label] if args.key?(:localized_account_id_label) @localized_account_name_label = args[:localized_account_name_label] if args.key?(:localized_account_name_label) @localized_issuer_name = args[:localized_issuer_name] if args.key?(:localized_issuer_name) @localized_program_name = args[:localized_program_name] if args.key?(:localized_program_name) @localized_rewards_tier = args[:localized_rewards_tier] if args.key?(:localized_rewards_tier) @localized_rewards_tier_label = args[:localized_rewards_tier_label] if args.key?(:localized_rewards_tier_label) @localized_secondary_rewards_tier = args[:localized_secondary_rewards_tier] if args.key?(:localized_secondary_rewards_tier) @localized_secondary_rewards_tier_label = args[:localized_secondary_rewards_tier_label] if args.key?(:localized_secondary_rewards_tier_label) @locations = args[:locations] if args.key?(:locations) @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations) @messages = args[:messages] if args.key?(:messages) @multiple_devices_and_holders_allowed_status = args[:multiple_devices_and_holders_allowed_status] if args.key?(:multiple_devices_and_holders_allowed_status) @notify_preference = args[:notify_preference] if args.key?(:notify_preference) @program_logo = args[:program_logo] if args.key?(:program_logo) @program_name = args[:program_name] if args.key?(:program_name) @redemption_issuers = args[:redemption_issuers] if args.key?(:redemption_issuers) @review = args[:review] if args.key?(:review) @review_status = args[:review_status] if args.key?(:review_status) @rewards_tier = args[:rewards_tier] if args.key?(:rewards_tier) @rewards_tier_label = args[:rewards_tier_label] if args.key?(:rewards_tier_label) @secondary_rewards_tier = args[:secondary_rewards_tier] if args.key?(:secondary_rewards_tier) @secondary_rewards_tier_label = args[:secondary_rewards_tier_label] if args.key?(:secondary_rewards_tier_label) @security_animation = args[:security_animation] if args.key?(:security_animation) @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data) @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data) @version = args[:version] if args.key?(:version) @view_unlock_requirement = args[:view_unlock_requirement] if args.key?(:view_unlock_requirement) @wide_program_logo = args[:wide_program_logo] if args.key?(:wide_program_logo) @word_mark = args[:word_mark] if args.key?(:word_mark) end |