Class: Google::Apis::WalletobjectsV1::Media
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::Media
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Overview
A reference to data stored on the filesystem, on GFS or in blobstore.
Instance Attribute Summary collapse
-
#algorithm ⇒ String
Deprecated, use one of explicit hash type fields instead.
-
#bigstore_object_ref ⇒ String
Use object_id instead.
-
#blob_ref ⇒ String
Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be the byte representation of a blobstore.BlobRef.
-
#blobstore2_info ⇒ Google::Apis::WalletobjectsV1::Blobstore2Info
Information to read/write to blobstore2.
-
#composite_media ⇒ Array<Google::Apis::WalletobjectsV1::CompositeMedia>
A composite media composed of one or more media objects, set if reference_type is COMPOSITE_MEDIA.
-
#content_type ⇒ String
MIME type of the data Corresponds to the JSON property
contentType. -
#content_type_info ⇒ Google::Apis::WalletobjectsV1::ContentTypeInfo
Detailed Content-Type information from Scotty.
-
#cosmo_binary_reference ⇒ String
A binary data reference for a media download.
-
#crc32c_hash ⇒ Fixnum
For Scotty Uploads: Scotty-provided hashes for uploads For Scotty Downloads: ( WARNING: DO NOT USE WITHOUT PERMISSION FROM THE SCOTTY TEAM.) A Hash provided by the agent to be used to verify the data being downloaded.
-
#diff_checksums_response ⇒ Google::Apis::WalletobjectsV1::DiffChecksumsResponse
Backend response for a Diff get checksums response.
-
#diff_download_response ⇒ Google::Apis::WalletobjectsV1::DiffDownloadResponse
Backend response for a Diff download response.
-
#diff_upload_request ⇒ Google::Apis::WalletobjectsV1::DiffUploadRequest
A Diff upload request.
-
#diff_upload_response ⇒ Google::Apis::WalletobjectsV1::DiffUploadResponse
Backend response for a Diff upload request.
-
#diff_version_response ⇒ Google::Apis::WalletobjectsV1::DiffVersionResponse
Backend response for a Diff get version response.
-
#download_parameters ⇒ Google::Apis::WalletobjectsV1::DownloadParameters
Parameters specific to media downloads.
-
#filename ⇒ String
Original file name Corresponds to the JSON property
filename. -
#hash_prop ⇒ String
Deprecated, use one of explicit hash type fields instead.
-
#hash_verified ⇒ Boolean
(also: #hash_verified?)
For Scotty uploads only.
-
#inline ⇒ String
Media data, set if reference_type is INLINE Corresponds to the JSON property
inlineNOTE: Values are automatically base64 encoded/decoded in the client library. -
#is_potential_retry ⇒ Boolean
(also: #is_potential_retry?)
|is_potential_retry| is set false only when Scotty is certain that it has not sent the request before.
-
#length ⇒ Fixnum
Size of the data, in bytes Corresponds to the JSON property
length. -
#md5_hash ⇒ String
Scotty-provided MD5 hash for an upload.
-
#media_id ⇒ String
Media id to forward to the operation GetMedia.
-
#object_id_prop ⇒ Google::Apis::WalletobjectsV1::ObjectIdProp
This is a copy of the tech.blob.ObjectId proto, which could not be used directly here due to transitive closure issues with JavaScript support; see http://b/8801763.
-
#path ⇒ String
Path to the data, set if reference_type is PATH Corresponds to the JSON property
path. -
#reference_type ⇒ String
Describes what the field reference contains.
-
#sha1_hash ⇒ String
Scotty-provided SHA1 hash for an upload.
-
#sha256_hash ⇒ String
Scotty-provided SHA256 hash for an upload.
-
#sha512_hash ⇒ String
Scotty-provided SHA512 hash for an upload.
-
#timestamp ⇒ Fixnum
Time at which the media data was last updated, in milliseconds since UNIX epoch Corresponds to the JSON property
timestamp. -
#token ⇒ String
A unique fingerprint/version id for the media data Corresponds to the JSON property
token.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Media
constructor
A new instance of Media.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Media
Returns a new instance of Media.
6004 6005 6006 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6004 def initialize(**args) update!(**args) end |
Instance Attribute Details
#algorithm ⇒ String
Deprecated, use one of explicit hash type fields instead. Algorithm used for
calculating the hash. As of 2011/01/21, "MD5" is the only possible value for
this field. New values may be added at any time.
Corresponds to the JSON property algorithm
5802 5803 5804 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5802 def algorithm @algorithm end |
#bigstore_object_ref ⇒ String
Use object_id instead.
Corresponds to the JSON property bigstoreObjectRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
5808 5809 5810 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5808 def bigstore_object_ref @bigstore_object_ref end |
#blob_ref ⇒ String
Blobstore v1 reference, set if reference_type is BLOBSTORE_REF This should be
the byte representation of a blobstore.BlobRef. Since Blobstore is deprecating
v1, use blobstore2_info instead. For now, any v2 blob will also be represented
in this field as v1 BlobRef.
Corresponds to the JSON property blobRef
NOTE: Values are automatically base64 encoded/decoded in the client library.
5817 5818 5819 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5817 def blob_ref @blob_ref end |
#blobstore2_info ⇒ Google::Apis::WalletobjectsV1::Blobstore2Info
Information to read/write to blobstore2.
Corresponds to the JSON property blobstore2Info
5822 5823 5824 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5822 def blobstore2_info @blobstore2_info end |
#composite_media ⇒ Array<Google::Apis::WalletobjectsV1::CompositeMedia>
A composite media composed of one or more media objects, set if reference_type
is COMPOSITE_MEDIA. The media length field must be set to the sum of the
lengths of all composite media objects. Note: All composite media must have
length specified.
Corresponds to the JSON property compositeMedia
5830 5831 5832 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5830 def composite_media @composite_media end |
#content_type ⇒ String
MIME type of the data
Corresponds to the JSON property contentType
5835 5836 5837 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5835 def content_type @content_type end |
#content_type_info ⇒ Google::Apis::WalletobjectsV1::ContentTypeInfo
Detailed Content-Type information from Scotty. The Content-Type of the media
will typically be filled in by the header or Scotty's best_guess, but this
extended information provides the backend with more information so that it can
make a better decision if needed. This is only used on media upload requests
from Scotty.
Corresponds to the JSON property contentTypeInfo
5844 5845 5846 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5844 def content_type_info @content_type_info end |
#cosmo_binary_reference ⇒ String
A binary data reference for a media download. Serves as a technology-agnostic
binary reference in some Google infrastructure. This value is a serialized
storage_cosmo.BinaryReference proto. Storing it as bytes is a hack to get
around the fact that the cosmo proto (as well as others it includes) doesn't
support JavaScript. This prevents us from including the actual type of this
field.
Corresponds to the JSON property cosmoBinaryReference
NOTE: Values are automatically base64 encoded/decoded in the client library.
5855 5856 5857 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5855 def cosmo_binary_reference @cosmo_binary_reference end |
#crc32c_hash ⇒ Fixnum
For Scotty Uploads: Scotty-provided hashes for uploads For Scotty Downloads: (
WARNING: DO NOT USE WITHOUT PERMISSION FROM THE SCOTTY TEAM.) A Hash provided
by the agent to be used to verify the data being downloaded. Currently only
supported for inline payloads. Further, only crc32c_hash is currently
supported.
Corresponds to the JSON property crc32cHash
5864 5865 5866 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5864 def crc32c_hash @crc32c_hash end |
#diff_checksums_response ⇒ Google::Apis::WalletobjectsV1::DiffChecksumsResponse
Backend response for a Diff get checksums response. For details on the Scotty
Diff protocol, visit http://go/scotty-diff-protocol.
Corresponds to the JSON property diffChecksumsResponse
5870 5871 5872 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5870 def diff_checksums_response @diff_checksums_response end |
#diff_download_response ⇒ Google::Apis::WalletobjectsV1::DiffDownloadResponse
Backend response for a Diff download response. For details on the Scotty Diff
protocol, visit http://go/scotty-diff-protocol.
Corresponds to the JSON property diffDownloadResponse
5876 5877 5878 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5876 def diff_download_response @diff_download_response end |
#diff_upload_request ⇒ Google::Apis::WalletobjectsV1::DiffUploadRequest
A Diff upload request. For details on the Scotty Diff protocol, visit http://
go/scotty-diff-protocol.
Corresponds to the JSON property diffUploadRequest
5882 5883 5884 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5882 def diff_upload_request @diff_upload_request end |
#diff_upload_response ⇒ Google::Apis::WalletobjectsV1::DiffUploadResponse
Backend response for a Diff upload request. For details on the Scotty Diff
protocol, visit http://go/scotty-diff-protocol.
Corresponds to the JSON property diffUploadResponse
5888 5889 5890 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5888 def diff_upload_response @diff_upload_response end |
#diff_version_response ⇒ Google::Apis::WalletobjectsV1::DiffVersionResponse
Backend response for a Diff get version response. For details on the Scotty
Diff protocol, visit http://go/scotty-diff-protocol.
Corresponds to the JSON property diffVersionResponse
5894 5895 5896 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5894 def diff_version_response @diff_version_response end |
#download_parameters ⇒ Google::Apis::WalletobjectsV1::DownloadParameters
Parameters specific to media downloads.
Corresponds to the JSON property downloadParameters
5899 5900 5901 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5899 def download_parameters @download_parameters end |
#filename ⇒ String
Original file name
Corresponds to the JSON property filename
5904 5905 5906 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5904 def filename @filename end |
#hash_prop ⇒ String
Deprecated, use one of explicit hash type fields instead. These two hash
related fields will only be populated on Scotty based media uploads and will
contain the content of the hash group in the NotificationRequest: http://cs/#
google3/blobstore2/api/scotty/service/proto/upload_listener.proto&q=class:Hash
Hex encoded hash value of the uploaded media.
Corresponds to the JSON property hash
5913 5914 5915 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5913 def hash_prop @hash_prop end |
#hash_verified ⇒ Boolean Also known as: hash_verified?
For Scotty uploads only. If a user sends a hash code and the backend has
requested that Scotty verify the upload against the client hash, Scotty will
perform the check on behalf of the backend and will reject it if the hashes
don't match. This is set to true if Scotty performed this verification.
Corresponds to the JSON property hashVerified
5921 5922 5923 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5921 def hash_verified @hash_verified end |
#inline ⇒ String
Media data, set if reference_type is INLINE
Corresponds to the JSON property inline
NOTE: Values are automatically base64 encoded/decoded in the client library.
5928 5929 5930 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5928 def inline @inline end |
#is_potential_retry ⇒ Boolean Also known as: is_potential_retry?
|is_potential_retry| is set false only when Scotty is certain that it has not
sent the request before. When a client resumes an upload, this field must be
set true in agent calls, because Scotty cannot be certain that it has never
sent the request before due to potential failure in the session state
persistence.
Corresponds to the JSON property isPotentialRetry
5937 5938 5939 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5937 def is_potential_retry @is_potential_retry end |
#length ⇒ Fixnum
Size of the data, in bytes
Corresponds to the JSON property length
5943 5944 5945 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5943 def length @length end |
#md5_hash ⇒ String
Scotty-provided MD5 hash for an upload.
Corresponds to the JSON property md5Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
5949 5950 5951 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5949 def md5_hash @md5_hash end |
#media_id ⇒ String
Media id to forward to the operation GetMedia. Can be set if reference_type is
GET_MEDIA.
Corresponds to the JSON property mediaId
NOTE: Values are automatically base64 encoded/decoded in the client library.
5956 5957 5958 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5956 def media_id @media_id end |
#object_id_prop ⇒ Google::Apis::WalletobjectsV1::ObjectIdProp
This is a copy of the tech.blob.ObjectId proto, which could not be used
directly here due to transitive closure issues with JavaScript support; see
http://b/8801763.
Corresponds to the JSON property objectId
5963 5964 5965 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5963 def object_id_prop @object_id_prop end |
#path ⇒ String
Path to the data, set if reference_type is PATH
Corresponds to the JSON property path
5968 5969 5970 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5968 def path @path end |
#reference_type ⇒ String
Describes what the field reference contains.
Corresponds to the JSON property referenceType
5973 5974 5975 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5973 def reference_type @reference_type end |
#sha1_hash ⇒ String
Scotty-provided SHA1 hash for an upload.
Corresponds to the JSON property sha1Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
5979 5980 5981 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5979 def sha1_hash @sha1_hash end |
#sha256_hash ⇒ String
Scotty-provided SHA256 hash for an upload.
Corresponds to the JSON property sha256Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
5985 5986 5987 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5985 def sha256_hash @sha256_hash end |
#sha512_hash ⇒ String
Scotty-provided SHA512 hash for an upload.
Corresponds to the JSON property sha512Hash
NOTE: Values are automatically base64 encoded/decoded in the client library.
5991 5992 5993 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5991 def sha512_hash @sha512_hash end |
#timestamp ⇒ Fixnum
Time at which the media data was last updated, in milliseconds since UNIX
epoch
Corresponds to the JSON property timestamp
5997 5998 5999 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 5997 def @timestamp end |
#token ⇒ String
A unique fingerprint/version id for the media data
Corresponds to the JSON property token
6002 6003 6004 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6002 def token @token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
6009 6010 6011 6012 6013 6014 6015 6016 6017 6018 6019 6020 6021 6022 6023 6024 6025 6026 6027 6028 6029 6030 6031 6032 6033 6034 6035 6036 6037 6038 6039 6040 6041 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 6009 def update!(**args) @algorithm = args[:algorithm] if args.key?(:algorithm) @bigstore_object_ref = args[:bigstore_object_ref] if args.key?(:bigstore_object_ref) @blob_ref = args[:blob_ref] if args.key?(:blob_ref) @blobstore2_info = args[:blobstore2_info] if args.key?(:blobstore2_info) @composite_media = args[:composite_media] if args.key?(:composite_media) @content_type = args[:content_type] if args.key?(:content_type) @content_type_info = args[:content_type_info] if args.key?(:content_type_info) @cosmo_binary_reference = args[:cosmo_binary_reference] if args.key?(:cosmo_binary_reference) @crc32c_hash = args[:crc32c_hash] if args.key?(:crc32c_hash) @diff_checksums_response = args[:diff_checksums_response] if args.key?(:diff_checksums_response) @diff_download_response = args[:diff_download_response] if args.key?(:diff_download_response) @diff_upload_request = args[:diff_upload_request] if args.key?(:diff_upload_request) @diff_upload_response = args[:diff_upload_response] if args.key?(:diff_upload_response) @diff_version_response = args[:diff_version_response] if args.key?(:diff_version_response) @download_parameters = args[:download_parameters] if args.key?(:download_parameters) @filename = args[:filename] if args.key?(:filename) @hash_prop = args[:hash_prop] if args.key?(:hash_prop) @hash_verified = args[:hash_verified] if args.key?(:hash_verified) @inline = args[:inline] if args.key?(:inline) @is_potential_retry = args[:is_potential_retry] if args.key?(:is_potential_retry) @length = args[:length] if args.key?(:length) @md5_hash = args[:md5_hash] if args.key?(:md5_hash) @media_id = args[:media_id] if args.key?(:media_id) @object_id_prop = args[:object_id_prop] if args.key?(:object_id_prop) @path = args[:path] if args.key?(:path) @reference_type = args[:reference_type] if args.key?(:reference_type) @sha1_hash = args[:sha1_hash] if args.key?(:sha1_hash) @sha256_hash = args[:sha256_hash] if args.key?(:sha256_hash) @sha512_hash = args[:sha512_hash] if args.key?(:sha512_hash) @timestamp = args[:timestamp] if args.key?(:timestamp) @token = args[:token] if args.key?(:token) end |