Class: Google::Apis::WalletobjectsV1::PurchaseDetails

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ PurchaseDetails

Returns a new instance of PurchaseDetails.



7149
7150
7151
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7149

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#account_idString

ID of the account used to purchase the ticket. Corresponds to the JSON property accountId

Returns:

  • (String)


7113
7114
7115
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7113

def 
  @account_id
end

#confirmation_codeString

The confirmation code for the purchase. This may be the same for multiple different tickets and is used to group tickets together. Corresponds to the JSON property confirmationCode

Returns:

  • (String)


7119
7120
7121
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7119

def confirmation_code
  @confirmation_code
end

#purchase_date_timeString

The purchase date/time of the ticket. This is an ISO 8601 extended format date/ time, with or without an offset. Time may be specified up to nanosecond precision. Offsets may be specified with seconds precision (even though offset seconds is not part of ISO 8601). For example: 1985-04-12T23:20:50.52Z would be 20 minutes and 50.52 seconds after the 23rd hour of April 12th, 1985 in UTC. 1985-04-12T19:20:50.52-04:00 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985, 4 hours before UTC (same instant in time as the above example). If the event were in New York, this would be the equivalent of Eastern Daylight Time (EDT). Remember that offset varies in regions that observe Daylight Saving Time (or Summer Time), depending on the time of the year. 1985-04-12T19:20:50.52 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985 with no offset information. Without offset information, some rich features may not be available. Corresponds to the JSON property purchaseDateTime

Returns:

  • (String)


7136
7137
7138
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7136

def purchase_date_time
  @purchase_date_time
end

#purchase_receipt_numberString

Receipt number/identifier for tracking the ticket purchase via the body that sold the ticket. Corresponds to the JSON property purchaseReceiptNumber

Returns:

  • (String)


7142
7143
7144
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7142

def purchase_receipt_number
  @purchase_receipt_number
end

#ticket_costGoogle::Apis::WalletobjectsV1::TicketCost

The cost of the ticket. Corresponds to the JSON property ticketCost



7147
7148
7149
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7147

def ticket_cost
  @ticket_cost
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7154
7155
7156
7157
7158
7159
7160
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7154

def update!(**args)
  @account_id = args[:account_id] if args.key?(:account_id)
  @confirmation_code = args[:confirmation_code] if args.key?(:confirmation_code)
  @purchase_date_time = args[:purchase_date_time] if args.key?(:purchase_date_time)
  @purchase_receipt_number = args[:purchase_receipt_number] if args.key?(:purchase_receipt_number)
  @ticket_cost = args[:ticket_cost] if args.key?(:ticket_cost)
end