Class: Google::Apis::WalletobjectsV1::RotatingBarcode

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ RotatingBarcode

Returns a new instance of RotatingBarcode.



7361
7362
7363
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7361

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#alternate_textString

An optional text that will override the default text that shows under the barcode. This field is intended for a human readable equivalent of the barcode value, used when the barcode cannot be scanned. Corresponds to the JSON property alternateText

Returns:

  • (String)


7321
7322
7323
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7321

def alternate_text
  @alternate_text
end

#initial_rotating_barcode_valuesGoogle::Apis::WalletobjectsV1::RotatingBarcodeValues

A payload containing many barcode values and start date/time. Corresponds to the JSON property initialRotatingBarcodeValues



7326
7327
7328
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7326

def initial_rotating_barcode_values
  @initial_rotating_barcode_values
end

#render_encodingString

The render encoding for the barcode. When specified, barcode is rendered in the given encoding. Otherwise best known encoding is chosen by Google. Corresponds to the JSON property renderEncoding

Returns:

  • (String)


7332
7333
7334
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7332

def render_encoding
  @render_encoding
end

#show_code_textGoogle::Apis::WalletobjectsV1::LocalizedString

Optional text that will be shown when the barcode is hidden behind a click action. This happens in cases where a pass has Smart Tap enabled. If not specified, a default is chosen by Google. Corresponds to the JSON property showCodeText



7339
7340
7341
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7339

def show_code_text
  @show_code_text
end

#totp_detailsGoogle::Apis::WalletobjectsV1::RotatingBarcodeTotpDetails

Configuration for the time-based OTP substitutions. See https://tools.ietf.org/ html/rfc6238 Corresponds to the JSON property totpDetails



7345
7346
7347
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7345

def totp_details
  @totp_details
end

#typeString

The type of this barcode. Corresponds to the JSON property type

Returns:

  • (String)


7350
7351
7352
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7350

def type
  @type
end

#value_patternString

String encoded barcode value. This string supports the following substitutions:

  • totp_value_n: Replaced with the TOTP value (see TotpDetails.parameters). * totp_timestamp_millis: Replaced with the timestamp (millis since epoch) at which the barcode was generated. * totp_timestamp_seconds: Replaced with the timestamp (seconds since epoch) at which the barcode was generated. Corresponds to the JSON property valuePattern

Returns:

  • (String)


7359
7360
7361
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7359

def value_pattern
  @value_pattern
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7366
7367
7368
7369
7370
7371
7372
7373
7374
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7366

def update!(**args)
  @alternate_text = args[:alternate_text] if args.key?(:alternate_text)
  @initial_rotating_barcode_values = args[:initial_rotating_barcode_values] if args.key?(:initial_rotating_barcode_values)
  @render_encoding = args[:render_encoding] if args.key?(:render_encoding)
  @show_code_text = args[:show_code_text] if args.key?(:show_code_text)
  @totp_details = args[:totp_details] if args.key?(:totp_details)
  @type = args[:type] if args.key?(:type)
  @value_pattern = args[:value_pattern] if args.key?(:value_pattern)
end