Class: Google::Apis::WalletobjectsV1::SetPassUpdateNoticeRequest

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Request to send a private pass update notice information to Google, so that devices can then fetch the notice prompting the user to update a pass.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ SetPassUpdateNoticeRequest

Returns a new instance of SetPassUpdateNoticeRequest.



7556
7557
7558
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7556

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#external_pass_idString

Required. A fully qualified identifier of the pass that the issuer wants to notify the pass holder(s) about. Formatted as . Corresponds to the JSON property externalPassId

Returns:

  • (String)


7539
7540
7541
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7539

def external_pass_id
  @external_pass_id
end

#update_uriString

Required. The issuer endpoint URI the pass holder needs to follow in order to receive an updated pass JWT. It can not contain any sensitive information. The endpoint needs to authenticate the user before giving the user the updated JWT. Example update URI https://someissuer.com/update/passId=someExternalPassId Corresponds to the JSON property updateUri

Returns:

  • (String)


7547
7548
7549
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7547

def update_uri
  @update_uri
end

#updated_pass_jwt_signatureString

Required. The JWT signature of the updated pass that the issuer wants to notify Google about. Only devices that report a different JWT signature than this JWT signature will receive the update notification. Corresponds to the JSON property updatedPassJwtSignature

Returns:

  • (String)


7554
7555
7556
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7554

def updated_pass_jwt_signature
  @updated_pass_jwt_signature
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7561
7562
7563
7564
7565
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7561

def update!(**args)
  @external_pass_id = args[:external_pass_id] if args.key?(:external_pass_id)
  @update_uri = args[:update_uri] if args.key?(:update_uri)
  @updated_pass_jwt_signature = args[:updated_pass_jwt_signature] if args.key?(:updated_pass_jwt_signature)
end