Class: Google::Apis::WalletobjectsV1::TextModuleData

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Overview

Data for Text module. All fields are optional. Header will be displayed if available, different types of bodies will be concatenated if they are defined.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TextModuleData

Returns a new instance of TextModuleData.



7747
7748
7749
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7747

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#bodyString

The body of the Text Module, which is defined as an uninterrupted string. Recommended maximum length is 500 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property body

Returns:

  • (String)


7718
7719
7720
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7718

def body
  @body
end

#headerString

The header of the Text Module. Recommended maximum length is 35 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property header

Returns:

  • (String)


7724
7725
7726
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7724

def header
  @header
end

#idString

The ID associated with a text module. This field is here to enable ease of management of text modules and referencing them in template overrides. The ID should only include alphanumeric characters, '_', or '-'. It can not include dots, as dots are used to separate fields within FieldReference.fieldPaths in template overrides. Corresponds to the JSON property id

Returns:

  • (String)


7733
7734
7735
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7733

def id
  @id
end

#localized_bodyGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the body. Recommended maximum length is 500 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property localizedBody



7739
7740
7741
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7739

def localized_body
  @localized_body
end

#localized_headerGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the header. Recommended maximum length is 35 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property localizedHeader



7745
7746
7747
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7745

def localized_header
  @localized_header
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7752
7753
7754
7755
7756
7757
7758
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7752

def update!(**args)
  @body = args[:body] if args.key?(:body)
  @header = args[:header] if args.key?(:header)
  @id = args[:id] if args.key?(:id)
  @localized_body = args[:localized_body] if args.key?(:localized_body)
  @localized_header = args[:localized_header] if args.key?(:localized_header)
end