Class: Google::Apis::WalletobjectsV1::TicketLeg

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketLeg

Returns a new instance of TicketLeg.



7903
7904
7905
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7903

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#arrival_date_timeString

The date/time of arrival. This is an ISO 8601 extended format date/time, with or without an offset. Time may be specified up to nanosecond precision. Offsets may be specified with seconds precision (even though offset seconds is not part of ISO 8601). For example: 1985-04-12T23:20:50.52Z would be 20 minutes and 50.52 seconds after the 23rd hour of April 12th, 1985 in UTC. 1985-04-12T19:20:50.52-04:00 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985, 4 hours before UTC (same instant in time as the above example). If the event were in New York, this would be the equivalent of Eastern Daylight Time (EDT). Remember that offset varies in regions that observe Daylight Saving Time (or Summer Time), depending on the time of the year. 1985-04-12T19:20:50.52 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985 with no offset information. The portion of the date/time without the offset is considered the "local date/time". This should be the local date/time at the destination station. For example, if the event occurs at the 20th hour of June 5th, 2018 at the destination station, the local date/time portion should be 2018-06-05T20:00:00. If the local date/ time at the destination station is 4 hours before UTC, an offset of -04:00 may be appended. Without offset information, some rich features may not be available. Corresponds to the JSON property arrivalDateTime

Returns:

  • (String)


7810
7811
7812
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7810

def arrival_date_time
  @arrival_date_time
end

#carriageString

The train or ship name/number that the passsenger needs to board. Corresponds to the JSON property carriage

Returns:

  • (String)


7815
7816
7817
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7815

def carriage
  @carriage
end

#departure_date_timeString

The date/time of departure. This is required if there is no validity time interval set on the transit object. This is an ISO 8601 extended format date/ time, with or without an offset. Time may be specified up to nanosecond precision. Offsets may be specified with seconds precision (even though offset seconds is not part of ISO 8601). For example: 1985-04-12T23:20:50.52Z would be 20 minutes and 50.52 seconds after the 23rd hour of April 12th, 1985 in UTC. 1985-04-12T19:20:50.52-04:00 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985, 4 hours before UTC (same instant in time as the above example). If the event were in New York, this would be the equivalent of Eastern Daylight Time (EDT). Remember that offset varies in regions that observe Daylight Saving Time (or Summer Time), depending on the time of the year. 1985-04-12T19:20:50.52 would be 20 minutes and 50.52 seconds after the 19th hour of April 12th, 1985 with no offset information. The portion of the date/time without the offset is considered the "local date/ time". This should be the local date/time at the origin station. For example, if the departure occurs at the 20th hour of June 5th, 2018 at the origin station, the local date/time portion should be 2018-06-05T20:00:00. If the local date/time at the origin station is 4 hours before UTC, an offset of -04: 00 may be appended. Without offset information, some rich features may not be available. Corresponds to the JSON property departureDateTime

Returns:

  • (String)


7839
7840
7841
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7839

def departure_date_time
  @departure_date_time
end

#destination_nameGoogle::Apis::WalletobjectsV1::LocalizedString

The destination name. Corresponds to the JSON property destinationName



7844
7845
7846
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7844

def destination_name
  @destination_name
end

#destination_station_codeString

The destination station code. Corresponds to the JSON property destinationStationCode

Returns:

  • (String)


7849
7850
7851
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7849

def destination_station_code
  @destination_station_code
end

#fare_nameGoogle::Apis::WalletobjectsV1::LocalizedString

Short description/name of the fare for this leg of travel. Eg "Anytime Single Use". Corresponds to the JSON property fareName



7855
7856
7857
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7855

def fare_name
  @fare_name
end

#origin_nameGoogle::Apis::WalletobjectsV1::LocalizedString

The name of the origin station. This is required if desinationName is present or if originStationCode is not present. Corresponds to the JSON property originName



7861
7862
7863
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7861

def origin_name
  @origin_name
end

#origin_station_codeString

The origin station code. This is required if destinationStationCode is present or if originName is not present. Corresponds to the JSON property originStationCode

Returns:

  • (String)


7867
7868
7869
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7867

def origin_station_code
  @origin_station_code
end

#platformString

The platform or gate where the passenger can board the carriage. Corresponds to the JSON property platform

Returns:

  • (String)


7872
7873
7874
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7872

def platform
  @platform
end

#ticket_seatGoogle::Apis::WalletobjectsV1::TicketSeat

The reserved seat for the passenger(s). If more than one seat is to be specified then use the ticketSeats field instead. Both ticketSeat and ticketSeats may not be set. Corresponds to the JSON property ticketSeat



7879
7880
7881
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7879

def ticket_seat
  @ticket_seat
end

#ticket_seatsArray<Google::Apis::WalletobjectsV1::TicketSeat>

The reserved seat for the passenger(s). If only one seat is to be specified then use the ticketSeat field instead. Both ticketSeat and ticketSeats may not be set. Corresponds to the JSON property ticketSeats



7886
7887
7888
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7886

def ticket_seats
  @ticket_seats
end

#transit_operator_nameGoogle::Apis::WalletobjectsV1::LocalizedString

The name of the transit operator that is operating this leg of a trip. Corresponds to the JSON property transitOperatorName



7891
7892
7893
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7891

def transit_operator_name
  @transit_operator_name
end

#transit_terminus_nameGoogle::Apis::WalletobjectsV1::LocalizedString

Terminus station or destination of the train/bus/etc. Corresponds to the JSON property transitTerminusName



7896
7897
7898
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7896

def transit_terminus_name
  @transit_terminus_name
end

#zoneString

The zone of boarding within the platform. Corresponds to the JSON property zone

Returns:

  • (String)


7901
7902
7903
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7901

def zone
  @zone
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



7908
7909
7910
7911
7912
7913
7914
7915
7916
7917
7918
7919
7920
7921
7922
7923
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7908

def update!(**args)
  @arrival_date_time = args[:arrival_date_time] if args.key?(:arrival_date_time)
  @carriage = args[:carriage] if args.key?(:carriage)
  @departure_date_time = args[:departure_date_time] if args.key?(:departure_date_time)
  @destination_name = args[:destination_name] if args.key?(:destination_name)
  @destination_station_code = args[:destination_station_code] if args.key?(:destination_station_code)
  @fare_name = args[:fare_name] if args.key?(:fare_name)
  @origin_name = args[:origin_name] if args.key?(:origin_name)
  @origin_station_code = args[:origin_station_code] if args.key?(:origin_station_code)
  @platform = args[:platform] if args.key?(:platform)
  @ticket_seat = args[:ticket_seat] if args.key?(:ticket_seat)
  @ticket_seats = args[:ticket_seats] if args.key?(:ticket_seats)
  @transit_operator_name = args[:transit_operator_name] if args.key?(:transit_operator_name)
  @transit_terminus_name = args[:transit_terminus_name] if args.key?(:transit_terminus_name)
  @zone = args[:zone] if args.key?(:zone)
end