Class: Google::Apis::WalletobjectsV1::TicketSeat
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::TicketSeat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#coach ⇒ String
The identifier of the train car or coach in which the ticketed seat is located.
-
#custom_fare_class ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custome fare class to be used if no
fareClassapplies. -
#fare_class ⇒ String
The fare class of the ticketed seat.
-
#seat ⇒ String
The identifier of where the ticketed seat is located.
-
#seat_assignment ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The passenger's seat assignment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TicketSeat
constructor
A new instance of TicketSeat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TicketSeat
Returns a new instance of TicketSeat.
8065 8066 8067 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8065 def initialize(**args) update!(**args) end |
Instance Attribute Details
#coach ⇒ String
The identifier of the train car or coach in which the ticketed seat is located.
Eg. "10"
Corresponds to the JSON property coach
8040 8041 8042 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8040 def coach @coach end |
#custom_fare_class ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custome fare class to be used if no fareClass applies. Both fareClass
and customFareClass may not be set.
Corresponds to the JSON property customFareClass
8046 8047 8048 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8046 def custom_fare_class @custom_fare_class end |
#fare_class ⇒ String
The fare class of the ticketed seat.
Corresponds to the JSON property fareClass
8051 8052 8053 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8051 def fare_class @fare_class end |
#seat ⇒ String
The identifier of where the ticketed seat is located. Eg. "42". If there is no
specific identifier, use seatAssigment instead.
Corresponds to the JSON property seat
8057 8058 8059 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8057 def seat @seat end |
#seat_assignment ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The passenger's seat assignment. Eg. "no specific seat". To be used when there
is no specific identifier to use in seat.
Corresponds to the JSON property seatAssignment
8063 8064 8065 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8063 def seat_assignment @seat_assignment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8070 8071 8072 8073 8074 8075 8076 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8070 def update!(**args) @coach = args[:coach] if args.key?(:coach) @custom_fare_class = args[:custom_fare_class] if args.key?(:custom_fare_class) @fare_class = args[:fare_class] if args.key?(:fare_class) @seat = args[:seat] if args.key?(:seat) @seat_assignment = args[:seat_assignment] if args.key?(:seat_assignment) end |