Class: Google::Apis::WalletobjectsV1::TicketSeat

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TicketSeat

Returns a new instance of TicketSeat.



8004
8005
8006
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8004

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#coachString

The identifier of the train car or coach in which the ticketed seat is located. Eg. "10" Corresponds to the JSON property coach

Returns:

  • (String)


7979
7980
7981
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7979

def coach
  @coach
end

#custom_fare_classGoogle::Apis::WalletobjectsV1::LocalizedString

A custome fare class to be used if no fareClass applies. Both fareClass and customFareClass may not be set. Corresponds to the JSON property customFareClass



7985
7986
7987
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7985

def custom_fare_class
  @custom_fare_class
end

#fare_classString

The fare class of the ticketed seat. Corresponds to the JSON property fareClass

Returns:

  • (String)


7990
7991
7992
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7990

def fare_class
  @fare_class
end

#seatString

The identifier of where the ticketed seat is located. Eg. "42". If there is no specific identifier, use seatAssigment instead. Corresponds to the JSON property seat

Returns:

  • (String)


7996
7997
7998
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7996

def seat
  @seat
end

#seat_assignmentGoogle::Apis::WalletobjectsV1::LocalizedString

The passenger's seat assignment. Eg. "no specific seat". To be used when there is no specific identifier to use in seat. Corresponds to the JSON property seatAssignment



8002
8003
8004
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8002

def seat_assignment
  @seat_assignment
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8009
8010
8011
8012
8013
8014
8015
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8009

def update!(**args)
  @coach = args[:coach] if args.key?(:coach)
  @custom_fare_class = args[:custom_fare_class] if args.key?(:custom_fare_class)
  @fare_class = args[:fare_class] if args.key?(:fare_class)
  @seat = args[:seat] if args.key?(:seat)
  @seat_assignment = args[:seat_assignment] if args.key?(:seat_assignment)
end