Class: Google::Apis::WalletobjectsV1::TicketSeat
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::TicketSeat
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#coach ⇒ String
The identifier of the train car or coach in which the ticketed seat is located.
-
#custom_fare_class ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custome fare class to be used if no
fareClassapplies. -
#fare_class ⇒ String
The fare class of the ticketed seat.
-
#seat ⇒ String
The identifier of where the ticketed seat is located.
-
#seat_assignment ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The passenger's seat assignment.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TicketSeat
constructor
A new instance of TicketSeat.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TicketSeat
Returns a new instance of TicketSeat.
7997 7998 7999 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7997 def initialize(**args) update!(**args) end |
Instance Attribute Details
#coach ⇒ String
The identifier of the train car or coach in which the ticketed seat is located.
Eg. "10"
Corresponds to the JSON property coach
7972 7973 7974 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7972 def coach @coach end |
#custom_fare_class ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custome fare class to be used if no fareClass applies. Both fareClass
and customFareClass may not be set.
Corresponds to the JSON property customFareClass
7978 7979 7980 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7978 def custom_fare_class @custom_fare_class end |
#fare_class ⇒ String
The fare class of the ticketed seat.
Corresponds to the JSON property fareClass
7983 7984 7985 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7983 def fare_class @fare_class end |
#seat ⇒ String
The identifier of where the ticketed seat is located. Eg. "42". If there is no
specific identifier, use seatAssigment instead.
Corresponds to the JSON property seat
7989 7990 7991 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7989 def seat @seat end |
#seat_assignment ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The passenger's seat assignment. Eg. "no specific seat". To be used when there
is no specific identifier to use in seat.
Corresponds to the JSON property seatAssignment
7995 7996 7997 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 7995 def seat_assignment @seat_assignment end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8002 8003 8004 8005 8006 8007 8008 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8002 def update!(**args) @coach = args[:coach] if args.key?(:coach) @custom_fare_class = args[:custom_fare_class] if args.key?(:custom_fare_class) @fare_class = args[:fare_class] if args.key?(:fare_class) @seat = args[:seat] if args.key?(:seat) @seat_assignment = args[:seat_assignment] if args.key?(:seat_assignment) end |