Class: Google::Apis::WalletobjectsV1::TimeInterval

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TimeInterval

Returns a new instance of TimeInterval.



8033
8034
8035
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8033

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#endGoogle::Apis::WalletobjectsV1::DateTime

End time of the interval. Offset is not required. If an offset is provided and start time is set, start must also include an offset. Corresponds to the JSON property end



8019
8020
8021
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8019

def end
  @end
end

#kindString

Identifies what kind of resource this is. Value: the fixed string " walletobjects#timeInterval". Corresponds to the JSON property kind

Returns:

  • (String)


8025
8026
8027
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8025

def kind
  @kind
end

#startGoogle::Apis::WalletobjectsV1::DateTime

Start time of the interval. Offset is not required. If an offset is provided and end time is set, end must also include an offset. Corresponds to the JSON property start



8031
8032
8033
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8031

def start
  @start
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8038
8039
8040
8041
8042
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8038

def update!(**args)
  @end = args[:end] if args.key?(:end)
  @kind = args[:kind] if args.key?(:kind)
  @start = args[:start] if args.key?(:start)
end