Class: Google::Apis::WalletobjectsV1::TimeInterval
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::TimeInterval
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#end ⇒ Google::Apis::WalletobjectsV1::DateTime
End time of the interval.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#start ⇒ Google::Apis::WalletobjectsV1::DateTime
Start time of the interval.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TimeInterval
constructor
A new instance of TimeInterval.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TimeInterval
Returns a new instance of TimeInterval.
8019 8020 8021 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8019 def initialize(**args) update!(**args) end |
Instance Attribute Details
#end ⇒ Google::Apis::WalletobjectsV1::DateTime
End time of the interval. Offset is not required. If an offset is provided and
start time is set, start must also include an offset.
Corresponds to the JSON property end
8005 8006 8007 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8005 def end @end end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#timeInterval".
Corresponds to the JSON property kind
8011 8012 8013 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8011 def kind @kind end |
#start ⇒ Google::Apis::WalletobjectsV1::DateTime
Start time of the interval. Offset is not required. If an offset is provided
and end time is set, end must also include an offset.
Corresponds to the JSON property start
8017 8018 8019 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8017 def start @start end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8024 8025 8026 8027 8028 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8024 def update!(**args) @end = args[:end] if args.key?(:end) @kind = args[:kind] if args.key?(:kind) @start = args[:start] if args.key?(:start) end |