Class: Google::Apis::WalletobjectsV1::TransitClass
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::TransitClass
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#activation_options ⇒ Google::Apis::WalletobjectsV1::ActivationOptions
ActivationOptions for the class Corresponds to the JSON property
activationOptions. -
#allow_multiple_users_per_object ⇒ Boolean
(also: #allow_multiple_users_per_object?)
Deprecated.
-
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front of the pass.
-
#callback_options ⇒ Google::Apis::WalletobjectsV1::CallbackOptions
Callback options to be used to call the issuer back for every save/delete of an object for this class by the end-user.
-
#class_template_info ⇒ Google::Apis::WalletobjectsV1::ClassTemplateInfo
Template information about how the class should be displayed.
-
#country_code ⇒ String
Country code used to display the card's country (when the user is not in that country), as well as to display localized content when content is not available in the user's locale.
-
#custom_carriage_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the carriage value (
transitObject.ticketLeg. carriage). -
#custom_coach_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the coach value (
transitObject.ticketLeg.ticketSeat. coach). -
#custom_concession_category_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit concession category value (
transitObject.concessionCategory). -
#custom_confirmation_code_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the confirmation code value (
transitObject. purchaseDetails.confirmationCode). -
#custom_discount_message_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit discount message value (
transitObject. purchaseDetails.ticketCost.discountMessage). -
#custom_fare_class_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the fare class value (
transitObject.ticketLeg. ticketSeat.fareClass). -
#custom_fare_name_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit fare name value (
transitObject. ticketLeg.fareName). -
#custom_other_restrictions_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the other restrictions value (
transitObject. ticketRestrictions.otherRestrictions). -
#custom_platform_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the boarding platform value (
transitObject. ticketLeg.platform). -
#custom_purchase_face_value_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the purchase face value (
transitObject. purchaseDetails.ticketCost.faceValue). -
#custom_purchase_price_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the purchase price value (
transitObject. purchaseDetails.ticketCost.purchasePrice). -
#custom_purchase_receipt_number_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the purchase receipt number value (
transitObject. purchaseDetails.purchaseReceiptNumber). -
#custom_route_restrictions_details_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the route restrictions details value (
transitObject. ticketRestrictions.routeRestrictionsDetails). -
#custom_route_restrictions_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the route restrictions value (
transitObject. ticketRestrictions.routeRestrictions). -
#custom_seat_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the seat location value (
transitObject.ticketLeg. ticketSeat.seat). -
#custom_ticket_number_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the ticket number value (
transitObject.ticketNumber). -
#custom_time_restrictions_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the time restrictions details value (
transitObject. ticketRestrictions.timeRestrictions). -
#custom_transit_terminus_name_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit terminus name value (
transitObject. ticketLeg.transitTerminusName). -
#custom_zone_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the boarding zone value (
transitObject.ticketLeg. zone). -
#enable_single_leg_itinerary ⇒ Boolean
(also: #enable_single_leg_itinerary?)
Controls the display of the single-leg itinerary for this class.
-
#enable_smart_tap ⇒ Boolean
(also: #enable_smart_tap?)
Identifies whether this class supports Smart Tap.
-
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#hex_background_color ⇒ String
The background color for the card.
-
#homepage_uri ⇒ Google::Apis::WalletobjectsV1::Uri
The URI of your application's home page.
-
#id ⇒ String
Required.
-
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data.
-
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated.
-
#issuer_name ⇒ String
Required.
-
#language_override ⇒ String
If this field is present, transit tickets served to a user's device will always be in this language.
-
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data.
-
#localized_issuer_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the issuer_name.
-
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
-
#logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations.
-
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app.
-
#multiple_devices_and_holders_allowed_status ⇒ String
Identifies whether multiple users and devices will save the same object referencing this class.
-
#notify_preference ⇒ String
Whether or not field updates to this class should trigger notifications.
-
#redemption_issuers ⇒ Array<Fixnum>
Identifies which redemption issuers can redeem the pass over Smart Tap.
-
#review ⇒ Google::Apis::WalletobjectsV1::Review
The review comments set by the platform when a class is marked
approvedorrejected. -
#review_status ⇒ String
Required.
-
#security_animation ⇒ Google::Apis::WalletobjectsV1::SecurityAnimation
Optional information about the security animation.
-
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data.
-
#transit_operator_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The name of the transit operator.
-
#transit_type ⇒ String
Required.
-
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data.
-
#version ⇒ Fixnum
Deprecated Corresponds to the JSON property
version. -
#view_unlock_requirement ⇒ String
View Unlock Requirement options for the transit ticket.
-
#watermark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#wide_logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
-
#word_mark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Instance Method Summary collapse
-
#initialize(**args) ⇒ TransitClass
constructor
A new instance of TransitClass.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ TransitClass
Returns a new instance of TransitClass.
8474 8475 8476 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8474 def initialize(**args) update!(**args) end |
Instance Attribute Details
#activation_options ⇒ Google::Apis::WalletobjectsV1::ActivationOptions
ActivationOptions for the class
Corresponds to the JSON property activationOptions
8120 8121 8122 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8120 def @activation_options end |
#allow_multiple_users_per_object ⇒ Boolean Also known as: allow_multiple_users_per_object?
Deprecated. Use multipleDevicesAndHoldersAllowedStatus instead.
Corresponds to the JSON property allowMultipleUsersPerObject
8125 8126 8127 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8125 def allow_multiple_users_per_object @allow_multiple_users_per_object end |
#app_link_data ⇒ Google::Apis::WalletobjectsV1::AppLinkData
Optional app or website link that will be displayed as a button on the front
of the pass. If AppLinkData is provided for the corresponding object that will
be used instead.
Corresponds to the JSON property appLinkData
8133 8134 8135 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8133 def app_link_data @app_link_data end |
#callback_options ⇒ Google::Apis::WalletobjectsV1::CallbackOptions
Callback options to be used to call the issuer back for every save/delete of
an object for this class by the end-user. All objects of this class are
eligible for the callback.
Corresponds to the JSON property callbackOptions
8140 8141 8142 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8140 def @callback_options end |
#class_template_info ⇒ Google::Apis::WalletobjectsV1::ClassTemplateInfo
Template information about how the class should be displayed. If unset, Google
will fallback to a default set of fields to display.
Corresponds to the JSON property classTemplateInfo
8146 8147 8148 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8146 def class_template_info @class_template_info end |
#country_code ⇒ String
Country code used to display the card's country (when the user is not in that
country), as well as to display localized content when content is not
available in the user's locale.
Corresponds to the JSON property countryCode
8153 8154 8155 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8153 def country_code @country_code end |
#custom_carriage_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the carriage value (transitObject.ticketLeg.
carriage).
Corresponds to the JSON property customCarriageLabel
8159 8160 8161 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8159 def custom_carriage_label @custom_carriage_label end |
#custom_coach_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the coach value (transitObject.ticketLeg.ticketSeat.
coach).
Corresponds to the JSON property customCoachLabel
8165 8166 8167 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8165 def custom_coach_label @custom_coach_label end |
#custom_concession_category_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit concession category value (
transitObject.concessionCategory).
Corresponds to the JSON property customConcessionCategoryLabel
8171 8172 8173 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8171 def custom_concession_category_label @custom_concession_category_label end |
#custom_confirmation_code_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the confirmation code value (transitObject.
purchaseDetails.confirmationCode).
Corresponds to the JSON property customConfirmationCodeLabel
8177 8178 8179 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8177 def custom_confirmation_code_label @custom_confirmation_code_label end |
#custom_discount_message_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit discount message value (transitObject.
purchaseDetails.ticketCost.discountMessage).
Corresponds to the JSON property customDiscountMessageLabel
8183 8184 8185 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8183 def @custom_discount_message_label end |
#custom_fare_class_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the fare class value (transitObject.ticketLeg.
ticketSeat.fareClass).
Corresponds to the JSON property customFareClassLabel
8189 8190 8191 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8189 def custom_fare_class_label @custom_fare_class_label end |
#custom_fare_name_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit fare name value (transitObject.
ticketLeg.fareName).
Corresponds to the JSON property customFareNameLabel
8195 8196 8197 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8195 def custom_fare_name_label @custom_fare_name_label end |
#custom_other_restrictions_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the other restrictions value (transitObject.
ticketRestrictions.otherRestrictions).
Corresponds to the JSON property customOtherRestrictionsLabel
8201 8202 8203 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8201 def custom_other_restrictions_label @custom_other_restrictions_label end |
#custom_platform_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the boarding platform value (transitObject.
ticketLeg.platform).
Corresponds to the JSON property customPlatformLabel
8207 8208 8209 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8207 def custom_platform_label @custom_platform_label end |
#custom_purchase_face_value_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the purchase face value (transitObject.
purchaseDetails.ticketCost.faceValue).
Corresponds to the JSON property customPurchaseFaceValueLabel
8213 8214 8215 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8213 def custom_purchase_face_value_label @custom_purchase_face_value_label end |
#custom_purchase_price_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the purchase price value (transitObject.
purchaseDetails.ticketCost.purchasePrice).
Corresponds to the JSON property customPurchasePriceLabel
8219 8220 8221 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8219 def custom_purchase_price_label @custom_purchase_price_label end |
#custom_purchase_receipt_number_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the purchase receipt number value (transitObject.
purchaseDetails.purchaseReceiptNumber).
Corresponds to the JSON property customPurchaseReceiptNumberLabel
8225 8226 8227 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8225 def custom_purchase_receipt_number_label @custom_purchase_receipt_number_label end |
#custom_route_restrictions_details_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the route restrictions details value (transitObject.
ticketRestrictions.routeRestrictionsDetails).
Corresponds to the JSON property customRouteRestrictionsDetailsLabel
8231 8232 8233 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8231 def custom_route_restrictions_details_label @custom_route_restrictions_details_label end |
#custom_route_restrictions_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the route restrictions value (transitObject.
ticketRestrictions.routeRestrictions).
Corresponds to the JSON property customRouteRestrictionsLabel
8237 8238 8239 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8237 def custom_route_restrictions_label @custom_route_restrictions_label end |
#custom_seat_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the seat location value (transitObject.ticketLeg.
ticketSeat.seat).
Corresponds to the JSON property customSeatLabel
8243 8244 8245 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8243 def custom_seat_label @custom_seat_label end |
#custom_ticket_number_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the ticket number value (transitObject.ticketNumber
).
Corresponds to the JSON property customTicketNumberLabel
8249 8250 8251 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8249 def custom_ticket_number_label @custom_ticket_number_label end |
#custom_time_restrictions_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the time restrictions details value (transitObject.
ticketRestrictions.timeRestrictions).
Corresponds to the JSON property customTimeRestrictionsLabel
8255 8256 8257 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8255 def custom_time_restrictions_label @custom_time_restrictions_label end |
#custom_transit_terminus_name_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the transit terminus name value (transitObject.
ticketLeg.transitTerminusName).
Corresponds to the JSON property customTransitTerminusNameLabel
8261 8262 8263 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8261 def custom_transit_terminus_name_label @custom_transit_terminus_name_label end |
#custom_zone_label ⇒ Google::Apis::WalletobjectsV1::LocalizedString
A custom label to use for the boarding zone value (transitObject.ticketLeg.
zone).
Corresponds to the JSON property customZoneLabel
8267 8268 8269 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8267 def custom_zone_label @custom_zone_label end |
#enable_single_leg_itinerary ⇒ Boolean Also known as: enable_single_leg_itinerary?
Controls the display of the single-leg itinerary for this class. By default,
an itinerary will only display for multi-leg trips.
Corresponds to the JSON property enableSingleLegItinerary
8273 8274 8275 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8273 def enable_single_leg_itinerary @enable_single_leg_itinerary end |
#enable_smart_tap ⇒ Boolean Also known as: enable_smart_tap?
Identifies whether this class supports Smart Tap. The redemptionIssuers and
object level smartTapRedemptionLevel fields must also be set up correctly in
order for a pass to support Smart Tap.
Corresponds to the JSON property enableSmartTap
8281 8282 8283 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8281 def enable_smart_tap @enable_smart_tap end |
#hero_image ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property heroImage
8287 8288 8289 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8287 def hero_image @hero_image end |
#hex_background_color ⇒ String
The background color for the card. If not set the dominant color of the hero
image is used, and if no hero image is set, the dominant color of the logo is
used. The format is #rrggbb where rrggbb is a hex RGB triplet, such as #
ffcc00. You can also use the shorthand version of the RGB triplet which is #
rgb, such as #fc0.
Corresponds to the JSON property hexBackgroundColor
8296 8297 8298 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8296 def hex_background_color @hex_background_color end |
#homepage_uri ⇒ Google::Apis::WalletobjectsV1::Uri
The URI of your application's home page. Populating the URI in this field
results in the exact same behavior as populating an URI in linksModuleData (
when an object is rendered, a link to the homepage is shown in what would
usually be thought of as the linksModuleData section of the object).
Corresponds to the JSON property homepageUri
8304 8305 8306 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8304 def homepage_uri @homepage_uri end |
#id ⇒ String
Required. The unique identifier for a class. This ID must be unique across all
classes from an issuer. This value should follow the format issuer ID.
identifier where the former is issued by Google and latter is chosen by you.
Your unique identifier should only include alphanumeric characters, '.', '_',
or '-'.
Corresponds to the JSON property id
8313 8314 8315 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8313 def id @id end |
#image_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::ImageModuleData>
Image module data. The maximum number of these fields displayed is 1 from
object level and 1 for class object level.
Corresponds to the JSON property imageModulesData
8319 8320 8321 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8319 def image_modules_data @image_modules_data end |
#info_module_data ⇒ Google::Apis::WalletobjectsV1::InfoModuleData
Deprecated. Use textModulesData instead.
Corresponds to the JSON property infoModuleData
8324 8325 8326 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8324 def info_module_data @info_module_data end |
#issuer_name ⇒ String
Required. The issuer name. Recommended maximum length is 20 characters to
ensure full string is displayed on smaller screens.
Corresponds to the JSON property issuerName
8330 8331 8332 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8330 def issuer_name @issuer_name end |
#language_override ⇒ String
If this field is present, transit tickets served to a user's device will
always be in this language. Represents the BCP 47 language tag. Example values
are "en-US", "en-GB", "de", or "de-AT".
Corresponds to the JSON property languageOverride
8337 8338 8339 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8337 def language_override @language_override end |
#links_module_data ⇒ Google::Apis::WalletobjectsV1::LinksModuleData
Links module data. If links module data is also defined on the object, both
will be displayed.
Corresponds to the JSON property linksModuleData
8343 8344 8345 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8343 def links_module_data @links_module_data end |
#localized_issuer_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the issuer_name. Recommended maximum length is 20
characters to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedIssuerName
8349 8350 8351 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8349 def localized_issuer_name @localized_issuer_name end |
#locations ⇒ Array<Google::Apis::WalletobjectsV1::LatLongPoint>
Note: This field is currently not supported to trigger geo notifications.
Corresponds to the JSON property locations
8354 8355 8356 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8354 def locations @locations end |
#logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property logo
8359 8360 8361 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8359 def logo @logo end |
#merchant_locations ⇒ Array<Google::Apis::WalletobjectsV1::MerchantLocation>
Merchant locations. There is a maximum of ten on the class. Any additional
MerchantLocations added beyond the 10 will be rejected. These locations will
trigger a notification when a user enters within a Google-set radius of the
point. This field replaces the deprecated LatLongPoints.
Corresponds to the JSON property merchantLocations
8367 8368 8369 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8367 def merchant_locations @merchant_locations end |
#messages ⇒ Array<Google::Apis::WalletobjectsV1::Message>
An array of messages displayed in the app. All users of this object will
receive its associated messages. The maximum number of these fields is 10.
Corresponds to the JSON property messages
8373 8374 8375 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8373 def @messages end |
#multiple_devices_and_holders_allowed_status ⇒ String
Identifies whether multiple users and devices will save the same object
referencing this class.
Corresponds to the JSON property multipleDevicesAndHoldersAllowedStatus
8379 8380 8381 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8379 def multiple_devices_and_holders_allowed_status @multiple_devices_and_holders_allowed_status end |
#notify_preference ⇒ String
Whether or not field updates to this class should trigger notifications. When
set to NOTIFY, we will attempt to trigger a field update notification to users.
These notifications will only be sent to users if the field is part of an
allowlist. If set to DO_NOT_NOTIFY or NOTIFICATION_SETTINGS_UNSPECIFIED, no
notification will be triggered. This setting is ephemeral and needs to be set
with each PATCH or UPDATE request, otherwise a notification will not be
triggered.
Corresponds to the JSON property notifyPreference
8390 8391 8392 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8390 def notify_preference @notify_preference end |
#redemption_issuers ⇒ Array<Fixnum>
Identifies which redemption issuers can redeem the pass over Smart Tap.
Redemption issuers are identified by their issuer ID. Redemption issuers must
have at least one Smart Tap key configured. The enableSmartTap and object
level smartTapRedemptionLevel fields must also be set up correctly in order
for a pass to support Smart Tap.
Corresponds to the JSON property redemptionIssuers
8399 8400 8401 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8399 def redemption_issuers @redemption_issuers end |
#review ⇒ Google::Apis::WalletobjectsV1::Review
The review comments set by the platform when a class is marked approved or
rejected.
Corresponds to the JSON property review
8405 8406 8407 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8405 def review @review end |
#review_status ⇒ String
Required. The status of the class. This field can be set to draft or
underReview using the insert, patch, or update API calls. Once the review
state is changed from draft it may not be changed back to draft. You
should keep this field to draft when the class is under development. A
draft class cannot be used to create any object. You should set this field to
underReview when you believe the class is ready for use. The platform will
automatically set this field to approved and it can be immediately used to
create or migrate objects. When updating an already approved class you
should keep setting this field to underReview.
Corresponds to the JSON property reviewStatus
8418 8419 8420 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8418 def review_status @review_status end |
#security_animation ⇒ Google::Apis::WalletobjectsV1::SecurityAnimation
Optional information about the security animation. If this is set a security
animation will be rendered on pass details.
Corresponds to the JSON property securityAnimation
8424 8425 8426 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8424 def security_animation @security_animation end |
#text_modules_data ⇒ Array<Google::Apis::WalletobjectsV1::TextModuleData>
Text module data. If text module data is also defined on the class, both will
be displayed. The maximum number of these fields displayed is 10 from the
object and 10 from the class.
Corresponds to the JSON property textModulesData
8431 8432 8433 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8431 def text_modules_data @text_modules_data end |
#transit_operator_name ⇒ Google::Apis::WalletobjectsV1::LocalizedString
The name of the transit operator.
Corresponds to the JSON property transitOperatorName
8436 8437 8438 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8436 def transit_operator_name @transit_operator_name end |
#transit_type ⇒ String
Required. The type of transit this class represents, such as "bus".
Corresponds to the JSON property transitType
8441 8442 8443 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8441 def transit_type @transit_type end |
#value_added_module_data ⇒ Array<Google::Apis::WalletobjectsV1::ValueAddedModuleData>
Optional value added module data. Maximum of fifteen on the class. For a pass
only fifteen will be displayed, prioritizing those from the object.
Corresponds to the JSON property valueAddedModuleData
8447 8448 8449 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8447 def value_added_module_data @value_added_module_data end |
#version ⇒ Fixnum
Deprecated
Corresponds to the JSON property version
8452 8453 8454 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8452 def version @version end |
#view_unlock_requirement ⇒ String
View Unlock Requirement options for the transit ticket.
Corresponds to the JSON property viewUnlockRequirement
8457 8458 8459 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8457 def view_unlock_requirement @view_unlock_requirement end |
#watermark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property watermark
8462 8463 8464 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8462 def watermark @watermark end |
#wide_logo ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property wideLogo
8467 8468 8469 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8467 def wide_logo @wide_logo end |
#word_mark ⇒ Google::Apis::WalletobjectsV1::Image
Wrapping type for Google hosted images.
Corresponds to the JSON property wordMark
8472 8473 8474 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8472 def word_mark @word_mark end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
8479 8480 8481 8482 8483 8484 8485 8486 8487 8488 8489 8490 8491 8492 8493 8494 8495 8496 8497 8498 8499 8500 8501 8502 8503 8504 8505 8506 8507 8508 8509 8510 8511 8512 8513 8514 8515 8516 8517 8518 8519 8520 8521 8522 8523 8524 8525 8526 8527 8528 8529 8530 8531 8532 8533 8534 8535 8536 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8479 def update!(**args) @activation_options = args[:activation_options] if args.key?(:activation_options) @allow_multiple_users_per_object = args[:allow_multiple_users_per_object] if args.key?(:allow_multiple_users_per_object) @app_link_data = args[:app_link_data] if args.key?(:app_link_data) @callback_options = args[:callback_options] if args.key?(:callback_options) @class_template_info = args[:class_template_info] if args.key?(:class_template_info) @country_code = args[:country_code] if args.key?(:country_code) @custom_carriage_label = args[:custom_carriage_label] if args.key?(:custom_carriage_label) @custom_coach_label = args[:custom_coach_label] if args.key?(:custom_coach_label) @custom_concession_category_label = args[:custom_concession_category_label] if args.key?(:custom_concession_category_label) @custom_confirmation_code_label = args[:custom_confirmation_code_label] if args.key?(:custom_confirmation_code_label) @custom_discount_message_label = args[:custom_discount_message_label] if args.key?(:custom_discount_message_label) @custom_fare_class_label = args[:custom_fare_class_label] if args.key?(:custom_fare_class_label) @custom_fare_name_label = args[:custom_fare_name_label] if args.key?(:custom_fare_name_label) @custom_other_restrictions_label = args[:custom_other_restrictions_label] if args.key?(:custom_other_restrictions_label) @custom_platform_label = args[:custom_platform_label] if args.key?(:custom_platform_label) @custom_purchase_face_value_label = args[:custom_purchase_face_value_label] if args.key?(:custom_purchase_face_value_label) @custom_purchase_price_label = args[:custom_purchase_price_label] if args.key?(:custom_purchase_price_label) @custom_purchase_receipt_number_label = args[:custom_purchase_receipt_number_label] if args.key?(:custom_purchase_receipt_number_label) @custom_route_restrictions_details_label = args[:custom_route_restrictions_details_label] if args.key?(:custom_route_restrictions_details_label) @custom_route_restrictions_label = args[:custom_route_restrictions_label] if args.key?(:custom_route_restrictions_label) @custom_seat_label = args[:custom_seat_label] if args.key?(:custom_seat_label) @custom_ticket_number_label = args[:custom_ticket_number_label] if args.key?(:custom_ticket_number_label) @custom_time_restrictions_label = args[:custom_time_restrictions_label] if args.key?(:custom_time_restrictions_label) @custom_transit_terminus_name_label = args[:custom_transit_terminus_name_label] if args.key?(:custom_transit_terminus_name_label) @custom_zone_label = args[:custom_zone_label] if args.key?(:custom_zone_label) @enable_single_leg_itinerary = args[:enable_single_leg_itinerary] if args.key?(:enable_single_leg_itinerary) @enable_smart_tap = args[:enable_smart_tap] if args.key?(:enable_smart_tap) @hero_image = args[:hero_image] if args.key?(:hero_image) @hex_background_color = args[:hex_background_color] if args.key?(:hex_background_color) @homepage_uri = args[:homepage_uri] if args.key?(:homepage_uri) @id = args[:id] if args.key?(:id) @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data) @info_module_data = args[:info_module_data] if args.key?(:info_module_data) @issuer_name = args[:issuer_name] if args.key?(:issuer_name) @language_override = args[:language_override] if args.key?(:language_override) @links_module_data = args[:links_module_data] if args.key?(:links_module_data) @localized_issuer_name = args[:localized_issuer_name] if args.key?(:localized_issuer_name) @locations = args[:locations] if args.key?(:locations) @logo = args[:logo] if args.key?(:logo) @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations) @messages = args[:messages] if args.key?(:messages) @multiple_devices_and_holders_allowed_status = args[:multiple_devices_and_holders_allowed_status] if args.key?(:multiple_devices_and_holders_allowed_status) @notify_preference = args[:notify_preference] if args.key?(:notify_preference) @redemption_issuers = args[:redemption_issuers] if args.key?(:redemption_issuers) @review = args[:review] if args.key?(:review) @review_status = args[:review_status] if args.key?(:review_status) @security_animation = args[:security_animation] if args.key?(:security_animation) @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data) @transit_operator_name = args[:transit_operator_name] if args.key?(:transit_operator_name) @transit_type = args[:transit_type] if args.key?(:transit_type) @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data) @version = args[:version] if args.key?(:version) @view_unlock_requirement = args[:view_unlock_requirement] if args.key?(:view_unlock_requirement) @watermark = args[:watermark] if args.key?(:watermark) @wide_logo = args[:wide_logo] if args.key?(:wide_logo) @word_mark = args[:word_mark] if args.key?(:word_mark) end |