Class: Google::Apis::WalletobjectsV1::TransitClass

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ TransitClass

Returns a new instance of TransitClass.



8406
8407
8408
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8406

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#activation_optionsGoogle::Apis::WalletobjectsV1::ActivationOptions

ActivationOptions for the class Corresponds to the JSON property activationOptions



8052
8053
8054
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8052

def activation_options
  @activation_options
end

#allow_multiple_users_per_objectBoolean Also known as: allow_multiple_users_per_object?

Deprecated. Use multipleDevicesAndHoldersAllowedStatus instead. Corresponds to the JSON property allowMultipleUsersPerObject

Returns:

  • (Boolean)


8057
8058
8059
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8057

def allow_multiple_users_per_object
  @allow_multiple_users_per_object
end

Optional app or website link that will be displayed as a button on the front of the pass. If AppLinkData is provided for the corresponding object that will be used instead. Corresponds to the JSON property appLinkData



8065
8066
8067
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8065

def app_link_data
  @app_link_data
end

#callback_optionsGoogle::Apis::WalletobjectsV1::CallbackOptions

Callback options to be used to call the issuer back for every save/delete of an object for this class by the end-user. All objects of this class are eligible for the callback. Corresponds to the JSON property callbackOptions



8072
8073
8074
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8072

def callback_options
  @callback_options
end

#class_template_infoGoogle::Apis::WalletobjectsV1::ClassTemplateInfo

Template information about how the class should be displayed. If unset, Google will fallback to a default set of fields to display. Corresponds to the JSON property classTemplateInfo



8078
8079
8080
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8078

def class_template_info
  @class_template_info
end

#country_codeString

Country code used to display the card's country (when the user is not in that country), as well as to display localized content when content is not available in the user's locale. Corresponds to the JSON property countryCode

Returns:

  • (String)


8085
8086
8087
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8085

def country_code
  @country_code
end

#custom_carriage_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the carriage value (transitObject.ticketLeg. carriage). Corresponds to the JSON property customCarriageLabel



8091
8092
8093
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8091

def custom_carriage_label
  @custom_carriage_label
end

#custom_coach_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the coach value (transitObject.ticketLeg.ticketSeat. coach). Corresponds to the JSON property customCoachLabel



8097
8098
8099
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8097

def custom_coach_label
  @custom_coach_label
end

#custom_concession_category_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the transit concession category value ( transitObject.concessionCategory). Corresponds to the JSON property customConcessionCategoryLabel



8103
8104
8105
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8103

def custom_concession_category_label
  @custom_concession_category_label
end

#custom_confirmation_code_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the confirmation code value (transitObject. purchaseDetails.confirmationCode). Corresponds to the JSON property customConfirmationCodeLabel



8109
8110
8111
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8109

def custom_confirmation_code_label
  @custom_confirmation_code_label
end

#custom_discount_message_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the transit discount message value (transitObject. purchaseDetails.ticketCost.discountMessage). Corresponds to the JSON property customDiscountMessageLabel



8115
8116
8117
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8115

def custom_discount_message_label
  @custom_discount_message_label
end

#custom_fare_class_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the fare class value (transitObject.ticketLeg. ticketSeat.fareClass). Corresponds to the JSON property customFareClassLabel



8121
8122
8123
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8121

def custom_fare_class_label
  @custom_fare_class_label
end

#custom_fare_name_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the transit fare name value (transitObject. ticketLeg.fareName). Corresponds to the JSON property customFareNameLabel



8127
8128
8129
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8127

def custom_fare_name_label
  @custom_fare_name_label
end

#custom_other_restrictions_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the other restrictions value (transitObject. ticketRestrictions.otherRestrictions). Corresponds to the JSON property customOtherRestrictionsLabel



8133
8134
8135
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8133

def custom_other_restrictions_label
  @custom_other_restrictions_label
end

#custom_platform_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the boarding platform value (transitObject. ticketLeg.platform). Corresponds to the JSON property customPlatformLabel



8139
8140
8141
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8139

def custom_platform_label
  @custom_platform_label
end

#custom_purchase_face_value_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the purchase face value (transitObject. purchaseDetails.ticketCost.faceValue). Corresponds to the JSON property customPurchaseFaceValueLabel



8145
8146
8147
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8145

def custom_purchase_face_value_label
  @custom_purchase_face_value_label
end

#custom_purchase_price_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the purchase price value (transitObject. purchaseDetails.ticketCost.purchasePrice). Corresponds to the JSON property customPurchasePriceLabel



8151
8152
8153
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8151

def custom_purchase_price_label
  @custom_purchase_price_label
end

#custom_purchase_receipt_number_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the purchase receipt number value (transitObject. purchaseDetails.purchaseReceiptNumber). Corresponds to the JSON property customPurchaseReceiptNumberLabel



8157
8158
8159
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8157

def custom_purchase_receipt_number_label
  @custom_purchase_receipt_number_label
end

#custom_route_restrictions_details_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the route restrictions details value (transitObject. ticketRestrictions.routeRestrictionsDetails). Corresponds to the JSON property customRouteRestrictionsDetailsLabel



8163
8164
8165
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8163

def custom_route_restrictions_details_label
  @custom_route_restrictions_details_label
end

#custom_route_restrictions_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the route restrictions value (transitObject. ticketRestrictions.routeRestrictions). Corresponds to the JSON property customRouteRestrictionsLabel



8169
8170
8171
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8169

def custom_route_restrictions_label
  @custom_route_restrictions_label
end

#custom_seat_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the seat location value (transitObject.ticketLeg. ticketSeat.seat). Corresponds to the JSON property customSeatLabel



8175
8176
8177
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8175

def custom_seat_label
  @custom_seat_label
end

#custom_ticket_number_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the ticket number value (transitObject.ticketNumber ). Corresponds to the JSON property customTicketNumberLabel



8181
8182
8183
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8181

def custom_ticket_number_label
  @custom_ticket_number_label
end

#custom_time_restrictions_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the time restrictions details value (transitObject. ticketRestrictions.timeRestrictions). Corresponds to the JSON property customTimeRestrictionsLabel



8187
8188
8189
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8187

def custom_time_restrictions_label
  @custom_time_restrictions_label
end

#custom_transit_terminus_name_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the transit terminus name value (transitObject. ticketLeg.transitTerminusName). Corresponds to the JSON property customTransitTerminusNameLabel



8193
8194
8195
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8193

def custom_transit_terminus_name_label
  @custom_transit_terminus_name_label
end

#custom_zone_labelGoogle::Apis::WalletobjectsV1::LocalizedString

A custom label to use for the boarding zone value (transitObject.ticketLeg. zone). Corresponds to the JSON property customZoneLabel



8199
8200
8201
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8199

def custom_zone_label
  @custom_zone_label
end

#enable_single_leg_itineraryBoolean Also known as: enable_single_leg_itinerary?

Controls the display of the single-leg itinerary for this class. By default, an itinerary will only display for multi-leg trips. Corresponds to the JSON property enableSingleLegItinerary

Returns:

  • (Boolean)


8205
8206
8207
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8205

def enable_single_leg_itinerary
  @enable_single_leg_itinerary
end

#enable_smart_tapBoolean Also known as: enable_smart_tap?

Identifies whether this class supports Smart Tap. The redemptionIssuers and object level smartTapRedemptionLevel fields must also be set up correctly in order for a pass to support Smart Tap. Corresponds to the JSON property enableSmartTap

Returns:

  • (Boolean)


8213
8214
8215
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8213

def enable_smart_tap
  @enable_smart_tap
end

#hero_imageGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property heroImage



8219
8220
8221
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8219

def hero_image
  @hero_image
end

#hex_background_colorString

The background color for the card. If not set the dominant color of the hero image is used, and if no hero image is set, the dominant color of the logo is used. The format is #rrggbb where rrggbb is a hex RGB triplet, such as # ffcc00. You can also use the shorthand version of the RGB triplet which is # rgb, such as #fc0. Corresponds to the JSON property hexBackgroundColor

Returns:

  • (String)


8228
8229
8230
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8228

def hex_background_color
  @hex_background_color
end

#homepage_uriGoogle::Apis::WalletobjectsV1::Uri

The URI of your application's home page. Populating the URI in this field results in the exact same behavior as populating an URI in linksModuleData ( when an object is rendered, a link to the homepage is shown in what would usually be thought of as the linksModuleData section of the object). Corresponds to the JSON property homepageUri



8236
8237
8238
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8236

def homepage_uri
  @homepage_uri
end

#idString

Required. The unique identifier for a class. This ID must be unique across all classes from an issuer. This value should follow the format issuer ID. identifier where the former is issued by Google and latter is chosen by you. Your unique identifier should only include alphanumeric characters, '.', '_', or '-'. Corresponds to the JSON property id

Returns:

  • (String)


8245
8246
8247
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8245

def id
  @id
end

#image_modules_dataArray<Google::Apis::WalletobjectsV1::ImageModuleData>

Image module data. The maximum number of these fields displayed is 1 from object level and 1 for class object level. Corresponds to the JSON property imageModulesData



8251
8252
8253
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8251

def image_modules_data
  @image_modules_data
end

#info_module_dataGoogle::Apis::WalletobjectsV1::InfoModuleData

Deprecated. Use textModulesData instead. Corresponds to the JSON property infoModuleData



8256
8257
8258
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8256

def info_module_data
  @info_module_data
end

#issuer_nameString

Required. The issuer name. Recommended maximum length is 20 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property issuerName

Returns:

  • (String)


8262
8263
8264
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8262

def issuer_name
  @issuer_name
end

#language_overrideString

If this field is present, transit tickets served to a user's device will always be in this language. Represents the BCP 47 language tag. Example values are "en-US", "en-GB", "de", or "de-AT". Corresponds to the JSON property languageOverride

Returns:

  • (String)


8269
8270
8271
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8269

def language_override
  @language_override
end

Links module data. If links module data is also defined on the object, both will be displayed. Corresponds to the JSON property linksModuleData



8275
8276
8277
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8275

def links_module_data
  @links_module_data
end

#localized_issuer_nameGoogle::Apis::WalletobjectsV1::LocalizedString

Translated strings for the issuer_name. Recommended maximum length is 20 characters to ensure full string is displayed on smaller screens. Corresponds to the JSON property localizedIssuerName



8281
8282
8283
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8281

def localized_issuer_name
  @localized_issuer_name
end

#locationsArray<Google::Apis::WalletobjectsV1::LatLongPoint>

Note: This field is currently not supported to trigger geo notifications. Corresponds to the JSON property locations



8286
8287
8288
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8286

def locations
  @locations
end

#logoGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property logo



8291
8292
8293
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8291

def 
  @logo
end

#merchant_locationsArray<Google::Apis::WalletobjectsV1::MerchantLocation>

Merchant locations. There is a maximum of ten on the class. Any additional MerchantLocations added beyond the 10 will be rejected. These locations will trigger a notification when a user enters within a Google-set radius of the point. This field replaces the deprecated LatLongPoints. Corresponds to the JSON property merchantLocations



8299
8300
8301
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8299

def merchant_locations
  @merchant_locations
end

#messagesArray<Google::Apis::WalletobjectsV1::Message>

An array of messages displayed in the app. All users of this object will receive its associated messages. The maximum number of these fields is 10. Corresponds to the JSON property messages



8305
8306
8307
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8305

def messages
  @messages
end

#multiple_devices_and_holders_allowed_statusString

Identifies whether multiple users and devices will save the same object referencing this class. Corresponds to the JSON property multipleDevicesAndHoldersAllowedStatus

Returns:

  • (String)


8311
8312
8313
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8311

def multiple_devices_and_holders_allowed_status
  @multiple_devices_and_holders_allowed_status
end

#notify_preferenceString

Whether or not field updates to this class should trigger notifications. When set to NOTIFY, we will attempt to trigger a field update notification to users. These notifications will only be sent to users if the field is part of an allowlist. If set to DO_NOT_NOTIFY or NOTIFICATION_SETTINGS_UNSPECIFIED, no notification will be triggered. This setting is ephemeral and needs to be set with each PATCH or UPDATE request, otherwise a notification will not be triggered. Corresponds to the JSON property notifyPreference

Returns:

  • (String)


8322
8323
8324
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8322

def notify_preference
  @notify_preference
end

#redemption_issuersArray<Fixnum>

Identifies which redemption issuers can redeem the pass over Smart Tap. Redemption issuers are identified by their issuer ID. Redemption issuers must have at least one Smart Tap key configured. The enableSmartTap and object level smartTapRedemptionLevel fields must also be set up correctly in order for a pass to support Smart Tap. Corresponds to the JSON property redemptionIssuers

Returns:

  • (Array<Fixnum>)


8331
8332
8333
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8331

def redemption_issuers
  @redemption_issuers
end

#reviewGoogle::Apis::WalletobjectsV1::Review

The review comments set by the platform when a class is marked approved or rejected. Corresponds to the JSON property review



8337
8338
8339
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8337

def review
  @review
end

#review_statusString

Required. The status of the class. This field can be set to draft or underReview using the insert, patch, or update API calls. Once the review state is changed from draft it may not be changed back to draft. You should keep this field to draft when the class is under development. A draft class cannot be used to create any object. You should set this field to underReview when you believe the class is ready for use. The platform will automatically set this field to approved and it can be immediately used to create or migrate objects. When updating an already approved class you should keep setting this field to underReview. Corresponds to the JSON property reviewStatus

Returns:

  • (String)


8350
8351
8352
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8350

def review_status
  @review_status
end

#security_animationGoogle::Apis::WalletobjectsV1::SecurityAnimation

Optional information about the security animation. If this is set a security animation will be rendered on pass details. Corresponds to the JSON property securityAnimation



8356
8357
8358
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8356

def security_animation
  @security_animation
end

#text_modules_dataArray<Google::Apis::WalletobjectsV1::TextModuleData>

Text module data. If text module data is also defined on the class, both will be displayed. The maximum number of these fields displayed is 10 from the object and 10 from the class. Corresponds to the JSON property textModulesData



8363
8364
8365
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8363

def text_modules_data
  @text_modules_data
end

#transit_operator_nameGoogle::Apis::WalletobjectsV1::LocalizedString

The name of the transit operator. Corresponds to the JSON property transitOperatorName



8368
8369
8370
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8368

def transit_operator_name
  @transit_operator_name
end

#transit_typeString

Required. The type of transit this class represents, such as "bus". Corresponds to the JSON property transitType

Returns:

  • (String)


8373
8374
8375
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8373

def transit_type
  @transit_type
end

#value_added_module_dataArray<Google::Apis::WalletobjectsV1::ValueAddedModuleData>

Optional value added module data. Maximum of fifteen on the class. For a pass only fifteen will be displayed, prioritizing those from the object. Corresponds to the JSON property valueAddedModuleData



8379
8380
8381
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8379

def value_added_module_data
  @value_added_module_data
end

#versionFixnum

Deprecated Corresponds to the JSON property version

Returns:

  • (Fixnum)


8384
8385
8386
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8384

def version
  @version
end

#view_unlock_requirementString

View Unlock Requirement options for the transit ticket. Corresponds to the JSON property viewUnlockRequirement

Returns:

  • (String)


8389
8390
8391
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8389

def view_unlock_requirement
  @view_unlock_requirement
end

#watermarkGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property watermark



8394
8395
8396
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8394

def watermark
  @watermark
end

#wide_logoGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property wideLogo



8399
8400
8401
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8399

def 
  @wide_logo
end

#word_markGoogle::Apis::WalletobjectsV1::Image

Wrapping type for Google hosted images. Corresponds to the JSON property wordMark



8404
8405
8406
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8404

def word_mark
  @word_mark
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



8411
8412
8413
8414
8415
8416
8417
8418
8419
8420
8421
8422
8423
8424
8425
8426
8427
8428
8429
8430
8431
8432
8433
8434
8435
8436
8437
8438
8439
8440
8441
8442
8443
8444
8445
8446
8447
8448
8449
8450
8451
8452
8453
8454
8455
8456
8457
8458
8459
8460
8461
8462
8463
8464
8465
8466
8467
8468
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 8411

def update!(**args)
  @activation_options = args[:activation_options] if args.key?(:activation_options)
  @allow_multiple_users_per_object = args[:allow_multiple_users_per_object] if args.key?(:allow_multiple_users_per_object)
  @app_link_data = args[:app_link_data] if args.key?(:app_link_data)
  @callback_options = args[:callback_options] if args.key?(:callback_options)
  @class_template_info = args[:class_template_info] if args.key?(:class_template_info)
  @country_code = args[:country_code] if args.key?(:country_code)
  @custom_carriage_label = args[:custom_carriage_label] if args.key?(:custom_carriage_label)
  @custom_coach_label = args[:custom_coach_label] if args.key?(:custom_coach_label)
  @custom_concession_category_label = args[:custom_concession_category_label] if args.key?(:custom_concession_category_label)
  @custom_confirmation_code_label = args[:custom_confirmation_code_label] if args.key?(:custom_confirmation_code_label)
  @custom_discount_message_label = args[:custom_discount_message_label] if args.key?(:custom_discount_message_label)
  @custom_fare_class_label = args[:custom_fare_class_label] if args.key?(:custom_fare_class_label)
  @custom_fare_name_label = args[:custom_fare_name_label] if args.key?(:custom_fare_name_label)
  @custom_other_restrictions_label = args[:custom_other_restrictions_label] if args.key?(:custom_other_restrictions_label)
  @custom_platform_label = args[:custom_platform_label] if args.key?(:custom_platform_label)
  @custom_purchase_face_value_label = args[:custom_purchase_face_value_label] if args.key?(:custom_purchase_face_value_label)
  @custom_purchase_price_label = args[:custom_purchase_price_label] if args.key?(:custom_purchase_price_label)
  @custom_purchase_receipt_number_label = args[:custom_purchase_receipt_number_label] if args.key?(:custom_purchase_receipt_number_label)
  @custom_route_restrictions_details_label = args[:custom_route_restrictions_details_label] if args.key?(:custom_route_restrictions_details_label)
  @custom_route_restrictions_label = args[:custom_route_restrictions_label] if args.key?(:custom_route_restrictions_label)
  @custom_seat_label = args[:custom_seat_label] if args.key?(:custom_seat_label)
  @custom_ticket_number_label = args[:custom_ticket_number_label] if args.key?(:custom_ticket_number_label)
  @custom_time_restrictions_label = args[:custom_time_restrictions_label] if args.key?(:custom_time_restrictions_label)
  @custom_transit_terminus_name_label = args[:custom_transit_terminus_name_label] if args.key?(:custom_transit_terminus_name_label)
  @custom_zone_label = args[:custom_zone_label] if args.key?(:custom_zone_label)
  @enable_single_leg_itinerary = args[:enable_single_leg_itinerary] if args.key?(:enable_single_leg_itinerary)
  @enable_smart_tap = args[:enable_smart_tap] if args.key?(:enable_smart_tap)
  @hero_image = args[:hero_image] if args.key?(:hero_image)
  @hex_background_color = args[:hex_background_color] if args.key?(:hex_background_color)
  @homepage_uri = args[:homepage_uri] if args.key?(:homepage_uri)
  @id = args[:id] if args.key?(:id)
  @image_modules_data = args[:image_modules_data] if args.key?(:image_modules_data)
  @info_module_data = args[:info_module_data] if args.key?(:info_module_data)
  @issuer_name = args[:issuer_name] if args.key?(:issuer_name)
  @language_override = args[:language_override] if args.key?(:language_override)
  @links_module_data = args[:links_module_data] if args.key?(:links_module_data)
  @localized_issuer_name = args[:localized_issuer_name] if args.key?(:localized_issuer_name)
  @locations = args[:locations] if args.key?(:locations)
  @logo = args[:logo] if args.key?(:logo)
  @merchant_locations = args[:merchant_locations] if args.key?(:merchant_locations)
  @messages = args[:messages] if args.key?(:messages)
  @multiple_devices_and_holders_allowed_status = args[:multiple_devices_and_holders_allowed_status] if args.key?(:multiple_devices_and_holders_allowed_status)
  @notify_preference = args[:notify_preference] if args.key?(:notify_preference)
  @redemption_issuers = args[:redemption_issuers] if args.key?(:redemption_issuers)
  @review = args[:review] if args.key?(:review)
  @review_status = args[:review_status] if args.key?(:review_status)
  @security_animation = args[:security_animation] if args.key?(:security_animation)
  @text_modules_data = args[:text_modules_data] if args.key?(:text_modules_data)
  @transit_operator_name = args[:transit_operator_name] if args.key?(:transit_operator_name)
  @transit_type = args[:transit_type] if args.key?(:transit_type)
  @value_added_module_data = args[:value_added_module_data] if args.key?(:value_added_module_data)
  @version = args[:version] if args.key?(:version)
  @view_unlock_requirement = args[:view_unlock_requirement] if args.key?(:view_unlock_requirement)
  @watermark = args[:watermark] if args.key?(:watermark)
  @wide_logo = args[:wide_logo] if args.key?(:wide_logo)
  @word_mark = args[:word_mark] if args.key?(:word_mark)
end