Class: Google::Apis::WalletobjectsV1::Uri
- Inherits:
-
Object
- Object
- Google::Apis::WalletobjectsV1::Uri
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/walletobjects_v1/classes.rb,
lib/google/apis/walletobjects_v1/representations.rb,
lib/google/apis/walletobjects_v1/representations.rb
Instance Attribute Summary collapse
-
#description ⇒ String
The URI's title appearing in the app as text.
-
#id ⇒ String
The ID associated with a uri.
-
#kind ⇒ String
Identifies what kind of resource this is.
-
#localized_description ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the description.
-
#uri ⇒ String
The location of a web page, image, or other resource.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Uri
constructor
A new instance of Uri.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Uri
Returns a new instance of Uri.
9074 9075 9076 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9074 def initialize(**args) update!(**args) end |
Instance Attribute Details
#description ⇒ String
The URI's title appearing in the app as text. Recommended maximum is 20
characters to ensure full string is displayed on smaller screens. Note that in
some contexts this text is not used, such as when description is part of an
image.
Corresponds to the JSON property description
9046 9047 9048 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9046 def description @description end |
#id ⇒ String
The ID associated with a uri. This field is here to enable ease of management
of uris.
Corresponds to the JSON property id
9052 9053 9054 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9052 def id @id end |
#kind ⇒ String
Identifies what kind of resource this is. Value: the fixed string "
walletobjects#uri".
Corresponds to the JSON property kind
9058 9059 9060 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9058 def kind @kind end |
#localized_description ⇒ Google::Apis::WalletobjectsV1::LocalizedString
Translated strings for the description. Recommended maximum is 20 characters
to ensure full string is displayed on smaller screens.
Corresponds to the JSON property localizedDescription
9064 9065 9066 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9064 def localized_description @localized_description end |
#uri ⇒ String
The location of a web page, image, or other resource. URIs in the
LinksModuleData module can have different prefixes indicating the type of URI
(a link to a web page, a link to a map, a telephone number, or an email
address). URIs must have a scheme.
Corresponds to the JSON property uri
9072 9073 9074 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9072 def uri @uri end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
9079 9080 9081 9082 9083 9084 9085 |
# File 'lib/google/apis/walletobjects_v1/classes.rb', line 9079 def update!(**args) @description = args[:description] if args.key?(:description) @id = args[:id] if args.key?(:id) @kind = args[:kind] if args.key?(:kind) @localized_description = args[:localized_description] if args.key?(:localized_description) @uri = args[:uri] if args.key?(:uri) end |